package com.unis.inspection.app.base;


import java.util.*;

import com.unis.base.client.QybgsqApi;
import com.unis.base.client.XzqhFeign;
import com.unis.base.common.vo.*;
import com.unis.common.utils.JsonUtils;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspection.constant.CompanyMainBusinessConstant;
import com.unis.inspection.constant.InspectionConstant;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.base.client.CompanyFeign;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;


@RestController
@Slf4j
@Api(value = "企业信息", tags = "企业信息维护")
public class CompanyController {

	@Autowired
	private CompanyFeign companyFeign;

	@Autowired
	private MyUserClient myUserClient;

    @Autowired
    private QybgsqApi qybgsqApi;

    @Autowired
    private XzqhFeign xzqhFeign;

	/**
	 * @author huangxing
	 * @Description 获取企业信息列表
	 * 
	 * @return 企业信息列表
	 */
	@ApiOperation(value = "获取企业信息列表", notes = "参数：企业信息实体信息")
	@PostMapping(value = "/companyList")
	public ResponseWrapper getCompanyList(@RequestBody CompanyQueryVO companyQueryVO) {

		ResponseWrapper responseWrapper= companyFeign.getCompanyList(companyQueryVO);
		if(responseWrapper!=null && responseWrapper.getData()!=null){
			List<LinkedHashMap> list= (List<LinkedHashMap>)responseWrapper.getData();
			if(list!=null && list.size()>0){
				for(LinkedHashMap map : list){
					String qyjgdm= String.valueOf(map.get("sslsxzglbm"));
					if(StringUtils.isNotEmpty(qyjgdm)){
						ResponseWrapper response=myUserClient.findOrgByOrgCode(qyjgdm);
						if(response.isSuccess() && response.getData()!=null){
							Map<String,Object > orgMap= (LinkedHashMap)response.getData();
							String countyCode=String.valueOf(orgMap.get("countyCode"));
							map.put("orginfo", orgMap);
							if(StringUtils.isNotBlank(countyCode)){
								XzqhListVO xzqhListVO=new XzqhListVO();
								xzqhListVO.setXzqh(countyCode);
								ResponseWrapper rsp= xzqhFeign.selectByEntity(xzqhListVO);
								if(rsp.isSuccess() && rsp.getData()!=null){
									map.put("xzqhList", rsp.getData());
								}
							}
						}
					}
				}
			}
			responseWrapper.setData(list);
		}
		return responseWrapper;
	}

	/**
	 * @author huangxing
	 * @Description 获取企业信息列表
	 * 
	 * @return 企业信息列表
	 */
	@ApiOperation(value = "分页获取企业信息列表", notes = "参数：企业性质，法定代表人")
	@PostMapping(value = "/companyPage/{pageNum}/{pageSize}")
	public ResponseWrapper getCompanyPage(@RequestBody CompanyQueryVO companyVO,
			@PathVariable("pageNum") Integer pageNum, @PathVariable("pageSize") Integer pageSize) {

		List<Integer> zts = new ArrayList<Integer>();
		zts.add(0);
		zts.add(1);
		companyVO.setQyzts(zts);
		String orgCode = CurrentUtil.getOrgId();
		companyVO.setAreaCode(CurrentUtil.getAreaCode());
		/*
		if(){
			companyVO.setSslsxzglbm(orgCode);
		}*/

		if(InspectionConstant.GRAIN_RESERVE_CORPORATION_ORGANIZATION_CODE.equals(orgCode)) {
			companyVO.setQyzyywOperator("or");
			companyVO.setQyzyyw(CompanyMainBusinessConstant.CITY.getValue());
		}
		ResponseWrapper resp= companyFeign.getCompanyPage(companyVO, pageNum, pageSize);
		if(resp.isSuccess() && resp.getData()!=null){
			LinkedHashMap pageData= (LinkedHashMap)resp.getData();
			for(Map<String,Object> map : (ArrayList<Map<String,Object>>)pageData.get("list")){
				QybgsqShowVO qybgsqShowVO=new QybgsqShowVO();
				qybgsqShowVO.setSfty("-999");
				qybgsqShowVO.setTyshxydm((String)map.get("tyshxydm"));
				ResponseWrapper reson= qybgsqApi.selectById(qybgsqShowVO);
				if(reson.isSuccess() && reson.getData()!=null){
					QybgsqVO qybgsqVO= JsonUtils.parse(JsonUtils.serialize(reson.getData()), QybgsqVO.class);
					map.put("qybgsqVO",qybgsqVO);
				}
			}
			resp.setData(pageData);
		}
		return resp;

	}

	/**
	 * @author huangxing
	 * @Description 查询企业信息
	 * @param companyQueryVO
	 */
	@ApiOperation(value = "判断企业是否存在并返回企业信息", notes = "判断企业是否存在并返回企业信息")
	@PostMapping(value = "/findCompany")
	public ResponseWrapper findCompany(@RequestBody CompanyQueryVO companyQueryVO) {
		String orgId=CurrentUtil.getOrgId();
		String orgName=CurrentUtil.getOrgName();
		ResponseWrapper responseWrapper= companyFeign.selectByEntity(companyQueryVO);
		Map<String,Object> dataMap=new HashMap<>();
		List<Map<String,Object>> dataList=new ArrayList<>();

		dataMap.put("orgId", orgId);
		dataMap.put("orgName", orgName);
		if(responseWrapper.isSuccess() && responseWrapper.getData()!=null){
            QybgsqListVO qybgsqListVO=new QybgsqListVO();
			Object obj= responseWrapper.getData();
			List<CompanyNewVO> companyVOList= JsonUtils.parseList(JsonUtils.serialize(obj), CompanyNewVO.class);

			dataMap.put("companyInfo", dataList);

			Map<String,Object> companyMap=null;
			for(CompanyNewVO companyVOTemp : companyVOList){
				companyMap = new HashMap<>();
				String glbm= companyVOTemp.getSslsxzglbm();
				if(glbm!=null && glbm.equals(orgId)){
					companyMap.put("same", true);
				}else{
					companyMap.put("same", false);
				}
				companyMap.put("qymc", companyVOTemp.getQymc() );
				companyMap.put("tyshxydm", companyVOTemp.getTyshxydm() );
				companyMap.put("sslsxzglbm", companyVOTemp.getSslsxzglbm() );
				ResponseWrapper resp= myUserClient.findByCode(companyVOTemp.getSslsxzglbm());
				if(resp.isSuccess() && resp.getData()!=null){
					companyMap.put("sslsxzglbmmc", resp.getData());
				}
				//公司是否注销,需要对接平台,目前尚未对接,都是未注销
				boolean isOffLine=false;
				companyMap.put("isOffLine", isOffLine);
				if(isOffLine){
					companyMap.put("company", companyVOTemp);
				}

                companyMap.put("apply", true);
                qybgsqListVO.setSfty("-999");
                qybgsqListVO.setTyshxydm(companyVOTemp.getTyshxydm());
                ResponseWrapper reson= qybgsqApi.selectByEntity(qybgsqListVO);
                if(reson.isSuccess() && reson.getData()!=null){
                    List<QybgsqVO> sqList= JsonUtils.parseList(JsonUtils.serialize(reson.getData()), QybgsqVO.class);
                    if(sqList==null || sqList.size()==0){
                        companyMap.put("apply", false);
                    }
                }
				dataList.add(companyMap);
			}


			return ResponseWrapper.success(dataMap);
		}
		return ResponseWrapper.error("找不到记录");
	}


	/**
	 * @author huangxing
	 * @Description 新增企业信息
	 * @param companyVO：企业信息实体
	 *            models
	 * @return 新增状态
	 */
	@PostMapping(value = "/company")
	@ApiOperation(value = "新增企业信息", notes = "参数：企业信息实体 models")
	public ResponseWrapper insert(@RequestBody CompanyVO companyVO) {
		if(companyVO.getQyzt()==null){
			companyVO.setQyzt(1);
		}
		return companyFeign.insert(companyVO);
	}

	/**
	 * @author huangxing
	 * @Description 修改企业信息
	 * @param companyVO：企业信息实体
	 *            models
	 * @return 新增状态
	 */
	@PutMapping(value = "/company")
	@ApiOperation(value = "更新企业信息", notes = "参数：企业信息实体 models")
	public ResponseWrapper update(@RequestBody CompanyVO companyVO) {

		return companyFeign.update(companyVO);

	}

	/**
	 * @author huangxing
	 * @Description 获取企业信息
	 * @param tyshxydm：社会行政代码
	 * @return 企业信息实体
	 */
	@GetMapping(value = "/company/{tyshxydm}")
	@ApiOperation(value = "根据统一社会行政代码获取企业信息", notes = "参数：社会行政代码")
	public ResponseWrapper getCompanyBytyshxydm(@PathVariable("tyshxydm") String tyshxydm) {

		return companyFeign.getCompanyBytyshxydm(tyshxydm);
	}

	/**
	 * @author huangxing
	 * @Description 删除企业信息
	 * @param tyshxydm：社会行政代码
	 * @return 状态
	 */
	@DeleteMapping(value = "/company/{tyshxydm}")
	@ApiOperation(value = "根据统一社会行政代码删除企业信息", notes = "参数：社会行政代码")
	public ResponseWrapper delete(@PathVariable("tyshxydm") String tyshxydm) {

		return companyFeign.delete(tyshxydm);
	}

	/**
	 * 企业机构关联添加
	 * 
	 * @param tzQyjgDO
	 * @return
	 */
	@PostMapping(value = "/organization")
	@ApiOperation(value = "企业机构关联添加", notes = "参数：企业机构代码")
	public ResponseWrapper insertQyjg(@RequestBody TzQyjgVO tzQyjgDO){
		
		return companyFeign.insertQyjg(tzQyjgDO);
	}

	/**
	 * 根据企业机构代码查询企业
	 * 
	 * @param qyjgdm
	 * @return
	 */
	@GetMapping(value = "/organization/{qyjgdm}")
	@ApiOperation(value = "根据企业机构代码查询企业", notes = "参数：企业机构代码")
	public ResponseWrapper getSlqy(@PathVariable("qyjgdm") String qyjgdm){
		
		return companyFeign.getSlqy(qyjgdm);
	}

	/**
	 * 根据企业机构代码查询企业
	 * 
	 * @param randomCompanyQuery
	 * @return
	 */
	@PostMapping(value = "/randomcompany")
	@ApiOperation(value = "随机抽取企业", notes = "参数：随机抽取企业查询信息")
	public ResponseWrapper randomcompany(@RequestBody RandomCompanyQuery randomCompanyQuery){
		
		return companyFeign.randomcompany(randomCompanyQuery);
	}
	
	/**
	 * 禁用/启用
	 * @param qyzt
	 * @return
	 */
	@PostMapping(value = "/companyStatus/{qyzt}/{id}")
	@ApiOperation(value = "企业信息-更新启用状态", notes = "参数：启用状态，企业ID")
	public ResponseWrapper updateQyzt(@PathVariable(value="qyzt") Integer qyzt,
									  @PathVariable(value="id") Integer id) {
		return companyFeign.updateQyzt(qyzt,id);
	}
	
	@ApiOperation(value = "获取企业信息列表", notes = "参数：经纬度")
	@PostMapping(value = "/companyListLaLo/{pageNum}/{pageSize}")
    public ResponseWrapper getCompanyListByLaLo(@RequestBody CompanyQueryVO companyQueryVO,@PathVariable(value="pageNum") Integer pageNum,@PathVariable(value="pageSize") Integer pageSize) {
		return companyFeign.getCompanyListByLaLo(companyQueryVO, pageNum, pageSize);
	}

}
