package com.unis.inspection.app.base;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.collections.map.HashedMap;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.unis.base.client.CompanyFeign;
import com.unis.base.common.vo.CompanyQueryVO;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.client.GatherFeign;
import com.unis.inspectionplan.common.vo.GatherQueryVO;
import com.unis.inspectionplan.common.vo.GatherVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
 
@RestController
@Slf4j
@Api(value = "专项汇总", tags = "专项汇总")
public class GatherController {
	
	@Autowired
	private GatherFeign gatherFeign;
	@Autowired
	private CompanyFeign companyFeign;
 
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "新增/更新专项汇总")
    @PostMapping("/gather")
    public ResponseWrapper gather(@RequestBody List<GatherVO> gatherVOs) {
		return gatherFeign.gather(gatherVOs);
    }
	
	 private ObjectMapper objectMapper = new ObjectMapper();
	
	
	@ApiOperation(value = "分页获取企业信息列表", notes = "参数：社会统一行政编码，企业名称，企业类型，企业性质，法定代表人")
	@PostMapping(value = "/gatherPage/{pageNum}/{pageSize}")
	public ResponseWrapper getgatherPage(@RequestBody GatherQueryVO gatherQueryVO,
			@PathVariable("pageNum") Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		CompanyQueryVO companyVO = new CompanyQueryVO();
		String orgCode = CurrentUtil.getOrgId();
		List<Integer> zts = new ArrayList<Integer>();
		zts.add(0);
		zts.add(1);
		companyVO.setQyzts(zts);
		companyVO.setSfzdzgqy("1");
		if(StringUtils.isNotBlank(gatherQueryVO.getDwid())){
			if(gatherQueryVO.getDwid().length()>8){
				companyVO.setSslsxzglbm(gatherQueryVO.getDwid().substring(0,8));
				companyVO.setQyjgdm(gatherQueryVO.getDwid());
			}else{
				companyVO.setSslsxzglbm(gatherQueryVO.getDwid());
			}
		}else{
			if(orgCode.length()>8){
				companyVO.setSslsxzglbm(orgCode.substring(0,8));
			}else{
				companyVO.setSslsxzglbm(orgCode);
			}
		}

		String[] qylx = null;
		if(gatherQueryVO.getTblx().equals("0")) {
			qylx = new String[1];
			qylx[0] = "10";
			companyVO.setQylxbh(qylx);
		} else if(gatherQueryVO.getTblx().equals("1")) {
			qylx = new String[1];
			qylx[0] = "26";
			companyVO.setQylxbh(qylx);
		} else if(gatherQueryVO.getTblx().equals("2")) {
			qylx = new String[11];
			qylx[0] = "13";
			qylx[1] = "14";
			qylx[2] = "15";
			qylx[3] = "16";
			qylx[4] = "25";
			qylx[5] = "17";
			qylx[6] = "18";
			qylx[7] = "19";
			qylx[8] = "21";
			qylx[9] = "22";
			qylx[10] = "23";
			companyVO.setQylxbh(qylx);
		}
		ResponseWrapper responseWrapper = companyFeign.getCompanyPage(companyVO, pageNum, pageSize);
		if(responseWrapper.getInfoCode()!=200) {
			return ResponseWrapper.error("获取企业信息失败");
		}
		JSONObject jsonObject5 = new JSONObject();
		List<GatherVO> jsonObjects = new ArrayList<GatherVO>();
		Map<String, Object> map = new HashMap<String, Object>();
		if(responseWrapper.getData()!=null) {
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData());
			JSONArray array = JSONUtil.parseArray(jsonObject.get("list"));
			for (int i = 0; i < array.size(); i++) {
				JSONObject jsonObject2 = array.getJSONObject(i);
				gatherQueryVO.setDwid(jsonObject2.getStr("qyjgdm"));
				ResponseWrapper wrapper = gatherFeign.gatherInfo(gatherQueryVO);
				JSONObject object = new JSONObject();
				if(wrapper.getInfoCode()==200 && wrapper.getData()!=null) {
					GatherVO inspectionplanVO = objectMapper.convertValue(wrapper.getData(), GatherVO.class);
					inspectionplanVO.setDwdz(jsonObject2.getStr("qytxdz"));
					inspectionplanVO.setDwlxr(jsonObject2.getStr("qylxr"));
					inspectionplanVO.setDwfr(jsonObject2.getStr("fddbr"));
					inspectionplanVO.setDwqyxz(jsonObject2.getStr("qyxz"));
					inspectionplanVO.setDwlxrdh(jsonObject2.getStr("bgdh"));
					jsonObjects.add(inspectionplanVO);
				} else {
					GatherVO vo = new GatherVO();
					vo.setDwid(jsonObject2.getStr("qyjgdm"));
					vo.setDwdz(jsonObject2.getStr("qytxdz"));
					vo.setDwmc(jsonObject2.getStr("qymc"));
					vo.setDwlxr(jsonObject2.getStr("qylxr"));
					vo.setDwfr(jsonObject2.getStr("fddbr"));
					vo.setDwqyxz(jsonObject2.getStr("qyxz"));
					vo.setDwlxrdh(jsonObject2.getStr("bgdh"));
					vo.setSjzt("0");
					jsonObjects.add(vo);
				}
			}
			jsonObject5.put("list", jsonObjects);
			jsonObject5.put("total", jsonObject.getInt("total"));
		}
		
		return ResponseWrapper.success(jsonObject5);

	}
	
	@ApiOperation(value = "退回")
	@PostMapping("/gatherInfoBack")
    public ResponseWrapper updategatherInfo(@RequestBody List<String> dwids) {
		return gatherFeign.updategatherInfo(dwids);
    }
}