package com.unis.inspection.app.base;

import com.unis.base.client.OiltankFeign;
import com.unis.base.client.WarehouseFeign;
import com.unis.base.common.vo.DCfxxsjyVO;
import com.unis.base.common.vo.OiltankQueryVO;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.client.GrainAndOilRecordClient;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.unis.inspection.service.WarehouseService;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;

@RestController
@Slf4j
@Api(value = "仓房信息", tags = "仓房信息维护")
public class WarehouseController {

	@Autowired
	private WarehouseFeign warehouseFeign;

	@Autowired
    private GrainAndOilRecordClient grainandoilrecordClient;

	@Autowired
	private OiltankFeign oiltankFeign;

	@Autowired
	private DailyCheckResultApi dailyCheckResultApi;

	@Autowired
	private WarehouseService warehouseService;

	@Value("${project.chengpinliang}")
	private String[] chengPinLiangArray;

    @Value("${env.java-run}")
    private String env;


    private static final List<String> envIgnore = Arrays.asList("dev", "test");

	/**
	 * @author huangxing
	 * @Description 获取仓房列表
	 * @return 仓房信息列表
	 */
	@ApiOperation(value = "获取仓房信息列表", notes = "参数：仓房编号，仓房名称，库点编号，库点名称，仓房类型，建筑类型，仓房状态")
	@PostMapping(value = "/warehouseList")
	public ResponseWrapper getDCfxxxsjyList(@RequestBody DCfxxsjyVO dCfxxsjyVO){
		return warehouseFeign.getDCfxxxsjyList(dCfxxsjyVO);
	}


	/**
	 * @author huangxing
	 * @Description 获取仓房列表
	 * @return 仓房信息列表
	 */
	@ApiOperation(value = "获取成品粮仓房和油罐信息列表", notes = "参数：库点编号")
	@PostMapping(value = "/warehouseoiltankList")
	public ResponseWrapper warehouseoiltankList(@RequestBody DCfxxsjyVO dCfxxsjyVO){
        log.info("env >>>>>>>>>>>>>>>>> {}", env);
		return ResponseWrapper.success(warehouseService.getWarehouseOilTankList(dCfxxsjyVO));
	}

	@ApiOperation(value = "获取成品粮仓房和油罐信息列表", notes = "参数：库点编号")
	@PostMapping(value = "/warehouseoiltankList1")
	public ResponseWrapper warehouseoiltankList1(@RequestBody DCfxxsjyVO dCfxxsjyVO){
		JSONArray jsonArray = warehouseService.getWarehouseOilTankList(dCfxxsjyVO);
		if(jsonArray != null && !jsonArray.isEmpty()){
			return ResponseWrapper.success(warehouseService.getWarehouseOilTankList(jsonArray));
		}
		return ResponseWrapper.error("获取数据失败！");
	}

	/**
	 * @author huangxing
	 * @Description 获取仓房列表
	 * @return 仓房信息列表
	 */
	/*@ApiOperation(value = "获取原粮仓房信息列表", notes = "参数：库点编号")
	@PostMapping(value = "/warehouseTypeList")
	public ResponseWrapper warehouseTypeList(@RequestBody DCfxxsjyVO dCfxxsjyVO){
		ResponseWrapper responseWrapper = warehouseFeign.getDCfxxxsjyList(dCfxxsjyVO);
		JSONArray array = new JSONArray();
		if(responseWrapper.isSuccess()) {
			if(responseWrapper.getData()!=null) {
				array = JSONUtil.parseArray(responseWrapper.getData());
				Iterator<Object> it= array.iterator();
				JSONObject jsonObject=null;
				while(it.hasNext()){
					jsonObject=(JSONObject)it.next();
					jsonObject.put("sfyg", "0");
					String lspzmc=jsonObject.getStr("lspzmc");
					boolean isYuanLiang=true;
					if(StringUtils.isNotEmpty(lspzmc)){
						for(String s : chengPinLiangArray){
							if(lspzmc.contains(s)){
								isYuanLiang=false;
								break;
							}
						}
					}
					if(!isYuanLiang){
						it.remove();
					}
				}
			}
		}
		return ResponseWrapper.success(array);
	}*/


	/**
	 * @author huangxing
	 * @Description 获取企业信息列表
	 * @param ，企业名称，企业类型，企业性质，法定代表人
	 * @return 企业信息列表
	 */
	@ApiOperation(value = "分页获取仓房信息列表", notes = "参数：仓房编号，仓房名称，库点编号，库点名称，仓房类型，建筑类型，仓房状态")
	@PostMapping(value = "/warehousePage/{pageNum}/{pageSize}")
	public ResponseWrapper getDCfxxxsjyPage(@RequestBody DCfxxsjyVO dCfxxsjyVO,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize){
		return warehouseFeign.getDCfxxxsjyPage(dCfxxsjyVO,pageNum,pageSize);
	}


	/**
	 * @author huangxing
	 * @Description 根据库点编码获取库点信息
	 * @return 库点信息
	 */
	@ApiOperation(value = "根据仓房编码获取仓房信息", notes = "参数：库点编号")
	@GetMapping(value = "/warehouse/{cfbh}")
	public ResponseWrapper getDCfxxxsjyInfoBycfbh(@PathVariable("cfbh")String cfbh){
		return warehouseFeign.getDCfxxxsjyInfoBycfbh(cfbh);
	}

	/**
	 * @author huangxing
	 * @Description 根据库点编码获取库点信息
	 * @return 库点信息
	 */
	@ApiOperation(value = "更新仓房信息", notes = "参数：仓房信息 models")
	@PutMapping(value = "/warehouse")
	public ResponseWrapper update(@RequestBody DCfxxsjyVO dCfxxsjyVO){
		dCfxxsjyVO.setRefresher(CurrentUtil.getUserName());
		dCfxxsjyVO.setRefresherCode(CurrentUtil.getUserId());
		dCfxxsjyVO.setRefreshTime(new Date());
		return warehouseFeign.update(dCfxxsjyVO);
	}

	/**
	 * @author huangxing
	 * @Description 删除企业信息
	 * @param ：社会行政代码
	 * @return 状态
	 */
	@DeleteMapping(value="/warehouse/{cfbh}")
	@ApiOperation(value = "根据仓房编号删除仓房信息", notes = "参数：仓房编号")
	public ResponseWrapper delete(@PathVariable("cfbh")String cfbh){
		return warehouseFeign.delete(cfbh);
	}

	/**
	 * @author huangxing
	 * @Description 新增仓房信息
	 * @param
	 * @return 新增状态
	 */
	@PostMapping(value = "/warehouse")
	@ApiOperation(value = "新增仓房信息", notes = "参数：仓房信息实体 models")
	public ResponseWrapper insert(@RequestBody DCfxxsjyVO dAjxxsjyVO){

		dAjxxsjyVO.setCreator(CurrentUtil.getUserName());
		dAjxxsjyVO.setCreatorCode(CurrentUtil.getUserId());
		dAjxxsjyVO.setCreateDate(new Date());

		return warehouseFeign.insert(dAjxxsjyVO);
	}

}
