package com.unis.inspection.app.myuser;

import java.util.List;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;

import io.swagger.annotations.ApiOperation;

/**
 * 
 * @Description：用户中心服务
 * @author：王帅
 * @date: 2020年1月4日 下午4:45:40
 */
@FeignClient("myuser")
public interface MyUserClient {

	/**
	 * 
	 * @Description: 查询本部门下所有人员
	 * @author: 王帅
	 * @param: @param  obj
	 * @param: @param  page
	 * @param: @param  size
	 * @param: @return 参数
	 * @return: ResponseWrapper 返回类型
	 */
	@PostMapping(value = "/user/findByDeptCode/{page}/{size}")
	public ResponseWrapper findByDeptCode(@RequestBody JSONObject obj, @RequestParam(value = "page") Integer page,
			@RequestParam(value = "size") Integer size);

	@ApiOperation(value = "根据组织编号获取本单位名字")
	@GetMapping("/org/findByCode")
	public ResponseWrapper findByCode(@RequestParam(value = "orgCode") String orgCode);

	@GetMapping("/user/getUserByRole")
	public ResponseWrapper getUserByRole(@RequestParam(value = "orgCode") List<String> roleCode);

    @ApiOperation(value = "通过部门编码获取用户", notes = "参数：deptCode")
    @GetMapping(value = "/user/findByDeptCode/{deptCode}")
    public ResponseWrapper findByDeptCode(@RequestParam(value = "deptCode") String deptCode);
    
    @ApiOperation(value = "根据用户类型，组织/部门获取用户", notes = "")
    @PostMapping("/user/findUserDeptId")
    public ResponseWrapper findUserDeptId(@RequestParam(value = "deptId") String deptId, @RequestParam(value = "deptSign") String deptSign, @RequestParam(value = "roleCode", required = false) String roleCode);
    
    @ApiOperation(value = "根据职务获取用户细腻", notes = "")
    @GetMapping("/user/findBySectionChief")
    public ResponseWrapper findBySectionChief(@RequestParam(value = "deptCode") String deptCode, @RequestParam(value = "headship") String headship, @RequestParam(value = "orgcode") String orgcode);
    
    @ApiOperation(value = "根据职务获取用户细腻", notes = "")
    @PostMapping("/org/getJdjcTreeData")
    public ResponseWrapper findBySectionChief(@RequestParam(value = "deptCode") String orgCode);

	@ApiOperation(value = "根据组织编号获取本单位信息-非树")
	@GetMapping("/org/info")
	public ResponseWrapper findOrgByOrgCode(@RequestParam(name="orgCode") String orgCode);
}
