package com.unis.inspection.app.plan;

import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.Map.Entry;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspectionplan.client.BaseInfoFeign;
import com.unis.inspectionplan.common.vo.BaseInfoVO;
import com.unis.inspectionplan.common.vo.GatherQueryVO;
import com.unis.inspectionplan.common.vo.GatherVO;
import com.unis.inspectionplan.common.vo.ReportVO;
import com.unis.inspectionresult.common.vo.CheckOrgVO;
import com.unis.inspectionresult.common.vo.CheckSecurityVO;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
 
@RestController
@Slf4j
@Api(value = "基础信息", tags = "基础信息")
public class BaseInfoController {
	
	@Autowired
	private BaseInfoFeign baseInfoService;

	@Autowired
	private MyUserClient myuserClient;
 
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "查询基础信息列表")
    @PostMapping("/baseinfo")
    public ResponseWrapper gather() {
    	try {
    		List<String> orgids = new ArrayList<String>();
    		ResponseWrapper responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				orgids.add(jsonObject.getStr("orgCode"));
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					orgids.add(obj.getStr("orgCode"));
				}
			} else {
				orgids.add(jsonObject.getStr("orgCode"));
			}
    		
    		
    		return baseInfoService.gather(orgids);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	@ApiOperation(value = "更新详情")
    @PostMapping("/getbaseinfo")
    public ResponseWrapper gatherInfo(String orgid) {
    	try {
    		return baseInfoService.gatherInfo(orgid);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	@ApiOperation(value = "查询详情")
    @PostMapping("/getbaseinfocha")
    public ResponseWrapper getbaseinfocha(String orgid) {
    	try {
    		return baseInfoService.getbaseinfocha(orgid);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	
	@ApiOperation(value = "更新基础信息")
    @PutMapping("/getbaseinfo")
    public ResponseWrapper getbaseinfo(@RequestBody BaseInfoVO baseInfoVO) {
    	try {
    		return baseInfoService.getbaseinfo(baseInfoVO);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	
	
	
	@ApiOperation(value = "经费落实情况")
    @PutMapping("/jfReport/{nd}")
    public ResponseWrapper jflsqk(@PathVariable("nd")String nd) {
    	try {
    		List<String> orgids = new ArrayList<String>();
    		ResponseWrapper responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				orgids.add(jsonObject.getStr("orgCode"));
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					orgids.add(obj.getStr("orgCode"));
				}
			} else {
				orgids.add(jsonObject.getStr("orgCode"));
			}
    		return  baseInfoService.jflsqk(orgids,nd);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	

	 private ObjectMapper objectMapper = new ObjectMapper();
	
	@ApiOperation(value = "经费落实情况")
    @PutMapping("/jfReportExport/{nd}")
    public ResponseWrapper jfReportExport(@PathVariable("nd")String nd, HttpServletRequest request,
			HttpServletResponse response) {
    	try {
    		List<String> orgids = new ArrayList<String>();
    		ResponseWrapper responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				orgids.add(jsonObject.getStr("orgCode"));
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					orgids.add(obj.getStr("orgCode"));
				}
			} else {
				orgids.add(jsonObject.getStr("orgCode"));
			}
			
			ResponseWrapper responseWrapper2 = baseInfoService.jflsqk(orgids,nd);
			if(responseWrapper2.getInfoCode()!=200) {
				 return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
			}
//			List<ReportVO> checkSecurityVOs = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), ReportVO.class);
			String xxx = JSONUtil.toJsonStr(responseWrapper2.getData());
			JSONArray jsonArray = JSONUtil.parseArray(xxx);
//			com.alibaba.fastjson.JSONArray arr = JSON.parseArray(JsonUtils.serialize(responseWrapper.getData()));
			List<ReportVO> checkSecurityVOs = new ArrayList<ReportVO>();
			int xzjghj=0,dljg=0,jglshwzcbp=0,znzhrqtbm=0,bmryhj=0,xzbz=0,sybz=0,nshj=0,dlslzfdc=0,jgzfdc=0,znzhdqtc=0,xzzfhj=0,qzhdlshwzcbz=0,lsjfdlshwzcbbm=0,ndlsjfje=0;
			for(int i=0;i<jsonArray.size();i++) {
				ReportVO reportVO = objectMapper.convertValue(jsonArray.getJSONObject(i), ReportVO.class);
				xzjghj = xzjghj + (reportVO.getXzjghj()==null?0:reportVO.getXzjghj());
				dljg = dljg+ (reportVO.getDljg()==null?0:reportVO.getDljg());
				jglshwzcbp = jglshwzcbp+(reportVO.getJglshwzcbp()==null?0:reportVO.getJglshwzcbp());
				znzhrqtbm = znzhrqtbm+(reportVO.getZnzhrqtbm()==null?0:reportVO.getZnzhrqtbm());
				bmryhj = bmryhj+(reportVO.getBmryhj()==null?0:reportVO.getBmryhj());
				xzbz=xzbz+(reportVO.getXzbz()==null?0:reportVO.getXzbz());    
				sybz=sybz+(reportVO.getSybz()==null?0:reportVO.getSybz());
				nshj=nshj+(reportVO.getNshj()==null?0:reportVO.getNshj());
				dlslzfdc=dlslzfdc+(reportVO.getDlslzfdc()==null?0:reportVO.getDlslzfdc());
				jgzfdc=jgzfdc+(reportVO.getJgzfdc()==null?0:reportVO.getJgzfdc());
				znzhdqtc=znzhdqtc+(reportVO.getZnzhdqtc()==null?0:reportVO.getZnzhdqtc());     
				xzzfhj=xzzfhj+(reportVO.getXzzfhj()==null?0:reportVO.getXzzfhj());    
				qzhdlshwzcbz=qzhdlshwzcbz+(reportVO.getQzhdlshwzcbz()==null?0:reportVO.getQzhdlshwzcbz());
				lsjfdlshwzcbbm=lsjfdlshwzcbbm+(reportVO.getLsjfdlshwzcbbm()==null?0:reportVO.getLsjfdlshwzcbbm());
				ndlsjfje=ndlsjfje+(reportVO.getNdlsjfje()==null?0:reportVO.getNdlsjfje());
				checkSecurityVOs.add(reportVO);
			}
			List<ReportVO> checkSecurityVOs2 = new ArrayList<ReportVO>();
			for(int i=0;i<checkSecurityVOs.size();i++) {
				if(i==0){
					ReportVO vo = checkSecurityVOs.get(i);
					vo.setOrgname("省级");
					vo.setXzqs(1);
					checkSecurityVOs2.add(vo);
					ReportVO reportVO = new ReportVO();
					reportVO.setOrgname("地市级");
					reportVO.setXzjghj(xzjghj);
					reportVO.setDljg(dljg);
					reportVO.setXzqs(16);
					reportVO.setJglshwzcbp(jglshwzcbp);
					reportVO.setZnzhrqtbm(znzhrqtbm);
					reportVO.setBmryhj(bmryhj);
					reportVO.setXzbz(xzbz);
					reportVO.setSybz(sybz);
					reportVO.setNshj(nshj);
					reportVO.setDlslzfdc(dlslzfdc);
					reportVO.setJgzfdc(jgzfdc);
					reportVO.setZnzhdqtc(znzhdqtc);
					reportVO.setXzzfhj(xzzfhj);
					reportVO.setQzhdlshwzcbz(qzhdlshwzcbz);
					reportVO.setLsjfdlshwzcbbm(lsjfdlshwzcbbm);
					reportVO.setNdlsjfje(ndlsjfje);
					checkSecurityVOs2.add(reportVO);
				} else {
					ReportVO vo = checkSecurityVOs.get(i);
					vo.setOrgname(vo.getOrgname().replace(vo.getOrgname().substring(vo.getOrgname().indexOf("区")+1, vo.getOrgname().length()),"" ));
					checkSecurityVOs2.add(vo);
				}
			}
			LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
			columnName.put("orgname", "行政区级");
			columnName.put("xzqs", "行政区数（个）");
			columnName.put("xzjghj", "合计");
			columnName.put("dljg", "独立机构");
			columnName.put("jglshwzcbp", "加挂粮食和物资储备牌");
			columnName.put("znzhrqtbm", "职能整合入其他部门");
			columnName.put("bmryhj", "合计");
			columnName.put("xzbz", "行政编制");
			columnName.put("sybz", "事业编制");
			columnName.put("nshj", "合计");
			columnName.put("dlslzfdc", "独立设立执法督查（监督检查）处（科、股）");
			columnName.put("jgzfdc", "加挂执法督查（监督检查）处（科、股）牌子");
			columnName.put("znzhdqtc", "职能整合入其他处（科、股）");
			columnName.put("xzzfhj", "合计");
			columnName.put("qzhdlshwzcbz", "其中：获得粮食和物资储备监督检查证的人数");
			columnName.put("lsjfdlshwzcbbm", "落实经费的粮食和物资储备部门数");
			columnName.put("ndlsjfje", "年度落实经费金额");
			String[] nds = nd.split("-");
			String jd = "";
			if(nds[1].equals("03")) {
				jd = "1";
			} else if(nds[1].equals("06")) {
				jd = "2";
			} else if(nds[1].equals("09")) {
				jd = "3";
			} else if(nds[1].equals("12")) {
				jd = "4";
			}
			// 输出Excel文件
			ServletOutputStream output = response.getOutputStream();
			response.reset();
			response.setHeader("content-disposition", "attachment;filename="
					+ new String(("粮食和物资储备行政管理部门"+nds[0]+"第"+jd+"季度执法督查机构、人员和经费落实情况统计表").getBytes("gb2312"), "ISO8859-1") + ".xls");
			response.setContentType("application/msexcel");
			pojo3Excel(checkSecurityVOs2, output, columnName,"粮食和物资储备行政管理部门"+nds[0]+"第"+jd+"季度执法督查机构、人员和经费落实情况统计表");
			output.close();
			return null;
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	
	public static <T> void pojo3Excel(List<T> pojoList, OutputStream out, LinkedHashMap<String, String> alias,String tableNmae) throws Exception {
		// 创建一个工作簿
		HSSFWorkbook wb = new HSSFWorkbook();
		// 创建一个表
		HSSFSheet sheet = wb.createSheet();
		// 创建第一行，作为表名
		HSSFRow row = sheet.createRow(0);
		HSSFCell cell = row.createCell(0);
		cell.setCellValue(tableNmae);
		
		HSSFRow row2 = sheet.createRow(1);
		HSSFCell cell2 = row2.createCell(0);
		cell2.setCellValue("填报单位：（盖章）");
		
		HSSFCell cell3 = row2.createCell(15);
		cell3.setCellValue("单位：个、万元");
		
		HSSFRow row7 = sheet.createRow(2);
		HSSFCell cell11 = row7.createCell(2);
		cell11.setCellValue("粮食和物资储备部门\r\n" + 
				"行政机构设置情况");
		HSSFCell cell12 = row7.createCell(6);
		cell12.setCellValue("粮食和物资储备\r\n" + 
				"部门人员编制情况");
		HSSFCell cell13 = row7.createCell(9);
		cell13.setCellValue("粮食和物资储备部门\r\n" + 
				"内设执法督查机构情况");
		HSSFCell cell14 = row7.createCell(13);
		cell14.setCellValue("具备行政执法（监督检查）资格的人数（人）");

		HSSFCell cell15 = row7.createCell(15);
		cell15.setCellValue("执法督查经费\r\n" + 
				"落实情况");

		sheet.addMergedRegion(new CellRangeAddress(2, 2, 2, 5));
		sheet.addMergedRegion(new CellRangeAddress(2, 2, 6, 8));
		sheet.addMergedRegion(new CellRangeAddress(2, 2, 9, 12));
		sheet.addMergedRegion(new CellRangeAddress(2, 2, 13, 14));
		sheet.addMergedRegion(new CellRangeAddress(2, 2, 15, 16));
//		HSSFCell cell2 = row.createCell(6);
//		cell2.setCellValue(headLine2);
		sheet.addMergedRegion(new CellRangeAddress(0, 0, 0, 16));
		sheet.addMergedRegion(new CellRangeAddress(1, 1, 0, 14));
		sheet.addMergedRegion(new CellRangeAddress(1, 1, 15, 16));

		// 在第一行插入列名
		insertColumnName(3, sheet, alias);
		// *从第2行开始插入数据
		insertColumnDate(4, pojoList, sheet, alias);
		
		
		
		
		HSSFRow row3 = sheet.createRow(22);
		HSSFCell cell4 = row3.createCell(0);
		cell4.setCellValue("执法督查机构负责人：");

		HSSFCell cell5 = row3.createCell(6);
		cell5.setCellValue("填表人：");
		HSSFCell cell6 = row3.createCell(9);
		cell6.setCellValue("填报日期：");

		sheet.addMergedRegion(new CellRangeAddress(22, 22, 0, 5));
		sheet.addMergedRegion(new CellRangeAddress(22, 22, 6, 8));
		sheet.addMergedRegion(new CellRangeAddress(22, 22, 9, 17));
		
		
		// 输出表格文件
		try {
			wb.write(out);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			wb.close();
		}
	}
	
	private static <T> void insertColumnDate(int beginRowNum, List<T> models, HSSFSheet sheet,
			Map<String, String> alias) throws Exception {
		for (T model : models) {
			// 创建新的一行
			HSSFRow rowTemp = sheet.createRow(beginRowNum++);

			// 获取列的迭代
			Set<Entry<String, String>> entrySet = alias.entrySet();

			// 从第0个格子开始创建
			int columnNum = 0;
			for (Entry<String, String> entry : entrySet) {
				// 获取属性值
				String property = BeanUtils.getProperty(model, entry.getKey());
				// 创建一个格子
				HSSFCell cell = rowTemp.createCell(columnNum++);
				cell.setCellValue(property);
			}
		}
	}
	
	private static void insertColumnName(int rowNum, HSSFSheet sheet, Map<String, String> alias) {
		HSSFRow row = sheet.createRow(rowNum);
		// 列的数量
		int columnCount = 0;

		Set<Entry<String, String>> entrySet = alias.entrySet();

		for (Entry<String, String> entry : entrySet) {
			// 创建第一行的第columnCount个格子
			HSSFCell cell = row.createCell(columnCount++);
			// 将此格子的值设置为alias中的键名
			cell.setCellValue(isNull(entry.getValue()).toString());
		}
	}
	
	private static Object isNull(Object object) {
		if (object != null) {
			return object;
		} else {
			return "0";
		}
	}
	
	
	
	@ApiOperation(value = "执法队信息")
    @PutMapping("/zfdReport/{nd}")
    public ResponseWrapper zfdReport(@PathVariable("nd")String nd) {
    	try {
    		List<String> orgids = new ArrayList<String>();
    		ResponseWrapper responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				orgids.add(jsonObject.getStr("orgCode"));
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					orgids.add(obj.getStr("orgCode"));
				}
			} else {
				orgids.add(jsonObject.getStr("orgCode"));
			}
    		return  baseInfoService.zfdReport(orgids,nd);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	
	
	
	@ApiOperation(value = "执法队信息")
    @PutMapping("/zfdReportExport/{nd}")
    public ResponseWrapper zfdReportExport(@PathVariable("nd")String nd, HttpServletRequest request,
			HttpServletResponse response) {
    	try {
    		List<String> orgids = new ArrayList<String>();
    		ResponseWrapper responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				orgids.add(jsonObject.getStr("orgCode"));
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					orgids.add(obj.getStr("orgCode"));
				}
			} else {
				orgids.add(jsonObject.getStr("orgCode"));
			}
			ResponseWrapper responseWrapper2=baseInfoService.zfdReport(orgids,nd);
			if(responseWrapper2.getInfoCode()!=200) {
				 return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
			}
//			List<ReportVO> checkSecurityVOs = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), ReportVO.class);
			String xxx = JSONUtil.toJsonStr(responseWrapper2.getData());
			JSONArray jsonArray = JSONUtil.parseArray(xxx);
//			com.alibaba.fastjson.JSONArray arr = JSON.parseArray(JsonUtils.serialize(responseWrapper.getData()));
			List<ReportVO> checkSecurityVOs = new ArrayList<ReportVO>();
			int xzqs=0,zjxzzfdhj=0,zzjgsl=0,fzzjgsl=0,xzbz=0,sybz=0;
			for(int i=0;i<jsonArray.size();i++) {
				ReportVO reportVO = objectMapper.convertValue(jsonArray.getJSONObject(i), ReportVO.class);
				xzqs = xzqs + (reportVO.getXzqs()==null?0:reportVO.getXzqs());
				zjxzzfdhj = zjxzzfdhj+   (reportVO.getZjxzzfdhj()==null?0:reportVO.getZjxzzfdhj());
				zzjgsl = zzjgsl+  (reportVO.getZzjgsl()==null?0:reportVO.getZzjgsl());
				fzzjgsl = fzzjgsl+  (reportVO.getFzzjgsl()==null?0:reportVO.getFzzjgsl());
				xzbz=xzbz+   (reportVO.getXzbz()==null?0:reportVO.getXzbz());    
				sybz=sybz+  (reportVO.getSybz()==null?0:reportVO.getSybz());
				checkSecurityVOs.add(reportVO);
			}
			List<ReportVO> checkSecurityVOs2 = new ArrayList<ReportVO>();
			for(int i=0;i<checkSecurityVOs.size();i++) {
				if(i==0){
					ReportVO vo = checkSecurityVOs.get(i);
					vo.setOrgname("省级");
					vo.setXzqs(1);
					checkSecurityVOs2.add(vo);
					ReportVO reportVO = new ReportVO();
					reportVO.setOrgname("地市级");
					reportVO.setXzqs(xzqs);
					reportVO.setZjxzzfdhj(zjxzzfdhj);
					reportVO.setZzjgsl(zzjgsl);
					reportVO.setFzzjgsl(fzzjgsl);
					reportVO.setXzbz(xzbz);
					reportVO.setSybz(sybz);
					checkSecurityVOs2.add(reportVO);
				} else {
					ReportVO vo = checkSecurityVOs.get(i);
					vo.setOrgname(vo.getOrgname().replace(vo.getOrgname().substring(vo.getOrgname().indexOf("区")+1, vo.getOrgname().length()),"" ));
					checkSecurityVOs2.add(vo);
				}
			}
			
			LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
			columnName.put("orgname", "行政区级");
			columnName.put("xzqs", "总计");
			columnName.put("xzqs", "合计");
			columnName.put("xzbz", "行政编制类");
			columnName.put("sybz", "事业编制类");
			columnName.put("zjxzzfdhj", "合计");
			columnName.put("zzjgsl", "专职机构");
			columnName.put("fzzjgsl", "非专职机构");
			String[] nds = nd.split("-");
			String jd = "";
			if(nds[1].equals("03")) {
				jd = "1";
			} else if(nds[1].equals("06")) {
				jd = "2";
			} else if(nds[1].equals("09")) {
				jd = "3";
			} else if(nds[1].equals("12")) {
				jd = "4";
			}
			// 输出Excel文件
			ServletOutputStream output = response.getOutputStream();
			response.reset();
			response.setHeader("content-disposition", "attachment;filename="
					+ new String(("粮食和物资储备行政管理部门"+nds[0]+"第"+jd+"季度成立行政执法队情况统计表").getBytes("gb2312"), "ISO8859-1") + ".xls");
			response.setContentType("application/msexcel");
			pojo4Excel(checkSecurityVOs2, output, columnName,"粮食和物资储备行政管理部门"+nds[0]+"第"+jd+"季度成立行政执法队情况统计表");
			output.close();
			return null;
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }
	
	public static <T> void pojo4Excel(List<T> pojoList, OutputStream out, LinkedHashMap<String, String> alias,String tableNmae) throws Exception {
		// 创建一个工作簿
		HSSFWorkbook wb = new HSSFWorkbook();
		// 创建一个表
		HSSFSheet sheet = wb.createSheet();
		// 创建第一行，作为表名
		HSSFRow row = sheet.createRow(0);
		HSSFCell cell = row.createCell(0);
		cell.setCellValue(tableNmae);
		
		HSSFRow row2 = sheet.createRow(1);
		HSSFCell cell2 = row2.createCell(0);
		cell2.setCellValue("填报单位：（盖章）");
		
		HSSFCell cell3 = row2.createCell(5);
		cell3.setCellValue("单位：个");
		
		
		
		HSSFRow row7 = sheet.createRow(2);
		HSSFCell cell11 = row7.createCell(1);
		cell11.setCellValue("编办批准粮食和物资储备行政\r\n" + 
				"管理部门成立行政执法队数");
		HSSFCell cell12 = row7.createCell(4);
		cell12.setCellValue("粮食和物资储备行政管理部门\r\n" + 
				"内部组建行政执法队数");

		sheet.addMergedRegion(new CellRangeAddress(2, 2, 1, 3));
		sheet.addMergedRegion(new CellRangeAddress(2, 2, 4, 6));
		
//		HSSFCell cell2 = row.createCell(6);
//		cell2.setCellValue(headLine2);
		sheet.addMergedRegion(new CellRangeAddress(0, 0, 0, 6));
		sheet.addMergedRegion(new CellRangeAddress(1, 1, 0, 4));
		sheet.addMergedRegion(new CellRangeAddress(1, 1, 5, 6));
		
		
		

		// 在第一行插入列名
		insertColumnName(3, sheet, alias);
		// *从第2行开始插入数据
		insertColumnDate(4, pojoList, sheet, alias);
		HSSFRow row3 = sheet.createRow(22);
		HSSFCell cell4 = row3.createCell(0);
		cell4.setCellValue("执法督查机构负责人：");

		HSSFCell cell5 = row3.createCell(4);
		cell5.setCellValue("填表人：");
		HSSFCell cell6 = row3.createCell(6);
		cell6.setCellValue("填报日期：");

		sheet.addMergedRegion(new CellRangeAddress(22, 22, 0, 3));
		sheet.addMergedRegion(new CellRangeAddress(22, 22, 4, 5));
		sheet.addMergedRegion(new CellRangeAddress(22, 22, 6, 8));
		// 输出表格文件
		try {
			wb.write(out);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			wb.close();
		}
	}
}