package com.unis.inspection.app.plan;

import java.util.Date;
import java.util.List;

import com.unis.inspectiontask.common.constant.TaskTypeConstant;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.collect.Lists;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspection.service.InspectionTaskService;
import com.unis.inspection.service.InspectionplanService;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.FileVO;
import com.unis.inspectionplan.common.vo.InspectionUnitVO;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.TypesofInspectedUnitsVO;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.common.vo.TaskVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "检查计划", tags = "检查计划")
public class InspectionController {

	@Autowired
	private InspectionplanFeign inspectionplanFeign;

	@Autowired
	private TaskFeign taskFeign;

	@Autowired
	private InspectionTaskService inspectionTaskService;

	@Autowired
	private DailyCheckResultApi dailyCheckResultApi;

	@Autowired
	private InspectionplanService inspectionplanService;

	@Autowired
    private MyUserClient userClient;

	/***************** 全局对象******************/
    private ObjectMapper objectMapper = new ObjectMapper();



	@ApiOperation(value = "根据仓号获取仓位信息", notes = "参数：仓号Id")
	@GetMapping(value = "/inspectionplan1/{cfbm}")
	public ResponseWrapper getStockInfoByCh(@PathVariable("cfbm") String cfbm){
		return inspectionplanFeign.getStockInfoByCh(cfbm);
	}

	/**
	 * 新增检查计划
	 *
	 * @param jcjhvo
	 * @return
	 */
	@ApiOperation(value = "新增检查计划", notes = "参数：检查计划实体信息")
	@PostMapping(value = "/inspectionplan")
	public ResponseWrapper insert(@RequestBody InspectionplanVO jcjhvo) {

		// 获得被检查单位列表
		List<TypesofInspectedUnitsVO> bjdwlxList = jcjhvo.getBjdwlxList();
		if (bjdwlxList != null) {
			for (TypesofInspectedUnitsVO vo : bjdwlxList) {
				vo.setCreateDate(new Date());
				vo.setRefreshDate(new Date());
				vo.setStatus(1);
				vo.setCreateor(CurrentUtil.getUserName());
				vo.setRefresher(CurrentUtil.getUserName());
			}
		}

		// 获得文件列表
		List<FileVO> fileList = jcjhvo.getFile();
		if (fileList != null) {
			for (FileVO vo : fileList) {
				vo.setStatus(1);
				vo.setCreateDate(new Date());
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
				vo.setRefresher(CurrentUtil.getUserName());
			}
		}

		// 获得表单列表
		List<CheckformVO> jcbdList = jcjhvo.getJcbd();
		if (jcbdList != null) {
			for (CheckformVO vo : jcbdList) {
				vo.setStatus(1);
				vo.setCreateDate(new Date());
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
				vo.setRefresher(CurrentUtil.getUserName());
			}
		}

		// 获取检查单位列表
		List<InspectionUnitVO> jcdwList = jcjhvo.getJcdwList();
		if (jcdwList != null) {
			for (InspectionUnitVO vo : jcdwList) {
				vo.setStatus(1);
				vo.setCreateDate(new Date());
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
				vo.setRefresher(CurrentUtil.getUserName());
			}
		}

		jcjhvo.setStatus(1);
		jcjhvo.setJhzt(1);
		jcjhvo.setCreateDate(new Date());
		jcjhvo.setRefreshDate(new Date());
		jcjhvo.setCreateor(CurrentUtil.getUserName());
		jcjhvo.setRefresher(CurrentUtil.getUserName());
		jcjhvo.setOrgId(CurrentUtil.getOrgId());

		return inspectionplanFeign.insert(jcjhvo);
	}

	/**
	 * 根据条件分页获取信息列表
	 *
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件分页获取信息列表")
	@PostMapping(value = "/inspectionplanList/{pageNum}/{pageSize}")
	public ResponseWrapper getInspectionplanList(@RequestBody InspectionplanQueryVO queryvo,
			   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize) {
		/**
		 * 	制定任务权限划分：
		 * 	1、粮食储备公司只能看类型为(日常检查-储备粮公司)的信息
		 *  2、市局的人只能查看该部门制定的任务，不区分任务类型
		 *  3、区粮办只能看各自制定的任务，不区分任务类型
		 */
		if(StringUtils.isNotEmpty(queryvo.getJhName())) {
			queryvo.setJhName(queryvo.getJhName().replace(" ", "").replace("%", "\\%"));
		}
		List<String> planIds = Lists.newArrayList();
		boolean isShow = false;
		this.createQueryVO(queryvo, planIds, null);
		String[] taskType = queryvo.getRwlxIds();
		if(!ObjectUtils.isEmpty(taskType)) {
			isShow = true;
		}
		if(CollectionUtils.isNotEmpty(planIds)) {
			isShow = true;
		}
		if(!isShow) {
			return ResponseWrapper.success(Lists.newArrayList());
		}
		queryvo.setOrgId(CurrentUtil.getOrgId());

		ResponseWrapper responseWrapper= inspectionplanFeign.getInspectionplanList(queryvo, pageNum, pageSize);
		return responseWrapper;
	}

	private InspectionplanQueryVO createQueryVO(InspectionplanQueryVO queryvo, List<String> planIds, String taskStatus) {
		String orgCode = CurrentUtil.getOrgId();
		String orgLevel = CurrentUtil.getOrgLevel();
		String deptId = CurrentUtil.getDeptId();
		if(StringUtils.isNotEmpty(orgCode)
				&& InspectionConstant.GRAIN_RESERVE_CORPORATION_ORGANIZATION_CODE.equals(orgCode)) {
			//无敌，是多么的寂寞
			queryvo.setRwlxIds(new String[] {"5000150",TaskTypeConstant.ShiJiChuBeiJianCha.getValue()});
		}else if(StringUtils.isNotEmpty(orgCode) && InspectionConstant.LiangShiChuBeiChu.equals(deptId)) {
			// 粮食储备处
			queryvo.setRwlxIds(new String[] {TaskTypeConstant.FangXunJianCha.getValue(),TaskTypeConstant.ZhuanXiangJianCha.getValue(),TaskTypeConstant.ANQUANJianCha.getValue()});
		} else if(StringUtils.isNotEmpty(orgCode) && InspectionConstant.JianDuJianChaChu.equals(deptId)) {
			// 监督检查处
			queryvo.setRwlxIds(new String[] {TaskTypeConstant.RiChangJianCha.getValue(),TaskTypeConstant.ShiJiChuBeiJianCha.getValue()
					,TaskTypeConstant.FangXunJianCha.getValue(),TaskTypeConstant.ZhuanXiangJianCha.getValue(),TaskTypeConstant.ANQUANJianCha.getValue()
					,TaskTypeConstant.ChuBeiLiangGongSi.getValue()});
		} else {
			//区粮办
			if(StringUtils.isNotEmpty(orgLevel) && InspectionConstant.AREA_FOOD_DO_ORGANIZATIONAL.equals(orgLevel)) {
				// 获取当前组织下任务
				ResponseWrapper result = taskFeign.getPlanIdsByOrgCodeOrMakers(orgCode, null, taskStatus);
				if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
					Object obj = result.getData();
					JSONArray arr = JSON.parseArray(JsonUtils.serialize(obj));
					arr.stream().forEach( planId -> {
						planIds.add((String)planId);
					});
				}
			} else if(StringUtils.isNotEmpty(orgLevel) && InspectionConstant.CITY_BUREAU_ORGANIZATIONAL.equals(orgLevel)) {//市局
				// 根据当前登录用户所在部门查询该部门下所有用户，然后根据用户集合查询计划主键集合
				/*String departmentId = CurrentUtil.getDeptId();
				if(StringUtils.isNotEmpty(departmentId)) {
					JSONObject obj = new JSONObject();
					obj.put("deptCode", departmentId);
					ResponseWrapper result = userClient.findByDeptCode(obj, 1, 10000);
					if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
						Object content = result.getData();
						JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(content));
						JSONArray jsonArray = jsonObj.getJSONArray("content");
						if(CollectionUtils.isNotEmpty(jsonArray)) {
							List<String> makers = Lists.newArrayList();
							jsonArray.stream().forEach( member -> {
								JSONObject memberObj = (JSONObject)member;
								String userCode = memberObj.getString("userCode");
								if(StringUtils.isNotEmpty(userCode)) {
									makers.add(userCode);
								}
							});
							ResponseWrapper taskResult = taskFeign.getPlanIdsByOrgCodeOrMakers(null, makers, taskStatus);
							if(taskResult.isSuccess() && !ObjectUtils.isEmpty(taskResult.getData())) {
								Object taskIdsObj =  taskResult.getData();
								JSONArray arr = JSON.parseArray(JsonUtils.serialize(taskIdsObj));
								arr.stream().forEach( planId -> {
									planIds.add((String)planId);
								});
							}
						}
					}
				}*/
				queryvo.setRwlxIds(new String[] {TaskTypeConstant.RiChangJianCha.getValue(),TaskTypeConstant.ShiJiChuBeiJianCha.getValue()
						,TaskTypeConstant.FangXunJianCha.getValue(),TaskTypeConstant.ZhuanXiangJianCha.getValue(),TaskTypeConstant.ANQUANJianCha.getValue()
						,TaskTypeConstant.ChuBeiLiangGongSi.getValue()
				});
			}
		}
		if(CollectionUtils.isNotEmpty(planIds)) {
			queryvo.setJhIds(planIds.toArray(new String[planIds.size()]));
		}

		return queryvo;
	}

	/**
	 * 编辑检查计划
	 *
	 * @param jcjhvo
	 * @return
	 */
	@ApiOperation(value = "编辑检查计划")
	@PutMapping(value = "/inspectionplan")
	public ResponseWrapper updateInspectionplan(@RequestBody InspectionplanVO jcjhvo) {

		// 获得被检查单位列表
		List<TypesofInspectedUnitsVO> bjdwlxList = jcjhvo.getBjdwlxList();
		if (bjdwlxList != null) {
			for (TypesofInspectedUnitsVO vo : bjdwlxList) {
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
			}
		}

		// 获得文件列表
		List<FileVO> fileList = jcjhvo.getFile();
		if (fileList != null) {
			for (FileVO vo : fileList) {
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
			}
		}

		// 获得表单列表
		List<CheckformVO> jcbdList = jcjhvo.getJcbd();
		if (jcbdList != null) {
			for (CheckformVO vo : jcbdList) {
				vo.setRefreshDate(new Date());
				vo.setRefresher(CurrentUtil.getUserName());
			}
		}

		// 获取检查单位列表
		List<InspectionUnitVO> jcdwList = jcjhvo.getJcdwList();
		if (jcdwList != null) {
			for (InspectionUnitVO vo : jcdwList) {
				vo.setRefreshDate(new Date());
				vo.setCreateor(CurrentUtil.getUserName());
			}
		}

		jcjhvo.setRefreshDate(new Date());
		jcjhvo.setRefresher(CurrentUtil.getUserName());

		return inspectionplanFeign.updateInspectionplan(jcjhvo);

	}

	/**
	 * 查看检查计划
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "查看检查计划")
	@GetMapping(value = "/inspectionplan/{jhId}")
	public ResponseWrapper getInspectionplan(@PathVariable("jhId") String jhId) {

		return inspectionplanFeign.getInspectionplan(jhId);
	}

	/**
	 * 下发计划
	 *
	 * @param jhvo
	 * @return
	 */
	@ApiOperation(value = "下发")
	@PostMapping(value = "/taskInsert")
	public ResponseWrapper taskInsert(@RequestBody InspectionplanVO jhvo) {

	// 封装taskVO
		TaskVO taskVO = new TaskVO();
		// 任务名称
		taskVO.setRwName(jhvo.getJhName());
		// 计划编号
		taskVO.setJhId(jhvo.getJhId());
		// 检查组取得方式（0，指定。1、双随机。2、指定。）
		taskVO.setJczqdfs(jhvo.getBjdwfx());
		//任务类型id
		taskVO.setRwlx(jhvo.getRwlxId());
		// 检查开始时间
		taskVO.setJckssjDate(jhvo.getRwqsr());
		// 检查结束时间
		taskVO.setJcjssjDate(jhvo.getRwjsr());
		// 是否分配检查组 (0,是 1，否)
		taskVO.setSffp(jhvo.getIsBjjcz());
		//任务类型名称
		taskVO.setRwlxName(jhvo.getRwlxmc());

		//被检单位选择方式
		taskVO.setBjdwxzfs(jhvo.getBjdwfx());
		//张琪添加

		taskVO.setCreateDate(DateUtil.getNowDate());
		taskVO.setCreator(CurrentUtil.getUserName());
		taskVO.setCreatorCode(CurrentUtil.getUserId());
		taskVO.setRefresher(CurrentUtil.getUserName());
		taskVO.setRefreshTime(DateUtil.getNowDate());
		taskVO.setRefresherCode(CurrentUtil.getUserId());
		taskVO.setOrgId(CurrentUtil.getOrgId());

		// 获得jcdwList
		List<InspectionUnitVO> jcdwList = jhvo.getJcdwList();
		// 遍历jcdwList
		if(jhvo.getRwlxId().equals("5000150")){//直接下发该状态
			return inspectionplanFeign.updateInspectionplanonly(jhvo);
		}
		if (jcdwList != null) {
			for (InspectionUnitVO inspectionUnitVO : jcdwList) {
				// 检查单位ID
				taskVO.setJcdwId(inspectionUnitVO.getJcdwId());
				// 检查单位名称
				taskVO.setJcdwmc(inspectionUnitVO.getJcdwName());

				try {
					//进taskFeign
					ResponseWrapper inspectionTaskInsert = taskFeign.inspectionTaskInsert(taskVO);
					if(inspectionTaskInsert.getInfoCode()!=200){
						inspectionTaskInsert.setMsg("下发计划失败");
						// 更新计划状态
						return inspectionTaskInsert;
					}
					 if (inspectionUnitVO.getJcdwId().equals(CurrentUtil.getOrgId())) {
		                TaskVO taskInfoAll = inspectionTaskService.getTaskInfoAll(inspectionUnitVO.getJcdwId(), jhvo.getJhId());
		                if(taskInfoAll==null){
		                 inspectionTaskInsert.setMsg("下发任务结果失败");
		                }
		                inspectionTaskService.inspectionTaskResultInsert(taskInfoAll);
					 }


				} catch (Exception e) {
					log.error(e.getMessage());
					return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败", null);
				}
			}
			return inspectionplanFeign.updateInspectionplanonly(jhvo);
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败，不存在检查单位，请选择后在下发", null);
	}


	/**
	 * 撤回计划
	 * @return
	 */
	@DeleteMapping("/inspectionplan/{jhId}")
	@ApiOperation(value = "撤回计划")
	public ResponseWrapper deleteInspectionlan(@PathVariable("jhId") String jhId){
		ResponseWrapper wrapper = inspectionplanFeign.getInspectionplan(jhId);
		if(wrapper.getInfoCode()==200) {
			InspectionplanVO inspectionplanVO = objectMapper.convertValue(wrapper.getData(), InspectionplanVO.class);
			//任务对象初始化
			TaskVO taskVO=new TaskVO();
			taskVO.setJhId(jhId);
			//如果分配了本级检查组
			if(inspectionplanVO.getIsBjjcz() == 0) {
				//任务初始化删除
				taskVO.setJcdwId(inspectionplanVO.getOrgId());
			}
			//结果初始化删除
			DailyCheckResultVO dailyCheckResultVO=new DailyCheckResultVO();
			dailyCheckResultVO.setJhid(jhId);
			ResponseWrapper responseWrapper=dailyCheckResultApi.deleteBackByEntity(dailyCheckResultVO);
			if(responseWrapper.getInfoCode()==200){
				responseWrapper=taskFeign.deleteByEntity(taskVO);
				if(responseWrapper.isSuccess()){
					//计划初始化
					responseWrapper= inspectionplanFeign.deleteInspectionlan(jhId);
					if(responseWrapper.getInfoCode()==200) {
						inspectionplanFeign.backlog(jhId);
					}
				}
			} else {
				return responseWrapper;
			}
		}
		return wrapper;
	}


	/**
	 * 删除计划
	 * @return
	 */
	@PostMapping("/inspectionplan/deleteById")
	@ApiOperation(value = "删除计划")
	public ResponseWrapper deleteById(@RequestBody InspectionplanVO jcjhvo){
		return inspectionplanFeign.deleteById(jcjhvo);
	}


	@ApiOperation(value = "分页查询归档列表")
	@PostMapping("/inspectionplanplace/{pageNum}/{pageSize}")
    public ResponseWrapper inspectionplanplace(@RequestBody InspectionplanQueryVO queryvo,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize) {
		/**
		 * 	制定任务权限划分：
		 * 	1、粮食储备公司只能看类型为(日常检查-储备粮公司)的信息
		 *  2、市局的人只能查看该部门制定的任务，不区分任务类型
		 *  3、区粮办只能看各自制定的任务，不区分任务类型
		 */
		List<String> planIds = Lists.newArrayList();
		boolean isShow = false;
		this.createQueryVO(queryvo, planIds, InspectionConstant.PLAN_AND_TASK_FINISHED_STATUS + "");
		String[] taskType = queryvo.getRwlxIds();
		if(!ObjectUtils.isEmpty(taskType)) {
			isShow = true;
		}
		if(CollectionUtils.isNotEmpty(planIds)) {
			isShow = true;
		}
		if(!isShow) {
			return ResponseWrapper.success(Lists.newArrayList());
		}
		queryvo.setOrgId(CurrentUtil.getOrgId());
		return inspectionplanService.inspectionplanplace(queryvo,pageNum,pageSize);
	}

	/**
     * 查看检查计划
     * @param rwlxbh
     * @return
     */
	@ApiOperation(value = "根据任务类型获取计划列表")
    @GetMapping("/inspectionplanList/{rwlxbh}")
    public ResponseWrapper getInspectionplanList(@PathVariable("rwlxbh") String rwlxbh, @RequestParam(value = "jcsj",required = false) String jcsj) {
		return inspectionplanService.getInspectionplanList(rwlxbh,jcsj);
    }

    /**
     * 根据条件分页获取信息列表
     */
    @ApiOperation(value = "根据计划id进行归档")
    @PutMapping("/inspectionplanplace/{jhId}")
    public ResponseWrapper inspectionplanPlace(@PathVariable(value = "jhId") String  jhId) {
    	return inspectionplanFeign.inspectionplanPlace(jhId);
    }

    /**
     *
     * @Title: inspectionplanMain
     * @Description:方法描述:(这里用一句话描述这个方法的作用)
     * @param @param inspectionplanQueryVo
     * @param @return    设定文件
     * @return ResponseWrapper    返回类型
     * @throws
     */
	@PostMapping("/inspectionplanMain")
	@ApiOperation(value = "获取取信息列表")
	public ResponseWrapper inspectionplanMain(@RequestBody InspectionplanQueryVO inspectionplanQueryVo) {
		return inspectionplanFeign.inspectionplanMain(inspectionplanQueryVo);
	}
}

