package com.unis.inspection.app.plan;

import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.ExcelUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.client.YearPlanFeign;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.YearPlanChartVO;
import com.unis.inspectionplan.common.vo.YearPlanVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
 
@RestController
@Slf4j
@Api(value = "年度计划", tags = "年度计划")
public class YearPlanController {
	
	@Autowired
	private YearPlanFeign yearPlanFeign;
 
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "新增年度计划")
    @PostMapping("/yearplan")
    public ResponseWrapper insertyearplan(@RequestBody YearPlanVO yearPlanVO) {
		return yearPlanFeign.insertyearplan(yearPlanVO);

    }
	
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "修改检查计划")
    @PutMapping("/yearplan")
    public ResponseWrapper updateyearplan(@RequestBody YearPlanVO yearPlanVO) {
		return yearPlanFeign.updateyearplan(yearPlanVO);

    }
	
	
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "撤回检查计划")
    @DeleteMapping("/yearplan")
    public ResponseWrapper deleteyearplan(@RequestBody YearPlanVO yearPlanVO) {
		yearPlanVO.setStatus("2");
		return yearPlanFeign.updateyearplan(yearPlanVO);

    }
	
	
	/**
     * 根据条件分页获取信息列表
     */
    @PostMapping("/yearplan/{pageNum}/{pageSize}")
    public ResponseWrapper getInspectionplanList(@RequestParam(value="jhnf",required = false) String jhnf,
                                                 @RequestParam(value="jhmc",required = false) String jhmc,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize){
    		return yearPlanFeign.getInspectionplanList(jhnf,jhmc, pageNum,pageSize);

    	
    }
    
    /**
     * 根据条件分页获取信息列表
     */
    @PostMapping("/yearplanChat")
    public ResponseWrapper getInspectionplanList(@RequestParam(value="jhnf",required = false) String jhnf, @RequestParam(value="jhmc",required = false) String jhmc){
    		return yearPlanFeign.yearplanChat(jhnf,jhmc);

    	
    }
    
    /**
     * 根据条件分页获取信息列表
     */
    @DeleteMapping("/yearplan/{id}")
    public ResponseWrapper yearplan(@PathVariable(value="id") String id){
    		return yearPlanFeign.yearplan(id);

    	
    }
    
    
    /**
     * 根据条件分页获取信息列表
     * @throws Exception 
     */
    @ApiOperation(value = "导出年度计划")
    @PostMapping("/yearplanexport")
    public ResponseWrapper yearplanexport(@RequestParam(value="jhnf",required = false) String jhnf,
                                          @RequestParam(value="jhmc",required = false) String jhmc,
    		   HttpServletResponse response) throws Exception{
    	
    	ResponseWrapper inspectionResultExport = yearPlanFeign.getInspectionplanList(jhnf,jhmc,1,1000);
    	LinkedHashMap pageInfoMap = (LinkedHashMap) inspectionResultExport.getData();
        List<LinkedHashMap> items = (List<LinkedHashMap>) pageInfoMap.get("yearPlanlist");
        for(LinkedHashMap hashMap:items) {
        	String dwmc = "";
        	List<LinkedHashMap> list = (List<LinkedHashMap>) hashMap.get("jcdwList");
        	for(LinkedHashMap map:list) {
        		dwmc += map.get("jcdwmc")+",";
        	}
        	hashMap.put("dwmc", dwmc);
        }
        LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
        columnName.put("jhnf","计划年份");
        columnName.put("jhmc","计划名称");
        columnName.put("jhnr","计划内容");
        columnName.put("dwmc","检查单位");
        columnName.put("jhkssj","计划开始月");
        columnName.put("jhjssj","计划结束月");
        //输出Excel文件
        ServletOutputStream output = response.getOutputStream();
        response.reset();
        response.setHeader("content-disposition","attachment;filename=" + new String((jhnf).getBytes("gb2312"), "ISO8859-1") + ".xls");
        response.setContentType("application/msexcel");
        ExcelUtil.pojo2Excel(items,output,columnName,jhnf+"年度计划");
        output.close();
        return null;
    }
}