package com.unis.inspection.app.result;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.client.DataDictionaryFeign;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspectionresult.client.CheckCensusFeign;
import com.unis.inspectionresult.common.vo.CheckCensusQueryVO;
import com.unis.inspectionresult.common.vo.CheckCensusVO;
import com.unis.inspectionresult.common.vo.CheckOrgVO;
import com.unis.inspectionresult.common.vo.CheckSecurityVO;
import com.unis.inspectiontask.client.CheckPersonFeign;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.OutputStream;
import java.util.*;
import java.util.Map.Entry;

@RestController
@Slf4j
@Api(value = "检查数据统计", tags = "检查数据统计")
public class CheckCensusController {

	@Autowired
	private CheckCensusFeign checkCensusFeign;
	
	@Autowired
	private MyUserClient myuserClient;
	
	@Autowired
	private CheckPersonFeign checkPersonFeign;
	
	 private ObjectMapper objectMapper = new ObjectMapper();
	 
	 
	 @Autowired
	 private DataDictionaryFeign dataDictionaryFeign;

	/**
	 * 新增检查指标
	 * @return
	 */
	@ApiOperation(value = "检查统计", notes = "储备粮与监督检查字段区分")
	@PostMapping("/checkcensus")
	public ResponseWrapper checkcensus(@RequestBody CheckCensusQueryVO checkCensusQueryVO) {
		ResponseWrapper responseWrapper = null;
		try {
			List<CheckCensusVO> checkCensusVOs = new ArrayList<CheckCensusVO>();
			List<CheckOrgVO> checkOrgVOs = new ArrayList<CheckOrgVO>();
			responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				CheckOrgVO checkOrgVO = new CheckOrgVO();
				checkOrgVO.setDwDm(jsonObject.getStr("orgCode"));
				checkOrgVO.setDwMc(jsonObject.getStr("orgName"));
				checkOrgVOs.add(checkOrgVO);
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					CheckOrgVO checkOrg2O = new CheckOrgVO();
					checkOrg2O.setDwDm(obj.getStr("orgCode"));
					checkOrg2O.setDwMc(obj.getStr("orgName"));
					checkOrgVOs.add(checkOrg2O);
				}
			} else {
				CheckOrgVO checkOrgVO = new CheckOrgVO();
				checkOrgVO.setDwDm(jsonObject.getStr("orgCode"));
				checkOrgVO.setDwMc(jsonObject.getStr("orgName"));
				checkOrgVOs.add(checkOrgVO);
			}
			checkCensusQueryVO.setOrgVOs(checkOrgVOs);
			checkCensusQueryVO.setDwDm(CurrentUtil.getOrgId());
			//获取基本的检查情况
			responseWrapper = checkCensusFeign.checkcensus(checkCensusQueryVO);
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
			}
			ResponseWrapper jcrw =  checkCensusFeign.checkcensusrwid(checkCensusQueryVO);
			if(jcrw.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询检查人次失败", null);
			}
			JSONArray array = JSONUtil.parseArray(jcrw.getData());
			String[] rwids = new String[array.size()];
			for(int i =0 ;i<array.size();i++) {
//				JSONObject jsonObject2 = array.getJSONObject(i);
				System.out.println(array.get(i));
				rwids[i] = JSONUtil.toJsonStr(array.get(i));
			}
			checkCensusQueryVO.setRwids(rwids);
			com.unis.inspectiontask.common.vo.CheckCensusQueryVO checkCensusQueryVO2 = new com.unis.inspectiontask.common.vo.CheckCensusQueryVO();
			LsBeanUtils.copyAllProperties(checkCensusQueryVO, checkCensusQueryVO2);
			ResponseWrapper responseWrapper2 = checkPersonFeign.checkcensus(checkCensusQueryVO2);
			if(responseWrapper2.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
			}
			
			JSONArray jsonArray = JSONUtil.parseArray(responseWrapper.getData());
			
			JSONArray jsonArray2 = JSONUtil.parseArray(responseWrapper2.getData());
			for(int i = 0; i< jsonArray.size();i++) {
				CheckCensusVO object = objectMapper.convertValue(jsonArray.getJSONObject(i), CheckCensusVO.class);
				JSONObject object2 = jsonArray2.getJSONObject(i);
				object.setRcjcrc(object2.getInt("rcjcrc"));
				object.setFxjcrc(object2.getInt("fxjcrc"));
				object.setZxjcrc(object2.getInt("zxjcrc"));
				checkCensusVOs.add(object);
			}
			return ResponseWrapper.success(checkCensusVOs);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
		}
	}
	
	
	
	@ApiOperation(value = "导出检查统计", notes = "储备粮与监督检查字段区分")
	@PostMapping("/export")
	public ResponseWrapper export(@RequestBody CheckCensusQueryVO checkCensusQueryVO, HttpServletRequest request,
			HttpServletResponse response) {
		ResponseWrapper responseWrapper = null;
		try {
			List<CheckCensusVO> checkCensusVOs = new ArrayList<CheckCensusVO>();
			List<CheckOrgVO> checkOrgVOs = new ArrayList<CheckOrgVO>();
			responseWrapper = myuserClient.findBySectionChief(CurrentUtil.getOrgId());
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询组织列表失败", null);
			}
			//获取需要查询的组织
			JSONObject jsonObject = JSONUtil.parseObj(responseWrapper.getData()) ;
			if(CurrentUtil.getOrgId().equals("LS001")) {
				CheckOrgVO checkOrgVO = new CheckOrgVO();
				checkOrgVO.setDwDm(jsonObject.getStr("orgCode"));
				checkOrgVO.setDwMc(jsonObject.getStr("orgName"));
				checkOrgVOs.add(checkOrgVO);
				JSONArray array = jsonObject.getJSONArray("children");
				for(int i=0;i<16;i++) {
					JSONObject obj = array.getJSONObject(i);
					CheckOrgVO checkOrg2O = new CheckOrgVO();
					checkOrg2O.setDwDm(obj.getStr("orgCode"));
					checkOrg2O.setDwMc(obj.getStr("orgName"));
					checkOrgVOs.add(checkOrg2O);
				}
			} else {
				CheckOrgVO checkOrgVO = new CheckOrgVO();
				checkOrgVO.setDwDm(jsonObject.getStr("orgCode"));
				checkOrgVO.setDwMc(jsonObject.getStr("orgName"));
				checkOrgVOs.add(checkOrgVO);
			}
			checkCensusQueryVO.setOrgVOs(checkOrgVOs);
			checkCensusQueryVO.setDwDm(CurrentUtil.getOrgId());
			//获取基本的检查情况
			responseWrapper = checkCensusFeign.checkcensus(checkCensusQueryVO);
			if(responseWrapper.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
			}
			ResponseWrapper jcrw =  checkCensusFeign.checkcensusrwid(checkCensusQueryVO);
			if(jcrw.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询检查人次失败", null);
			}
			JSONArray array = JSONUtil.parseArray(jcrw.getData());
			String[] rwids = new String[array.size()];
			for(int i =0 ;i<array.size();i++) {
//				JSONObject jsonObject2 = array.getJSONObject(i);
				System.out.println(array.get(i));
				rwids[i] = JSONUtil.toJsonStr(array.get(i));
			}
			checkCensusQueryVO.setRwids(rwids);
			com.unis.inspectiontask.common.vo.CheckCensusQueryVO checkCensusQueryVO2 = new com.unis.inspectiontask.common.vo.CheckCensusQueryVO();
			LsBeanUtils.copyAllProperties(checkCensusQueryVO, checkCensusQueryVO2);
			ResponseWrapper responseWrapper2 = checkPersonFeign.checkcensus(checkCensusQueryVO2);
			if(responseWrapper2.getInfoCode()!=200) {
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
			}
			
			JSONArray jsonArray = JSONUtil.parseArray(responseWrapper.getData());
			
			JSONArray jsonArray2 = JSONUtil.parseArray(responseWrapper2.getData());
			for(int i = 0; i< jsonArray.size();i++) {
				CheckCensusVO object = objectMapper.convertValue(jsonArray.getJSONObject(i), CheckCensusVO.class);
				JSONObject object2 = jsonArray2.getJSONObject(i);
				object.setRcjcrc(object2.getInt("rcjcrc"));
				object.setFxjcrc(object2.getInt("fxjcrc"));
				object.setZxjcrc(object2.getInt("zxjcrc"));
				checkCensusVOs.add(object);
			}
			if(CurrentUtil.getDeptName().contains("监督")) {
				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("dwMc", "  ");
				columnName.put("rcjcqygs", "检查企业个次");
				columnName.put("rcjcrc", "检查人次");
				columnName.put("rckzjccs", "开展检查次数");
				columnName.put("rcywc", "已完成");
				columnName.put("rcwwc", "超期完成");
				// 输出Excel文件
				ServletOutputStream output = response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition", "attachment;filename="
						+ new String((DateUtil.getDate()+"检查情况统计表").getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				pojo2Excel(checkCensusVOs, output, columnName, "日常检查");
				output.close();
				return null;
			} else {
				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("dwMc", "  ");
				columnName.put("fxjcqygs", "检查企业个次");
				columnName.put("fxjcrc", "检查人次");
				columnName.put("fxkzjccs", "开展检查次数");
				columnName.put("fxywc", "已完成");
				columnName.put("fxwwc", "超期完成");
				
				columnName.put("zxjcqygs", "检查企业个次");
				columnName.put("zxjcrc", "检查人次");
				columnName.put("zxkzjccs", "开展检查次数");
				columnName.put("zxywc", "已完成");
				columnName.put("zxwwc", "超期完成");
				// 输出Excel文件
				ServletOutputStream output = response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition", "attachment;filename="
						+ new String((DateUtil.getDate()+"检查情况统计表").getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				pojo3Excel(checkCensusVOs, output, columnName, "防汛检查","专项检查");
				output.close();
				return null;
			}
			
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
		}
	}
	
	
	
	/**
	 * 新增检查指标
	 * @param jczbvo
	 * @return
	 */
	@ApiOperation(value = "安全生产检查统计")
	@PostMapping("/checksecurity")
	public ResponseWrapper checksecurity(@RequestBody CheckCensusQueryVO checkCensusQueryVO) {
		ResponseWrapper responseWrapper = dataDictionaryFeign.findByGroupId("JCLB");
		if(responseWrapper.getInfoCode()!=200) {
			return responseWrapper;
		}
		if(responseWrapper.getData()==null) {
			return ResponseWrapper.error("获取检查类型失败");
		}
		JSONArray array = JSONUtil.parseArray(responseWrapper.getData());
		String[] strings = new String[array.size()];
		for(int i=0;i<array.size();i++) {
			strings[i] = array.getJSONObject(i).getStr("dictName");
		}
		checkCensusQueryVO.setRwids(strings);
		checkCensusQueryVO.setOrgId(CurrentUtil.getOrgId());
		return checkCensusFeign.checksecurity(checkCensusQueryVO);
	}
	
	
	
	@ApiOperation(value = "安全生产检查统计导出")
	@PostMapping("/checksecurityExport")
	public ResponseWrapper checksecurityExport(@RequestBody CheckCensusQueryVO checkCensusQueryVO, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		ResponseWrapper responseWrapper = dataDictionaryFeign.findByGroupId("JCLB");
		if(responseWrapper.getInfoCode()!=200) {
			return responseWrapper;
		}
		if(responseWrapper.getData()==null) {
			return ResponseWrapper.error("获取检查类型失败");
		}
		JSONArray array = JSONUtil.parseArray(responseWrapper.getData());
		String[] strings = new String[array.size()];
		for(int i=0;i<array.size();i++) {
			strings[i] = array.getJSONObject(i).getStr("dictName");
		}
		checkCensusQueryVO.setRwids(strings);
		checkCensusQueryVO.setOrgId(CurrentUtil.getOrgId());
		responseWrapper = checkCensusFeign.checksecurity(checkCensusQueryVO);
		if(responseWrapper.getInfoCode()!=200) {
			return ResponseWrapper.error("获取安全生产统计失败");
		}
		JSONArray jsonArray = JSONUtil.parseArray(responseWrapper.getData());
		List<CheckSecurityVO> checkSecurityVOs = new ArrayList<CheckSecurityVO>();
		for(int i=0;i<jsonArray.size();i++) {
			checkSecurityVOs.add(objectMapper.convertValue(jsonArray.getJSONObject(i), CheckSecurityVO.class));
		}
		
		LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
		columnName.put("jczxMc", "  ");
		columnName.put("jcqygs", "检查企业个次");
		columnName.put("jcrc", "检查人次");
		columnName.put("kzjccs", "开展检查次数");
		columnName.put("rcywc", "已完成");
		columnName.put("rcwwc", "未完成");
		
		columnName.put("xczg", "现场整改");
		columnName.put("xqzg", "限期整改");
		columnName.put("wxzg", "无需整改");
		columnName.put("xcjc", "现场检查");
		columnName.put("ycjc", "远程检查");
		
		
		// 输出Excel文件
		ServletOutputStream output = response.getOutputStream();
		response.reset();
		response.setHeader("content-disposition", "attachment;filename="
				+ new String((DateUtil.getDate()+"安全生产检查情况统计表").getBytes("gb2312"), "ISO8859-1") + ".xls");
		response.setContentType("application/msexcel");
		pojo3Excel(checkSecurityVOs, output, columnName, CurrentUtil.getOrgName(),"时间：" + DateUtil.getDate());
		output.close();
		return null;
	}
	
	
	
	
	public static <T> void pojo3Excel(List<T> pojoList, OutputStream out, LinkedHashMap<String, String> alias,
			String headLine,String headLine2) throws Exception {
		// 创建一个工作簿
		HSSFWorkbook wb = new HSSFWorkbook();
		// 创建一个表
		HSSFSheet sheet = wb.createSheet();
		// 创建第一行，作为表名
		HSSFRow row = sheet.createRow(0);
		HSSFCell cell = row.createCell(0);
		cell.setCellValue(headLine);
		HSSFCell cell2 = row.createCell(6);
		cell2.setCellValue(headLine2);
		sheet.addMergedRegion(new CellRangeAddress(0, 0, 1, 5));
		sheet.addMergedRegion(new CellRangeAddress(0, 0, 6, 10));

		// 在第一行插入列名
		insertColumnName(1, sheet, alias);
		// *从第2行开始插入数据
		insertColumnDate(2, pojoList, sheet, alias);
		// 输出表格文件
		try {
			wb.write(out);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			wb.close();
		}
	}
	
	
	
	public static <T> void pojo2Excel(List<T> pojoList, OutputStream out, LinkedHashMap<String, String> alias,
			String headLine) throws Exception {
		// 创建一个工作簿
		HSSFWorkbook wb = new HSSFWorkbook();
		// 创建一个表
		HSSFSheet sheet = wb.createSheet();
		// 创建第一行，作为表名
		HSSFRow row = sheet.createRow(0);
		HSSFCell cell = row.createCell(0);
		cell.setCellValue(headLine);

		sheet.addMergedRegion(new CellRangeAddress(0, 0, 0, 5));

		// 在第一行插入列名
		insertColumnName(1, sheet, alias);

		// *从第2行开始插入数据
		insertColumnDate(2, pojoList, sheet, alias);

		// 输出表格文件
		try {
			wb.write(out);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			wb.close();
		}
	}
	
	private static void insertColumnName(int rowNum, HSSFSheet sheet, Map<String, String> alias) {
		HSSFRow row = sheet.createRow(rowNum);
		// 列的数量
		int columnCount = 0;

		Set<Entry<String, String>> entrySet = alias.entrySet();

		for (Entry<String, String> entry : entrySet) {
			// 创建第一行的第columnCount个格子
			HSSFCell cell = row.createCell(columnCount++);
			// 将此格子的值设置为alias中的键名
			cell.setCellValue(isNull(entry.getValue()).toString());
		}
	}
	
	private static Object isNull(Object object) {
		if (object != null) {
			return object;
		} else {
			return "0";
		}
	}


	/**
	 * 从指定行开始插入数据
	 * 
	 * @param beginRowNum
	 *            开始行
	 * @param models
	 *            对象数组
	 * @param sheet
	 *            表
	 * @param alias
	 *            列别名
	 * @throws Exception
	 */
	private static <T> void insertColumnDate(int beginRowNum, List<T> models, HSSFSheet sheet,
			Map<String, String> alias) throws Exception {
		for (T model : models) {
			// 创建新的一行
			HSSFRow rowTemp = sheet.createRow(beginRowNum++);

			// 获取列的迭代
			Set<Entry<String, String>> entrySet = alias.entrySet();

			// 从第0个格子开始创建
			int columnNum = 0;
			for (Entry<String, String> entry : entrySet) {
				// 获取属性值
				String property = BeanUtils.getProperty(model, entry.getKey());
				// 创建一个格子
				HSSFCell cell = rowTemp.createCell(columnNum++);
				cell.setCellValue(property);
			}
		}
	}


}
