package com.unis.inspection.app.result;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.service.CheckWorkLogService;
import com.unis.inspectionresult.client.CheckWorkLogFeign;
import com.unis.inspectionresult.common.vo.CheckWorkLogQueryVO;
import com.unis.inspectionresult.common.vo.CheckWorkLogVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;

/**
 * @author WangZL
 * @version 1.0
 * @Title CheckWorkLogController
 * @ProjectName 检查工作日志信息 CheckWorkLogController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "检查工作日志 ", tags = "检查工作日志")
@Slf4j
public class CheckWorkLogController {

	@Autowired
	private CheckWorkLogFeign checkWorkLogFeign;
	@Autowired
	private CheckWorkLogService checkWorkLogService;

	@ApiOperation(value = "检查工作日志-查询列表", notes = "参数：检查开始时间，检查结束时间，被检企业编号")
	@PostMapping(value = "/checkWorkLogList")
    public ResponseWrapper getCheckWorkLogList(@RequestBody CheckWorkLogQueryVO checkWorkLogQueryVO){
        return checkWorkLogFeign.getCheckWorkLogList(checkWorkLogQueryVO);
    }

	@ApiOperation(value = "检查工作日志-分页查询列表", notes = "参数：检查开始时间，检查结束时间，被检企业编号")
	@PostMapping(value = "/checkWorkLogPage/{pageNum}/{pageSize}")
    public ResponseWrapper getCheckWorkLogPage(@RequestBody CheckWorkLogQueryVO checkWorkLogQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
        return checkWorkLogFeign.getCheckWorkLogPage(checkWorkLogQueryVO,pageNum,pageSize);
    }

	@PostMapping(value = "/checkWorkLog")
	@ApiOperation(value = "检查工作日志-新增", notes = "参数：检查工作日志信息对象 model")
    public ResponseWrapper insert(@RequestBody CheckWorkLogVO checkWorkLogVO) {
	    checkWorkLogVO.setCreateor(CurrentUtil.getUserName());
	    checkWorkLogVO.setCreateDate(new Date());
	    checkWorkLogVO.setStatus(1);
        return checkWorkLogFeign.insert(checkWorkLogVO);
    }

	@PutMapping(value = "/checkWorkLog")
	@ApiOperation(value = "检查工作日志-更新", notes = "参数：检查工作日志信息对象 model")
    public ResponseWrapper update(@RequestBody CheckWorkLogVO checkWorkLogVO) {
	    checkWorkLogVO.setRefresher(CurrentUtil.getUserName());
        return checkWorkLogFeign.update(checkWorkLogVO);
    }

	@DeleteMapping(value="/checkWorkLog/{id}")
	@ApiOperation(value = "检查工作日志-删除", notes = "参数：日志ID")
	public ResponseWrapper delete(@PathVariable("id") Integer id) {
        return checkWorkLogFeign.delete(id);
    }

	@GetMapping(value="/checkWorkLog/{id}")
	@ApiOperation(value = "检查工作日志-查询详情", notes = "参数：日志ID")
	public ResponseWrapper getCheckWorkLogInfoById(@PathVariable("id") Integer id) {
        return checkWorkLogFeign.getCheckWorkLogInfoById(id);
    }

    @PostMapping(value = "/checkWorkLogExport")
	@ApiOperation(value = "检查工作日志-导出", notes = "参数：列表条件查询字段")
	public ResponseWrapper getCheckWorkLogExport(@RequestBody CheckWorkLogQueryVO checkWorkLogQueryVO, HttpServletResponse response){
		return checkWorkLogService.getCheckWorkLogExport(checkWorkLogQueryVO,response);
	}
}
