package com.unis.inspection.app.result;

import java.util.Date;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.client.FormfieldsFeign;
import com.unis.inspectionresult.common.vo.FormfieldsVO;
import com.unis.inspectionresult.common.vo.FormfieldsqueryVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "表单信息", tags = "表单信息")
public class FormfieldsController {

	@Autowired
	private FormfieldsFeign formfieldsFeign;

	/**
	 * 新增表单信息
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "新增表单信息", notes = "参数：表单信息实体信息")
	@PostMapping(value = "/formfields")
	public ResponseWrapper insert(@RequestBody FormfieldsVO vo) {
		vo.setCreateDate(new Date());
		vo.setRefreshDate(new Date());
		vo.setStatus(1);
		vo.setCreateor(CurrentUtil.getUserName());
		vo.setRefresher(CurrentUtil.getUserName());

		return formfieldsFeign.insertFormfields(vo);
	}

	/**
	 * 根据条件分页获取信息列表
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件分页获取信息列表")
	@PostMapping(value = "/formfieldsList")
	public ResponseWrapper getInspectionplanList(@RequestBody FormfieldsqueryVO queryvo,
			@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
			@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum) {

		return formfieldsFeign.getInspectionfieldsList(queryvo, pageSize, pageNum);
	}
	
	
	/**
	 * 根据条件获取信息列表
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件获取信息列表")
	@PostMapping(value = "/formfieldsforList")
	public ResponseWrapper getInspectionplanforList(@RequestBody FormfieldsqueryVO queryvo) {

		return formfieldsFeign.getInspectionforfieldsList(queryvo);
	}

	/**
	 * 编辑表单信息
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "编辑表单信息")
	@PutMapping(value = "/formfields")
	public ResponseWrapper updateInspectionplan(@RequestBody FormfieldsVO vo) {
		
		vo.setRefreshDate(new Date());
		vo.setCreateor(CurrentUtil.getUserName());

		return formfieldsFeign.updateFormfields(vo);
	}

	/**
	 * 查看表单信息
	 * @param bdId
	 * @return
	 */
	@ApiOperation(value = "查看表单信息")
	@GetMapping(value = "/formfields/{bdId}")
	public ResponseWrapper getInspectionplan(@PathVariable("bdId") String bdId) {

		return formfieldsFeign.getFormfields(bdId);
	}

}
