package com.unis.inspection.app.result;

import java.util.Date;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.client.InspectionIndicatorsFeign;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsVO;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsqueryVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "检查指标", tags = "检查指标")
public class InspectionIndicatorController {

	@Autowired
	private InspectionIndicatorsFeign indicatorsFeign;

	/**
	 * 新增检查指标
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "新增检查指标", notes = "参数：检查指标实体信息")
	@PostMapping(value = "/indicators")
	public ResponseWrapper insert(@RequestBody InspectionIndicatorsVO vo) {
		vo.setCreateDate(new Date());
		vo.setRefreshDate(new Date());
		vo.setStatus(1);
		vo.setCreateor(CurrentUtil.getUserName());
		vo.setRefresher(CurrentUtil.getUserName());

		return indicatorsFeign.insertInspectionresult(vo);
	}

	/**
	 * 根据条件分页获取信息列表
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件分页获取信息列表")
	@PostMapping(value = "/indicatorsList")
	public ResponseWrapper getIndicatorsList(@RequestBody InspectionIndicatorsqueryVO queryvo,
			@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
			@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum) {

		return indicatorsFeign.getInspectionresultList(queryvo, pageSize, pageNum);
	}
	
	

	/**
	 * 编辑检查指标
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "编辑检查指标")
	@PutMapping(value = "/indicators")
	public ResponseWrapper updateIndicators(@RequestBody InspectionIndicatorsVO vo) {
		
		vo.setRefreshDate(new Date());
		vo.setCreateor(CurrentUtil.getUserName());

		return indicatorsFeign.updateInspectionresult(vo);
	}

	/**
	 * 查看检查指标
	 * @return
	 */
	@ApiOperation(value = "查看检查指标")
	@GetMapping(value = "/indicators/{zbId}")
	public ResponseWrapper getIndicators(@PathVariable("zbId") String zbId) {

		return indicatorsFeign.getInspectionresult(zbId);
	}

}
