package com.unis.inspection.app.result;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import com.alibaba.excel.write.style.column.LongestMatchColumnWidthStyleStrategy;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.client.TrcjczbFeign;
import com.unis.inspectionresult.common.vo.DCfxxsjyVO;
import com.unis.inspectionresult.common.vo.Jcdwtjb;
import com.unis.inspectionresult.common.vo.Qyjsjctjb;
import com.unis.inspectionresult.common.vo.TrcjczbVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;

/**
 * @Classname TrcjczbController
 * @Description 日常检查主表控制层
 * @Date 2023/11/20 13:54
 * @Created by rising123sun
 */
@RestController
@Slf4j
@Api(value = "日常检查", tags = "日常检查")
public class TrcjczbController {

    @Resource
    private TrcjczbFeign trcjczbFeign;

    // 分页列表查询
    @ApiOperation(value = "分页列表查询", notes = "分页列表查询")
    @PostMapping("/trcjc/queryPageList")
    public ResponseWrapper queryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                         @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                         @RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.queryPageList(pageSize, pageNum, trcjczbVO);
    }

    // 日常检查新增
    @PostMapping("/trcjc/add")
    @ApiOperation(value = "日常检查新增", notes = "日常检查新增")
    public ResponseWrapper add(@RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.add(trcjczbVO);
    }

    // 日常检查修改
    @PostMapping("/trcjc/update")
    @ApiOperation(value = "日常检查修改", notes = "日常检查修改")
    public ResponseWrapper update(@RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.update(trcjczbVO);
    }

    // 日常检查删除
    @DeleteMapping("/trcjc/delete/{id}")
    @ApiOperation(value = "日常检查删除", notes = "日常检查删除")
    public ResponseWrapper delete(@PathVariable String id) {
        return trcjczbFeign.delete(id);
    }

    /**
     * @param dCfxxsjyVO 库点代码
     * @return 仓房信息列表
     * @author WangZL, wangruimin
     * @Description 根据库点代码获取仓房列表
     * @version V2
     */
    @ApiOperation(value = "仓房信息-根据库点代码获取仓房列表", notes = "参数：库点代码")
    @PostMapping(value = "/trcjc/warehouse/selectByEntity")
    public ResponseWrapper selectByEntity(@RequestBody DCfxxsjyVO dCfxxsjyVO) {
        return trcjczbFeign.selectByEntity(dCfxxsjyVO);
    }

    // 企业接受检查统计表分页列表查询
    @ApiOperation(value = "企业接受检查统计表分页列表查询", notes = "企业接受检查统计表分页列表查询")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageList")
    public ResponseWrapper qyjsjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                               @RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.qyjsjcQueryPageList(pageSize, pageNum, trcjczbVO);
    }

    // 检查单位统计表分页列表查询
    @ApiOperation(value = "检查单位统计表分页列表查询", notes = "检查单位统计表分页列表查询")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageList")
    public ResponseWrapper jcdwjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                               @RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.jcdwjcQueryPageList(pageSize, pageNum, trcjczbVO);
    }

    // 企业接受检查统计表报表导出
    @ApiOperation(value = "企业接受检查统计表报表导出", notes = "企业接受检查统计表报表导出")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageListForDc")
    public ResponseWrapper qyjsjcQueryPageListForDc(HttpServletResponse response,
                                                    @RequestBody TrcjczbVO trcjczbVO) {
        try {
            ResponseWrapper responseWrapper = trcjczbFeign.qyjsjcQueryPageListForDc(trcjczbVO);
            List<LinkedHashMap> rawList = (List<LinkedHashMap>) responseWrapper.getData();
            ObjectMapper mapper = new ObjectMapper();
            List<Qyjsjctjb> dataList = new ArrayList<>();
            for (LinkedHashMap linkedHashMap : rawList) {
                Qyjsjctjb obj = mapper.convertValue(linkedHashMap, Qyjsjctjb.class);
                dataList.add(obj);
            }
            // 设置响应类型和编码
            response.setContentType("application/vnd.ms-excel");
            response.setCharacterEncoding("utf-8");
            // 设置响应头，防止中文乱码
            String fileName = "企业接受检查统计表";
            try {
                fileName = URLEncoder.encode(fileName, "UTF-8");
                response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
            } catch (Exception e) {
                e.printStackTrace();
            }
            // 设置单元格样式策略，居中对齐
            WriteCellStyle cellStyle = new WriteCellStyle();
            cellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);

            HorizontalCellStyleStrategy horizontalCellStyleStrategy = new HorizontalCellStyleStrategy(cellStyle, cellStyle);
            // 使用EasyExcel的write方法，指定输出流和数据类
            EasyExcel.write(response.getOutputStream(), Qyjsjctjb.class)
                    .registerWriteHandler(new LongestMatchColumnWidthStyleStrategy())
                    .registerWriteHandler(horizontalCellStyleStrategy)
                    // 调用sheet方法，设置表格的名称和头部样式
                    .sheet("企业接受检查统计表")
                    // 调用doWrite方法，传入数据列表
                    .doWrite(dataList);

            return ResponseWrapper.success("导出成功");
        } catch (Exception e) {
            log.error("导出失败", e);
            return ResponseWrapper.error("导出失败");
        }

    }

    // 检查单位统计表报表导出
    @ApiOperation(value = "检查单位统计表报表导出", notes = "检查单位统计表报表导出")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageListForDc")
    public ResponseWrapper jcdwjcQueryPageListForDc(HttpServletResponse response,
                                                    @RequestBody TrcjczbVO trcjczbVO) {
        try {
            ResponseWrapper responseWrapper = trcjczbFeign.jcdwjcQueryPageListForDc(trcjczbVO);
            List<LinkedHashMap> rawList = (List<LinkedHashMap>) responseWrapper.getData();
            ObjectMapper mapper = new ObjectMapper();
            List<Jcdwtjb> dataList = new ArrayList<>();
            for (LinkedHashMap linkedHashMap : rawList) {
                Jcdwtjb obj = mapper.convertValue(linkedHashMap, Jcdwtjb.class);
                dataList.add(obj);
            }
            // 设置响应类型和编码
            response.setContentType("application/vnd.ms-excel");
            response.setCharacterEncoding("utf-8");
            // 设置响应头，防止中文乱码
            String fileName = "检查单位统计表";
            try {
                fileName = URLEncoder.encode(fileName, "UTF-8");
                response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
            } catch (Exception e) {
                e.printStackTrace();
            }
            // 设置单元格样式策略，居中对齐
            WriteCellStyle cellStyle = new WriteCellStyle();
            cellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);

            HorizontalCellStyleStrategy horizontalCellStyleStrategy = new HorizontalCellStyleStrategy(cellStyle, cellStyle);
            // 使用EasyExcel的write方法，指定输出流和数据类
            EasyExcel.write(response.getOutputStream(), Jcdwtjb.class)
                    .registerWriteHandler(new LongestMatchColumnWidthStyleStrategy())
                    .registerWriteHandler(horizontalCellStyleStrategy)
                    // 调用sheet方法，设置表格的名称和头部样式
                    .sheet("检查单位统计表")
                    // 调用doWrite方法，传入数据列表
                    .doWrite(dataList);

            return ResponseWrapper.success("导出成功");
        } catch (Exception e) {
            log.error("导出失败", e);
            return ResponseWrapper.error("导出失败");
        }

    }

    @ApiOperation(value = "根据被检企业名称，年份以及仓房编码查询相关检查时间", notes = "根据被检企业名称，年份以及仓房编码查询相关检查时间")
    @PostMapping("/trcjcshqk/queryJcsjByBjdwmcAndYearAndCfbm")
    public ResponseWrapper queryJcsjByBjdwmcAndYearAndCfbm(@RequestBody TrcjczbVO trcjczbVO) {
        return trcjczbFeign.queryJcsjByBjdwmcAndYearAndCfbm(trcjczbVO);
    }

    // 详情查询
    @ApiOperation(value = "详情查询", notes = "详情查询")
    @GetMapping("/trcjc/queryDetail/{id}")
    public ResponseWrapper queryDetail(@PathVariable String id) {
        return trcjczbFeign.queryDetail(id);
    }

}
