package com.unis.inspection.app.task;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.service.InspectionGroupService;
import com.unis.inspectiontask.client.EvasionFeign;
import com.unis.inspectiontask.client.TeamFeign;
import com.unis.inspectiontask.common.vo.DesignatedQueryVO;
import com.unis.inspectiontask.common.vo.RandomQueryVO;
import com.unis.inspectiontask.common.vo.TaskVO;
import com.unis.inspectiontask.common.vo.TeamVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;

/** 
 * @ClassName: InspectionGroupController 
 * @Description: 检查组信息管理Controller 
 * @author LiuFeng 
 * @date 2019年8月26日 上午10:26:11  
 */
@RestController
@Slf4j
@Api(value = "检查组管理", tags = "检查组管理")
public class InspectionGroupController {

	@Autowired
	private EvasionFeign evasionFeign;
	
	@Autowired
	private InspectionGroupService inspectionGroupService;
	
	@Autowired
	private TeamFeign teamFeign;
	
	@ApiOperation(value = "检查组双随机抽取")
	@PostMapping(value = "/doubleRandom")
	public ResponseWrapper doubleRandom(@RequestBody RandomQueryVO randomQueryVO) {
		try {
			return inspectionGroupService.getDoubleRandom(randomQueryVO);
		}catch (Exception e) {
			e.printStackTrace();
            log.error(e.getMessage());
		}
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");

	}
	
	@ApiOperation(value = "检查组被检单位指定抽取")
	@PostMapping(value = "/designated")
	public ResponseWrapper designated(@RequestBody List<DesignatedQueryVO> designatedQueryVOs) {
		try {
			return inspectionGroupService.getDesignated(designatedQueryVOs);
		}catch (Exception e) {
			e.printStackTrace();
            log.error(e.getMessage());
		}
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");

	}
	
	@ApiOperation(value = "检查组信息保存")
	@PostMapping(value = "/inspectionTeams")
	public ResponseWrapper inspectionTeams(@RequestBody List<TeamVO> teamVOs) {
		return inspectionGroupService.saveInspectionTeams(teamVOs);
	}

	/**
	 * 
	 * @Title: saveInspectionTeams 
	 * @Description: 制定任务检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "制定任务检查组信息暂存/下发", notes = "参数：")
    @PostMapping(value = "/saveInspectionPlanTeams")
    public ResponseWrapper saveInspectionPlanTeams(@RequestBody List<TeamVO> teamVOs){
		return inspectionGroupService.saveInspectionPlanTeams(teamVOs);
	}
	
	
	@ApiOperation(value = "检查组信息修改", notes = "参数：检查组VO")
    @PutMapping(value = "/inspectionTeams")
    public ResponseWrapper updateInspectionTeams(@RequestBody List<TeamVO> teamVOs) {
		
		return inspectionGroupService.updateInspectionTeams(teamVOs);
	}
	
	@ApiOperation(value = "根据任务编号查询检查组信息", notes = "参数：任务编号")
    @GetMapping(value = "/inspectionTeamList/{taskId}")
	public ResponseWrapper inspectionTeamList(@PathVariable(value="taskId")String taskId) {
		return inspectionGroupService.getInspectionTeamList(taskId);
	}
	

	@ApiOperation(value = "根据用户ID查询被检单位", notes = "参数：用户id")
    @GetMapping(value = "/inspectionUnit/{userId}")
    public ResponseWrapper getInspectionUnit(@PathVariable(value="userId")String userId) {
		return inspectionGroupService.getInspectionUnit(userId);
	}
	
	@ApiOperation(value = "根据用户编号查询人才库员信息", notes = "参数：人员编号")
    @GetMapping(value = "/personInfo/{rybh}")
    public ResponseWrapper personInfo(@PathVariable(value="rybh")String rybh) {
		return inspectionGroupService.getPersonInfo(rybh);
	}
	
	@ApiOperation(value = "根据用户编号名称查询人才库员信息", notes = "参数：人员名称")
    @PostMapping(value = "/personList")
    public ResponseWrapper personList(
    		@ApiParam(value="rymc人员名称",name="rymc",required=false)
    		@RequestParam(value="rymc", required=false)String rymc) {
		return inspectionGroupService.getPersonList(rymc);
	}
	
	@ApiOperation(value = "根据人员检查类型获取人员列表", notes = "根据人员检查类型获取人员列表")
	@GetMapping("personList/{type}")
	public ResponseWrapper selectPersonListByType(@PathVariable("type") String type, @RequestParam(value="rymc", required=false)String rymc) {
		return inspectionGroupService.selectPersonListByType(type, rymc);
	}
	
	@ApiOperation(value = "根据任务id查询规避记录", notes = "参数：任务id")
    @GetMapping(value = "/evasionList/{rwId}")
	public ResponseWrapper queryEvasionList(@PathVariable("rwId") String rwId) {

		return evasionFeign.queryEvasionList(rwId);
	}
	
	@ApiOperation(value = "根据检查组人员编号判断查询任务列表", notes = "参数：人员编号")
    @GetMapping(value = "/taskList/{rybh}")
    public ResponseWrapper getTaskList(@PathVariable(value="rybh")String rybh) {
		return teamFeign.getTaskList(rybh);
	}
	
	@ApiOperation(value = "根据任务编号和被检单位id查询检查组信息", notes = "参数：任务编号,被检企业id")
    @GetMapping(value = "/inspectionTeam/{rwId}/{bjdwId}")
    public ResponseWrapper getInspectionTeam(
    		@PathVariable(value="rwId")String rwId,
    		@PathVariable(value="bjdwId")String bjdwId) {
		return teamFeign.getInspectionTeam(rwId, bjdwId);
	}
	
	/**
	 * 根据任务编号删除检查组所有信息
	 * @param teamVO
	 */
	@ApiOperation(value = "根据任务编号删除检查组所有信息", notes = "参数：任务编号")
	@DeleteMapping(value = "/deleteInspectionTeams/{rwId}")
	public ResponseWrapper deleteInspectionTeams(@PathVariable(value="rwId")String rwId) {
		return teamFeign.deleteInspectionTeams(rwId);
	}
	
	/**
	 * 
	 * @Title: taskList
	 * @Description: 根据检查组人员编号 任务类型   判断查询任务列表
	 * @param rybh 人员编号 rwlx任务类型
	 * @return 
	 * @throws
	 */
	@ApiOperation(value = "根据检查组人员编号/任务类型判断查询任务列表", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/taskListMore/{rybh}/{rwlx}")
    public ResponseWrapper getTaskListMore(@PathVariable(value="rybh")String rybh,@PathVariable(value="rwlx")String rwlx) {
	
		try {
			List<TaskVO> taskListMore = inspectionGroupService.getTaskListMore(rybh,rwlx);
			if (taskListMore==null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败", null);
			}
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), taskListMore);
		}catch (Exception e) {
			e.printStackTrace();
            log.error(e.getMessage());
		}
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	@ApiOperation(value = "根据计划id,任务id查询详情", notes = "参数：组织编号,检查组id")
	@GetMapping(value = "/taskListMoreDetail/{rwid}/{jhid}")
	public ResponseWrapper taskListMoreDetail(@PathVariable(value="rwid")String rwid,@PathVariable(value="jhid")String jhid) {

		try {
			TaskVO taskListMore = inspectionGroupService.getTaskListMoreDetail(rwid,jhid);
			if (taskListMore==null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), taskListMore);
		}catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
