package com.unis.inspection.app.task;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.ExcelUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspection.app.vo.ReserveGrainVO;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspection.service.InspectionTaskService;
import com.unis.inspectionresult.common.constant.DailyCheckStatusConstant;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.common.constant.TaskStatusConstant;
import com.unis.inspectiontask.common.vo.*;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.util.Arrays;
import java.util.Date;
import java.util.LinkedHashMap;
import java.util.List;

/**
 * @author 张琪
 * @date 2019年8月27日 下午3:30:08
 * @description TaskController 日常检查任务
 */
@RestController
@Slf4j
@Api(value = "检查任务管理", tags = "检查任务管理维护")
public class InspectionTaskController {
	@Autowired
	private InspectionTaskService inspectionTaskService;
	@Autowired
	private TaskFeign taskFeign;

	@Autowired
	private MyUserClient userClient;

	/**
	 * 根据条件分页日常检查信息列表
	 *
	 * @param taskQueryVO
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@ApiOperation(value = "任务检查列表 根据条件【分页查询】", notes = "参数：被检单位编号，被检单位名称，检查单位编号，检查单位名称，检查开始时间，检查结束时间")
	@PostMapping(value = "/inspectionTaskPageList/{pageNum}/{pageSize}")
	public ResponseWrapper getTaskPageList(@RequestBody TaskQueryVO taskQueryVO,
			@PathVariable(value = "pageSize") Integer pageSize, @PathVariable(value = "pageNum") Integer pageNum) {
		try {
			PageInfo<TaskVO> rwTaskPageList = inspectionTaskService.getRwTaskPageList(taskQueryVO, pageNum, pageSize);
			if (rwTaskPageList == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", rwTaskPageList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * @author zhangQi
	 * @Description 根据任务编码查询信息
	 * @return 日常检查
	 */
	@ApiOperation(value = "任务检查分配 根据任务编号和计划ID【数据回显】", notes = "参数：rwId-任务编号 jhId-计划编号")
	@GetMapping(value = "/inspectionTaskCode/{rwId}/{jhId}")
	public ResponseWrapper getTaskInfoByrwbh(@PathVariable("rwId") String rwId, @PathVariable("jhId") String jhId) {
		try {
			TaskVO taskInfo = inspectionTaskService.getTaskInfo(rwId, jhId);
			if (taskInfo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", taskInfo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 根据检查单位ID和计划编号查询详单数据+检查组
	 *
	 * @param jcdwId
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务编辑 根据检查单位ID和计划编号【数据回显】详情+检查组", notes = "参数：jcdwId-检查单位ID   jhId：计划编号 ")
	@GetMapping(value = "/inspectionTaskInfoAll/{jcdwId}/{jhId}")
	public ResponseWrapper getTaskInfoAll(@PathVariable("jcdwId") String jcdwId, @PathVariable("jhId") String jhId) {
		try {
			TaskVO taskInfo = inspectionTaskService.getTaskInfoAll(jcdwId, jhId);
			if (taskInfo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", taskInfo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 制定任务检查数据新增对接
	 *
	 * @param taskVO
	 * @param sffp
	 * @return
	 * @throws ParseException
	 */
	@ApiOperation(value = "制定任务列表 【下发】", notes = "参数：任务编号，任务名称，计划编号，检查方式（0，远程。1、现场），检查组取得方式（0，指定。1、双随机。2、指定。），"
			+ "检查单位ID , 检查单位名称 , 下发人 , 下发人名称 , 下发时间 , 任务状态（0、待分配。1、待下发。2、已下发。3、已完成），"
			+ "任务类型，是否分配本级检查组值，被检单位选择方式（0,单一 1，组合），任务起日，任务止日，创建人，创建人编号，创建时间" + "刷新人" + "   sffp: 是否选择检查组")
	@PostMapping(value = "/inspectionTaskInsert")
	public ResponseWrapper inspectionTaskInsert(@RequestBody TaskVO taskVO) {
		taskVO = inspectionTaskService.setSessionAll(taskVO);
		return taskFeign.inspectionTaskInsert(taskVO);
	}

	/**
	 * 制定任务新增界面 暂存/下发 （是否分配检查组）
	 *
	 * @param taskTO
	 * @return
	 */
	@ApiOperation(value = "制定任务新增页面【暂存/下发/下一步】（下发） ", notes = "参数：是否分配本级检查组")
	@PostMapping(value = "/inspectionTaskInsertTeam")
	public ResponseWrapper inspectionTaskInsertTeam(@RequestBody TaskTeamVO taskTeamVO) {

		// 处理暂存0 下发1 下一步2
		try {
			taskTeamVO = inspectionTaskService.inspectionTaskInsertTeamImp(taskTeamVO);
			if (taskTeamVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", taskTeamVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 任务修改 并下发
	 *
	 * @param taskTeamVO
	 * @return
	 */
	@ApiOperation(value = "任务修改 并下发", notes = "参数：是否分配本级检查组")
	@PostMapping(value = "/inspectionTaskTeamDistributes")
	public ResponseWrapper inspectionTaskTeamDistributes(@RequestBody TaskTeamVO taskTeamVO) {
		return inspectionTaskService.inspectionTaskTeamDistributes(taskTeamVO);
	}

	/**
	 * 制定任务回撤
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务列表【回撤】", notes = "参数：计划ID")
	@PostMapping(value = "/inspectionTaskGetDate/{jhId}")
	public ResponseWrapper inspectionTaskGetDate(@PathVariable("jhId") String jhId) {
		ResponseWrapper inspectionTaskGetDate = taskFeign.inspectionTaskGetDate(jhId);
		if (inspectionTaskGetDate.getInfoCode() != 200) {
			return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "任务已下发,撤销失败", null);
		}
		return ResponseWrapper.success(HttpStatus.OK.value(), "回撤成功", jhId);
	}

	/**
	 * 任务检查回撤
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "任务检查列表 【回撤】", notes = "参数：任务ID")
	@PostMapping(value = "/inspectionTaskReturn/{rwId}")
	public ResponseWrapper inspectionTaskReturn(@PathVariable("rwId") String rwId) {
		return inspectionTaskService.inspectionTaskReturn(rwId, Integer.parseInt(TaskStatusConstant.TO_DXF.getValue()));
	}

	/**
	 * 修改任务状态
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查【状态更新】", notes = "参数：rwId-任务编号 rwZt-任务状态 （0、待分配。1、待下发。2、已下发。3、已完成 ）")
	@PutMapping(value = "/inspectionTaskUpdateByEntity/{rwId}/{rwZt}")
	public ResponseWrapper inspectionTaskUpdateByEntity(@PathVariable("rwId") String rwId,
			@PathVariable("rwZt") Integer rwZt) {
		return taskFeign.inspectionTaskUpdateByEntity(rwId, rwZt);
	}

	/**
	 * 分配操作中检查项目，检查内容数据暂存数据
	 *
	 * @param tJcrwDO
	 * @param tJcnrDO
	 * @param tRwjcxmDO
	 */
	@ApiOperation(value = "任务检查 【分配/暂存-检查任务表+任务检查项目表+ 检查内容表】", notes = "参数：任务编号，任务名称，检查项目 ，检查内容 ， 检查单位 ， 检查方式 ")
	@PostMapping(value = "/inspectionTaskDistribution")
	public ResponseWrapper inspectionTaskDistribution(@RequestBody TaskVO taskVO) {
		taskVO = inspectionTaskService.setSessionAll(taskVO);
		return taskFeign.inspectionTaskDistribution(taskVO);
	}

	/**
	 * 任务结果下发-新增
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务返回结果 【下发】")
	@PostMapping(value = "/inspectionTaskResultInsert")
	public ResponseWrapper inspectionTaskResultInsert(@RequestBody TaskVO taskVO) {
		return inspectionTaskService.inspectionTaskResultInsert(taskVO);
	}

	/**
	 * 根据条件导出日常检查管理信息
	 *
	 * @param taskQueryVO
	 * @param task
	 * @param request
	 * @param response
	 * @return
	 */
	@ApiOperation(value = "根据条件 【导出】", notes = "参数：查询条件")
	@PostMapping(value = "/inspectionTaskExport")
	public ResponseWrapper inspectionTaskExport(@RequestBody TaskQueryVO taskQueryVO, HttpServletRequest request,
			HttpServletResponse response) {
		try {
			String orgCode = CurrentUtil.getOrgId();
			String orgLevel = CurrentUtil.getOrgLevel();
			if (StringUtils.isNotEmpty(orgCode)
					&& InspectionConstant.GRAIN_RESERVE_CORPORATION_ORGANIZATION_CODE.equals(orgCode)) {
				// 当登录账号属于储备粮公司时 只能查看 日常检查-储备粮公司
				taskQueryVO.setRwlx("5000150");
			} else {
				// 区粮办
				if (StringUtils.isNotEmpty(orgLevel)
						&& InspectionConstant.AREA_FOOD_DO_ORGANIZATIONAL.equals(orgLevel)) {
					// 获取当前组织下任务
					taskQueryVO.setOrgId(orgCode);
				} else if (StringUtils.isNotEmpty(orgLevel)
						&& InspectionConstant.CITY_BUREAU_ORGANIZATIONAL.equals(orgLevel)) {// 市局
					// 根据当前登录用户所在部门查询该部门下所有用户，然后根据用户集合查询计划主键集合
					String departmentId = CurrentUtil.getDeptId();
					if (StringUtils.isNotEmpty(departmentId)) {
						JSONObject obj = new JSONObject();
						obj.put("deptCode", departmentId);
						ResponseWrapper result = userClient.findByDeptCode(obj, 1, 10000);
						if (result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
							Object content = result.getData();
							JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(content));
							JSONArray jsonArray = jsonObj.getJSONArray("content");
							if (CollectionUtils.isNotEmpty(jsonArray)) {
								List<String> makers = Lists.newArrayList();
								jsonArray.stream().forEach(member -> {
									JSONObject memberObj = (JSONObject) member;
									String userCode = memberObj.getString("userCode");
									if (StringUtils.isNotEmpty(userCode)) {
										makers.add(userCode);
									}
								});
								taskQueryVO.setUserIds(makers);
							}
						}
					}
				}
			}
			ResponseWrapper inspectionTaskExport = taskFeign.inspectionTaskExport(taskQueryVO);
			// 任务状态（0、待分配。1、待下发。2、已下发。3、已完成。4、已超期。5、超期完成。 6、已归档。）
			Integer[] rwztList = { 0, 1, 2, 3, 4, 5, 6 };
			String[] rwztmcList = { "待分配", "待下发", "已下发", "已完成", "已超期", "超期完成", "已归档" };
			if (inspectionTaskExport.getInfoCode() == 200) {
				List<TaskVO> parseList = JsonUtils.parseList(JsonUtils.serialize(inspectionTaskExport.getData()),
						TaskVO.class);
				for (TaskVO taskVO : parseList) {
					taskVO.setJckssjDate(DateUtil.turnDateToSqlDate(
							DateUtil.turnJavaUtilDateToStrDate(taskVO.getJckssjDate(), "yyyy-MM-dd"), "yyyy-MM-dd"));
					taskVO.setJcjssjDate(DateUtil.turnDateToSqlDate(
							DateUtil.turnJavaUtilDateToStrDate(taskVO.getJcjssjDate(), "yyyy-MM-dd"), "yyyy-MM-dd"));
					int index = 0;
					while (index < rwztList.length) {
						if (rwztList[index].equals(taskVO.getRwZt())) {
							taskVO.setRwZtmc(rwztmcList[index]);
						}
						index++;
					}
				}

				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("rwId", "任务编号");
				columnName.put("rwName", "任务名称");
				columnName.put("rwlxName", "任务类型");
				columnName.put("jcdwmc", "检查单位");
				columnName.put("jckssjDate", "检查开始时间");
				columnName.put("jcjssjDate", "检查结束时间");
				columnName.put("rwZtmc", "状态");
				// 输出Excel文件
				ServletOutputStream output = response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition", "attachment;filename="
						+ new String(("XCGS" + DateUtil.getDate()).getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				ExcelUtil.pojo2Excel(parseList, output, columnName, "任务检查" + DateUtil.getDate());
				output.close();
				return null;
			} else {
				return inspectionTaskExport;
			}
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "导出失败", null);
		}
	}

	/**
	 * 获取任务ID主键策略方法 计划编号+001 格式
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "获取任务ID主键策略方法  【计划编号+001 格式】", notes = "参数：jhId-计划编号")
	@GetMapping(value = "/inspectionTaskMaxCodeById/{jhId}")
	public ResponseWrapper inspectionTaskMaxCodeById(@PathVariable("jhId") String jhId) {
		return taskFeign.inspectionTaskMaxCodeById(jhId);
	}

	/**
	 * 检查任务数据 新增 + 内蒙
	 *
	 * @param taskVO
	 */
	@ApiOperation(value = "任务检查 【新增】")
	@PutMapping(value = "/inspectionTaskSave")
	public ResponseWrapper inspectionTaskSave(@RequestBody TaskVO taskVO) {
		taskVO = inspectionTaskService.setSessionAll(taskVO);
		return taskFeign.inspectionTaskSave(taskVO);
	}

	/**
	 * 检查任务数据 删除
	 *
	 * @param rwId
	 */
	@ApiOperation(value = "任务检查 【删除】")
	@DeleteMapping(value = "/inspectionTaskDelete/{rwId}")
	public ResponseWrapper inspectionTaskDelete(@PathVariable("rwId") String rwId) {
		return taskFeign.inspectionTaskDelete(rwId);
	}

	/**
	 * 检查任务子项目数据 删除
	 *
	 * @param rwId
	 */
	@ApiOperation(value = "检查任务子项目 【删除】")
	@DeleteMapping(value = "/taskCheckItemsVODelete/{rwId}")
	public ResponseWrapper taskCheckItemsVODelete(@PathVariable("rwId") String rwId) {
		return taskFeign.taskCheckItemsVODelete(rwId);
	}

	/**
	 * 检查任务子项目数据 新增
	 *
	 * @param taskCheckItemsVO
	 */
	@ApiOperation(value = "检查任务子项目 【新增】")
	@PutMapping(value = "/taskCheckItemsVOSave")
	public ResponseWrapper taskCheckItemsVOSave(@RequestBody TaskCheckItemsVO taskCheckItemsVO) {
		return taskFeign.taskCheckItemsVOSave(taskCheckItemsVO);
	}

	/**
	 * 检查任务内容数据 删除
	 *
	 * @param rwId
	 */
	@ApiOperation(value = "检查任务内容  【删除】")
	@DeleteMapping(value = "/checkContentVODelete/{rwId}")
	public ResponseWrapper checkContentVODelete(@PathVariable("rwId") String rwId) {
		return taskFeign.checkContentVODelete(rwId);
	}

	/**
	 * 检查任务内容数据 新增
	 *
	 * @param checkContentVO
	 */
	@ApiOperation(value = "检查任务内容 【新增】")
	@PutMapping(value = "/checkContentVOSave")
	public ResponseWrapper checkContentVOSave(@RequestBody CheckContentVO checkContentVO) {
		return taskFeign.checkContentVOSave(checkContentVO);
	}

	/**
	 * 检查任务内容数据 更新
	 *
	 * @param taskVO
	 */
	@ApiOperation(value = "检查任务内容数据 【更新】")
	@PutMapping(value = "/inspectionTaskUpdate")
	public ResponseWrapper inspectionTaskUpdate(@RequestBody TaskVO taskVO) {
		taskVO = inspectionTaskService.setSessionAll(taskVO);
		return taskFeign.inspectionTaskUpdate(taskVO);
	}

	/**
	 * 检查任务-归档管理
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "检查任务-【归档管理】")
	@PutMapping(value = "/inspectionTaskGuiDang")
	public ResponseWrapper inspectionTaskGuiDang(@RequestBody TaskVO taskVO) {
		taskVO = inspectionTaskService.setSessionAll(taskVO);
		return taskFeign.inspectionTaskGuiDang(taskVO);
	}

	/**
	 * 制定任务 根据计划ID查询列表
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务 【计划ID】查询列表", notes = "参数：计划编号，被检单位ID")
	@PostMapping(value = "/inspectionPlanList/{jhId}")
	public ResponseWrapper inspectionPlanList(@PathVariable("jhId") String jhId) {
		return taskFeign.inspectionPlanList(jhId);
	}

	/**
	 * 检查任务数据 更新/新增
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查 【更新】")
	@PutMapping(value = "/inspectionTaskEdit")
	public ResponseWrapper inspectionTaskEdit(@RequestBody TaskVO taskVO) {
		return taskFeign.inspectionTaskEdit(taskVO);
	}

	/**
	 * 检查任务数据 查询
	 *
	 * @return
	 */
	@ApiOperation(value = "任务检查 【数据】")
	@PostMapping(value = "/inspectionTaskMain")
	public ResponseWrapper inspectionTaskMain(@RequestBody TaskQueryVO taskQueryVO) {
		return taskFeign.inspectionTaskMain(taskQueryVO);
	}

	/**
	 * 检查任务数据 更新/新增 储备粮-日常检查
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查储备粮-日常检查 【更新】", tags = {"结果反馈", "市级储备成品粮油检查", "市级储备原粮检查"})
	@PutMapping(value = "/inspectionTaskCbl")
	public ResponseWrapper inspectionTaskCbl(@RequestBody ReserveGrainVO reserveGrainVO) {
        log.info("put inspectionTaskCbl arg =========================================\n" + JSON.toJSONString(reserveGrainVO));
		try {
            String rwlx = reserveGrainVO.getRwlx();
            if ("5000170".equals(rwlx)) {
                String jgTbbh = reserveGrainVO.getJgTbbh();
                List<String> constantList = Arrays.asList(DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getValue(),
                        DailyCheckStatusConstant.TO_BE_REFORM.getValue(),
                        DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getValue());
                if (constantList.contains(jgTbbh)) {
                    reserveGrainVO.setJgTbbh(DailyCheckStatusConstant.FINISHED.getValue());
                    reserveGrainVO.setJgTbmc(DailyCheckStatusConstant.FINISHED.getName());
                }

            }
			ReserveGrainVO inspectionTaskCbl = inspectionTaskService.inspectionTaskCbl(reserveGrainVO);
			if (inspectionTaskCbl == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "保存失败", null);
			}else{
                if("5000180".equals(rwlx)){
					inspectionTaskService.callBackOnFinish(inspectionTaskCbl.getJhId());
                }
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", inspectionTaskCbl);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 *
	 * @Title: inspectionJhTaskCq @Description:
	 * 方法描述:(这里用一句话描述这个方法的作用) @param @param taskQueryVO @param @return
	 * 设定文件 @return ResponseWrapper 返回类型 @throws
	 */
	@ApiOperation(value = "任务派发计划定时任务检查是否超期 【数据】")
	@PostMapping(value = "/inspectionJhTaskCq")
	public ResponseWrapper inspectionJhTaskCq(@RequestBody TaskQueryVO taskQueryVO) {
		inspectionTaskService.inspectionJhTaskCq();
		return taskFeign.inspectionJhTaskCq(taskQueryVO);
	}

	 private ObjectMapper objectMapper = new ObjectMapper();

	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更申请", notes = "变更申请")
	@PostMapping("/task/apply")
	public ResponseWrapper taskChange(@RequestBody TaskChangeVO taskChangeVO) {
		taskChangeVO.setTjr(CurrentUtil.getUserName());
		taskChangeVO.setTjsj(new Date());
		if(StringUtils.isEmpty(taskChangeVO.getRwId())) {
			return ResponseWrapper.error("任务编号为bull");
		}
		TaskVO taskVO = new TaskVO();
		ResponseWrapper taskVOResponse = taskFeign.getTaskInfoByrwbh(taskChangeVO.getRwId(), taskChangeVO.getRwId().substring(0, taskChangeVO.getRwId().length()-3));
        if (taskVOResponse.getInfoCode() == 200 && taskVOResponse.getData() != null) {
            taskVO = objectMapper.convertValue(taskVOResponse.getData(), TaskVO.class);
        }
		if(StringUtils.isNotEmpty(taskVO.getOrgId())&&taskVO.getOrgId().equals("LS001")) {
//			ResponseWrapper result = userClient.findBySectionChief("DP353", "10230006", "LS001");
//			if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
//				Object obj = result.getData();
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				JSONArray arr = JSON.parseArray(JsonUtils.serialize(obj));
//				arr.forEach( user -> {
//					JSONObject userObj = (JSONObject)user;
//					ReceiverCollectionVO vo = new ReceiverCollectionVO();
//					vo.setUserId(userObj.getString("userCode"));
//					vo.setUserName(userObj.getString("userName"));
//					vo.setRylx(0);
//					userList.add(vo);
//				});
//				taskChangeVO.setUserList(userList);
//			}
			List<ReceiverCollectionVO> userList = Lists.newArrayList();
			ReceiverCollectionVO vo = new ReceiverCollectionVO();
			vo.setUserId(taskVO.getCreatorCode());
			vo.setUserName(taskVO.getCreator());
			userList.add(vo);
			taskChangeVO.setUserList(userList);
		}



		return ResponseWrapper.success(taskFeign.taskChange(taskChangeVO));
	}

	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更审核", notes = "变更审核")
	@PostMapping("/task/examine")
	public ResponseWrapper taskExamine(@RequestBody TaskChangeVO taskChangeVO) {
		taskChangeVO.setSpr(CurrentUtil.getUserName());
		taskChangeVO.setSpsj(new Date());
		return ResponseWrapper.success(taskFeign.taskExamine(taskChangeVO));
	}
}
