package com.unis.inspection.app.task;

import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.*;
import com.unis.inspection.app.client.DataDictionaryFeign;
import com.unis.inspection.app.vo.DataDictionaryDO;
import com.unis.inspection.service.PerformanceService;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectiontask.client.PerformanceFeign;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.client.TeamFeign;
import com.unis.inspectiontask.common.vo.*;
import com.unis.intelligence.client.CheckTalentLibFeign;
import com.unis.intelligence.client.PersonRandomFeign;
import com.unis.intelligence.common.vo.TalentStoreVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import java.util.*;

/**
 * @author WangZL
 * @version 1.0
 * @Title PerformanceController
 * @ProjectName 履职情况表 PerformanceController
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "履职情况表 ", tags = "履职情况表")
@Slf4j
public class PerformanceController {

	@Autowired
	private PerformanceFeign performanceFeign;

	@Autowired
	private TaskFeign taskFeign;

	@Autowired
	private PersonRandomFeign personRandomFeign;

	@Autowired
	private CheckTalentLibFeign checkTalentLibFeign;

	@Autowired
	private TeamFeign teamFeign;

	@Autowired
	private PerformanceService performanceService;

	@Autowired
	private DataDictionaryFeign dataDictionaryFeign;

	/***************** 全局对象******************/
	private ObjectMapper objectMapper = new ObjectMapper();

	/**
	 * 公用封装方法
	 */
	public void getObjectMapperMethods() {
		// 序列化的时候序列对象的所有属性
		objectMapper.setSerializationInclusion(Include.ALWAYS);
		// 反序列化的时候如果多了其他属性,不抛出异常
		objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
		// 如果是空对象的时候,不抛异常
		objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
	}

	/**
	 *
	 * @Title: getPerformancePage
	 * @Description: 方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param performanceQueryVO
	 * @param @param pageNum
	 * @param @param pageSize
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	 */
	@ApiOperation(value = "履职情况-分页查询列表", notes = "参数：参数：所属单位，统计开始时间，统计结束时间，工作单位-不能为空，人员属性(任务类型编号)-不能为空，人员状态-不能为空，权限-不能为空")
	@PostMapping(value = "/performanceList/{pageNum}/{pageSize}")
	public ResponseWrapper getPerformancePage(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		return performanceService.getPerformancePage(performanceQueryVO,pageNum,pageSize);
	}

	@ApiOperation(value = "履职情况-导出列表", notes = "参数：所属单位，统计开始时间，统计结束时间")
	@PostMapping(value = "/exportPerformanceList/{pageNum}/{pageSize}")
	public ResponseWrapper exportPerformanceList(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize, HttpServletResponse response){
		try {
			ResponseWrapper responseWrapper = performanceService.getPerformancePage(performanceQueryVO,pageNum,pageSize);
			if(responseWrapper.getInfoCode()==200){
				PageInfo<PerformanceVO> pageInfo = objectMapper.convertValue(responseWrapper.getData(), PageInfo.class);
				List<PerformanceVO> performanceList = pageInfo.getList();
				List<Map<String,Object>> performanceMapList = new ArrayList<>();
				if (performanceList != null && performanceList.size() > 0){
					for (PerformanceVO performanceVO : performanceList) {
						Map<String,Object> performanceMap = new HashMap<>();
						performanceMap.put("ryxm",performanceVO.getRyxm());
						Map<String,Integer> rwnrMap = performanceVO.getRwnrList();
						for (String rwnr : rwnrMap.keySet()){
							performanceMap.put(rwnr,rwnrMap.get(rwnr));
						}
						performanceMapList.add(performanceMap);
					}
				}
				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("ryxm","人员名称");
				ResponseWrapper dataWrapper = dataDictionaryFeign.findByGroupId("50002");
				if (dataWrapper.getInfoCode() != 200) {
					return dataWrapper;
				}
				List<DataDictionaryDO> dataDictionaryList = com.unis.common.utils.JsonUtils.parseList(com.unis.common.utils.JsonUtils.serialize(dataWrapper.getData()), DataDictionaryDO.class);
				if (dataDictionaryList != null && dataDictionaryList.size() > 0){
					for (DataDictionaryDO dataDictionaryDO : dataDictionaryList) {
						columnName.put(dataDictionaryDO.getDictCode(),dataDictionaryDO.getDictName());
					}
				}
				//输出Excel文件
				OutputStream output=response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition",
						"attachment;filename=" + new String(("XCGS"+DateUtil.getDate()).getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				ExcelUtil.pojo2Excel(performanceMapList,output,columnName,"履职情况"+ DateUtil.getDate());
				output.close();
				return null;
			} else {
				return responseWrapper;
			}
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "导出失败", null);
		}
	}

	/**
	 *
	 * @Title: getPerformancePageInfo
	 * @Description: 方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param personPerformanceQueryVO
	 * @param @param pageNum
	 * @param @param pageSize
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	 */
	@ApiOperation(value = "人员履职情况-分页查询列表", notes = "参数：所属单位，统计开始时间，统计结束时间，持证情况：国家证、市级证")
	@PostMapping(value = "/personnelPerformanceList/{pageNum}/{pageSize}")
	public ResponseWrapper personnelPerformanceList(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		return performanceService.getPersonnelPerformanceList(performanceQueryVO,pageNum,pageSize);
	}

	@ApiOperation(value = "人员履职情况-导出列表", notes = "参数：所属单位，统计开始时间，统计结束时间，持证情况：国家证、市级证")
	@PostMapping(value = "/exportPersonnelPerformanceList/{pageNum}/{pageSize}")
	public ResponseWrapper exportPersonnelPerformanceList(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize, HttpServletResponse response){
		try {
			ResponseWrapper responseWrapper = performanceService.getPersonnelPerformanceList(performanceQueryVO,pageNum,pageSize);
			if(responseWrapper.getInfoCode()==200){
				PageInfo<PersonPerformanceVO> pageInfo = objectMapper.convertValue(responseWrapper.getData(), PageInfo.class);
				List<PersonPerformanceVO> personPerformanceList = pageInfo.getList();
				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("ryxm","人员名称");
				columnName.put("zydw","所属单位");
				columnName.put("zfzlx","执法证类型");
				columnName.put("jccs","检查次数");
				//输出Excel文件
				OutputStream output=response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition",
						"attachment;filename=" + new String(("XCGS"+DateUtil.getDate()).getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				ExcelUtil.pojo2Excel(personPerformanceList,output,columnName,"人员履职情况"+ DateUtil.getDate());
				output.close();
				return null;
			} else {
				return responseWrapper;
			}
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "导出失败", null);
		}
	}

	/**
	 *
	 * @Title: getPerformancePageInfo
	 * @Description: 方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param personPerformanceQueryVO
	 * @param @param pageNum
	 * @param @param pageSize
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	 */
	@ApiOperation(value = "履职任务-查询列表", notes = "参数：人员编号，统计开始时间，统计结束时间，字典编号，操作状态：1、人员履职。2、履职情况")
	@PostMapping(value = "/performanceDetailsList/{dataStatus}/{pageNum}/{pageSize}")
	public ResponseWrapper getPerformanceDetailsList(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("dataStatus")Integer dataStatus, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		return performanceService.getPerformanceDetailsList(performanceQueryVO,dataStatus,pageNum,pageSize);
	}

	@ApiOperation(value = "履职任务-导出列表", notes = "参数：人员编号，统计开始时间，统计结束时间，字典编号，操作状态：1、人员履职。2、履职情况")
	@PostMapping(value = "/exportPerformanceDetailsList/{dataStatus}/{pageNum}/{pageSize}")
	public ResponseWrapper exportPerformanceDetailsList(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("dataStatus")Integer dataStatus, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize, HttpServletResponse response){
		try {
			ResponseWrapper responseWrapper = performanceService.getPerformanceDetailsList(performanceQueryVO,dataStatus,pageNum,pageSize);
			if(responseWrapper.getInfoCode()==200){
				PageInfo<DailyCheckResultVO> pageInfo = objectMapper.convertValue(responseWrapper.getData(), PageInfo.class);
				List<DailyCheckResultVO> dailyCheckResultList = pageInfo.getList();
				if (dailyCheckResultList != null && dailyCheckResultList.size() > 0){
					for (DailyCheckResultVO dailyCheckResultVO : dailyCheckResultList) {
						dailyCheckResultVO.setJcsj(DateUtil.turnDateToSqlDate(DateUtil.turnJavaUtilDateToStrDate(dailyCheckResultVO.getJcsj(),"yyyy-MM-dd hh:mm:ss"),"yyyy-MM-dd hh:mm:ss"));
						dailyCheckResultVO.setJgTjsj(DateUtil.turnDateToSqlDate(DateUtil.turnJavaUtilDateToStrDate(dailyCheckResultVO.getJgTjsj(),"yyyy-MM-dd hh:mm:ss"),"yyyy-MM-dd hh:mm:ss"));
					}
				}
				LinkedHashMap<String, String> columnName = new LinkedHashMap<>();
				columnName.put("jgId","任务编号");
				columnName.put("rwmc","任务名称");
				columnName.put("bjdwName","被检单位");
				columnName.put("jcdwmc","检查单位");
				columnName.put("jcsj","检查时间");
				columnName.put("jgTjr","提交人");
				columnName.put("jgTjsj","提交时间");
				columnName.put("jgZglxmc","整改类型");
				columnName.put("jgTbmc","状态");
				//输出Excel文件
				OutputStream output=response.getOutputStream();
				response.reset();
				response.setHeader("content-disposition",
						"attachment;filename=" + new String(("XCGS"+DateUtil.getDate()).getBytes("gb2312"), "ISO8859-1") + ".xls");
				response.setContentType("application/msexcel");
				ExcelUtil.pojo2Excel(dailyCheckResultList,output,columnName,"人员履职情况"+ DateUtil.getDate());
				output.close();
				return null;
			} else {
				return responseWrapper;
			}
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "导出失败", null);
		}
	}


	/**
	 *
	 * @Title: getPerformancePageInfo
	 * @Description: 方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param personPerformanceQueryVO
	 * @param @param pageNum
	 * @param @param pageSize
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	 */
	/*@ApiOperation(value = "人员履职情况-分页查询列表", notes = "参数：人员信息列表，统计开始时间，统计结束时间")
	@PostMapping(value = "/performancePageInfo/{pageNum}/{pageSize}")
	public ResponseWrapper getPerformancePageInfo(@RequestBody PersonPerformanceQueryVO personPerformanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		try {
			PageInfo<PersonPerformanceVO> rwTaskPageList = this.getRwPageList(personPerformanceQueryVO,pageNum,pageSize);
			if (rwTaskPageList==null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败", null);
			}
		       return ResponseWrapper.success(HttpStatus.OK.value(),"获取成功", rwTaskPageList);
		} catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");

	}*/

	/**
	 * @Title: getRwPageList
	 * @Description: 方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param personPerformanceQueryVO
	 * @param @param pageNum
	 * @param @param pageSize
	 * @param @return    设定文件
	 * @return PageInfo<TaskVO>    返回类型
	 * @throws
	 */
	@SuppressWarnings("unchecked")
	private PageInfo<PersonPerformanceVO> getRwPageList(PersonPerformanceQueryVO personPerformanceQueryVO, Integer pageNum,
														Integer pageSize) {

		List<PersonPerformanceVO> vos=new ArrayList<PersonPerformanceVO>();
		TaskQueryVO	taskQueryVO=new TaskQueryVO();
		taskQueryVO.setJcdwId(personPerformanceQueryVO.getZydw());
		taskQueryVO.setJckssjDate(personPerformanceQueryVO.getTjkssjDate());
		taskQueryVO.setJcjssjDate(personPerformanceQueryVO.getTjjssjDate());

		PageInfo<PersonPerformanceVO> pageInfo = new PageInfo<PersonPerformanceVO>();
		ResponseWrapper rwTaskPageList = taskFeign.getRwTaskPageList(taskQueryVO, pageNum, pageSize);
		if (rwTaskPageList.getInfoCode()==200) {

			pageInfo = objectMapper.convertValue(rwTaskPageList.getData(), PageInfo.class);
			// 分页查询列表数据
			List<TaskVO> taskVOL = JsonUtils.parseList(JsonUtils.serialize(pageInfo.getList()), TaskVO.class);
			// 转换成json
			Iterator<TaskVO> iterator = taskVOL.iterator();
			while (iterator.hasNext()) {
				Object taskvo = iterator.next();
				TaskVO taskVO = (TaskVO) taskvo;
				TaskVO taskV = new TaskVO();
				LsBeanUtils.copyAllProperties(taskVO, taskV);

				// 检查组查询
				ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(taskVO.getRwId());
				if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
					List<TeamVO> list = objectMapper.convertValue(teamVOResponse.getData(), List.class);
					taskV.setTeamVOs(list);
				}

				List<TeamVO> team=new ArrayList<TeamVO>();
				if(taskV.getTeamVOs()!=null) {
					ArrayList<MemberVO> memberVOS = new ArrayList<>();
					team= JsonUtils.parseList(JsonUtils.serialize(taskV.getTeamVOs()), TeamVO.class);
					for (TeamVO teamvos:team){
						LsBeanUtils.copyCollection(teamvos.getMembers(), memberVOS, MemberVO.class);
					}
					for (MemberVO task : memberVOS) {
						PersonPerformanceVO vo=new PersonPerformanceVO();

						if(!org.springframework.util.StringUtils.isEmpty(task.getZyId()) &&task.getZyId()!=null) {
							ResponseWrapper taskList = teamFeign.getTaskList(task.getZyId());
							if (taskList.getInfoCode() == 200 && taskList.getData() != null) {
								List<TaskVO> t = JsonUtils.parseList(JsonUtils.serialize(taskList.getData()), TaskVO.class);
								vo.setJccs(t.size());
							}

							vo.setRyxm(task.getZyName());
							vo.setRybh(task.getZyId());

							TalentStoreVO talentStoreVO=new TalentStoreVO();
							ResponseWrapper personInfo = personRandomFeign.personInfo(task.getZyId());
							if (personInfo.getInfoCode() == 200 && personInfo.getData() != null) {
								talentStoreVO = objectMapper.convertValue(personInfo.getData(), TalentStoreVO.class);
							}
							vo.setZydw(talentStoreVO.getZzjgmc());

							if(!org.springframework.util.StringUtils.isEmpty(talentStoreVO.getZfzbh())) {
								vo.setZfzlx("国家证");
								vo.setZfzbh("1");
							}
							if(!org.springframework.util.StringUtils.isEmpty(talentStoreVO.getSZfzbh())) {
								vo.setZfzlx("市级证");
								vo.setZfzbh("2");
							}
							if(!org.springframework.util.StringUtils.isEmpty(talentStoreVO.getSZfzbh())&&!org.springframework.util.StringUtils.isEmpty(talentStoreVO.getZfzbh())) {
								vo.setZfzlx("国家证/市级证");
								vo.setZfzbh("3");
							}
							vos.add(vo);
						}
					}
				}
			}
			// 分页设置
		}
		pageInfo.setList(vos);
		return pageInfo;
	}




	@ApiOperation(value = "根据人员检查类型获取人员列表", notes = "根据人员检查类型获取人员列表")
	@PostMapping("personListByid")
	public ResponseWrapper selectPersonListById(@RequestParam List<String> userCodes) {
		try {
			return null;
//			return personRandomFeign.selectPersonListById(userCodes);
		} catch (Exception e) {
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询信息失败", null);
	}
}
