package com.unis.inspection.schedule;

import java.util.Date;
import java.util.List;
import java.util.Set;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.esotericsoftware.minlog.Log;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.utils.getPlanStatusUtil;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultByPlanShowVO;
import com.unis.inspectiontask.client.TaskFeign;

/**
 *
 * @Description：检查计划定时任务
 */
@Component
public class InspectionPlanOverdueSchedule {

	@Autowired
	private InspectionplanFeign inspectionplanFeign;

	@Autowired
	private DailyCheckResultApi dailyCheckResultApi;

	@Autowired
	private TaskFeign taskFeign;

	/**
	 *
	 * @Description: 修改计划状态->
	 * 				  结果反馈-日常检查：提交且组长审核通过任务已完成，反之超期
   	 *				  其它的任务类型：只要提交了就算检查任务已完成，除非在规定的期限内保存了检查内务但未提交的任务状态才会为已超期
	 */
    //@Scheduled(cron = "0 10 11 * * ?")
    //@Scheduled(cron = "0 */20 * * * ?")
	@Scheduled(cron = "0 0 1  * *  ? ")
	public void updatePlanStatus() {
		Log.info("===============  Execute 制定任务超期扫描任务数据开始！=============" + new Date());
		// 获取执行中的计划总数
		ResponseEntity<JSONObject> result = inspectionplanFeign.getPlanUnfinishedCount(InspectionConstant.PLAN_IN_PROGRESS_STATUS);
		Long count = 0L;
		if (!ObjectUtils.isEmpty(result) && HttpStatus.OK.value() == result.getStatusCodeValue()) {
			JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(result.getBody()));
			count = jsonObj.getLong("count");
		}
		// 计划数大于零，则执行查询当前状态下计划列表详情
		if (count > 0) {
			long pageSize = 20;
			long xunhuancishu = count / pageSize;
			if (count % pageSize > 0) {
				xunhuancishu = xunhuancishu + 1;
			}
			for (int i = 0; i < xunhuancishu; i++) {
				// 分页查询执行中的计划 状态为2则为执行中
				ResponseEntity<List<InspectionplanVO>> resultList = inspectionplanFeign.planUnfinishedList(Integer.valueOf(pageSize + ""), i + 1,
						InspectionConstant.PLAN_IN_PROGRESS_STATUS);
				if (!ObjectUtils.isEmpty(resultList) && HttpStatus.OK.value() == resultList.getStatusCodeValue()) {
					JSONArray arr = JSON.parseArray(JsonUtils.serialize(resultList.getBody()));
					arr.stream().forEach((obj) -> {
						InspectionplanVO planVO = JsonUtils.parse(JsonUtils.serialize(obj), InspectionplanVO.class);
						String planId = planVO.getJhId();
						if (StringUtils.isNotEmpty(planId)) {
							// 查询当前计划下的检查任务
							ResponseEntity<List<DailyCheckResultByPlanShowVO>> showVOObj = dailyCheckResultApi.getCheckResultListByPlanId(planId);
							if (!ObjectUtils.isEmpty(showVOObj)
									&& HttpStatus.OK.value() == showVOObj.getStatusCodeValue()) {
								List<DailyCheckResultByPlanShowVO> showVOList = showVOObj.getBody();
								// 判断当前计划下的任务是否都未完成
								if (CollectionUtils.isNotEmpty(showVOList)) {
									/*List<String> statusList = Lists.newArrayList();
									List<String> statusListForOverdueComplete = Lists.newArrayList(); // 超期完成
									Set<String> taskIds = Sets.newHashSet();


									String rwlxId = planVO.getRwlxId(); // 任务类型
									Date rwqsr = planVO.getRwqsr(); // 任务开始时间
									Date rwjsr = planVO.getRwjsr(); // 任务结束时间
									if(null != rwqsr && null != rwjsr) {
										if(("5000110").equals(rwlxId)) { // 结果反馈-日常检查：提交且组长审核通过任务已完成，反之超期
											showVOList.stream().forEach(checkResult ->{
													String status = checkResult.getJgTbbh();
													Date tjsj = checkResult.getJgTjsj(); // 提交时间
													if(null == tjsj) { // 未提交，判断是否已过任务结束时间
														tjsj = DateUtil.getNowDate();
													}
													if (StringUtils.isNotEmpty(status) && !dateCompare(tjsj, rwqsr, rwjsr)
															&& (InspectionConstant.INSPECTION_RESULTS_TOCHECK_STATUS.equals(status)
															|| InspectionConstant.INSPECTION_RESULTS_TOCOMMIT_STATUS.equals(status)
															|| InspectionConstant.INSPECTION_RESULTS_APPROVAL_STATUS.equals(status))) { // 时间范围内还未审批通过
														statusList.add(status);
														String taskId = checkResult.getRwId();
														if (StringUtils.isNotEmpty(taskId)) {
															taskIds.add(taskId);
														}
													} else if (StringUtils.isNotEmpty(status) && !dateCompare(tjsj, rwqsr, rwjsr)
															&& (!InspectionConstant.INSPECTION_RESULTS_TOCHECK_STATUS.equals(status)
															&& !InspectionConstant.INSPECTION_RESULTS_TOCOMMIT_STATUS.equals(status)
															&& !InspectionConstant.INSPECTION_RESULTS_APPROVAL_STATUS.equals(status))) { // 任务时间范围外审批通过
														statusListForOverdueComplete.add(status);
													}
											});
										} else { // 其它的任务类型：只要提交了就算检查任务已完成，除非在规定的期限内保存了但未提交的任务状态才会为已超期
											showVOList.stream().forEach(checkResult -> {
													String status = checkResult.getJgTbbh();
													Date tjsj = checkResult.getJgTjsj(); // 提交时间
													if(null == tjsj) { // 未提交，判断是否已过任务结束时间
														tjsj = DateUtil.getNowDate();
													}
													// 子任务在计划时间之外，状态码为0,2 则表示任务超期
													if (StringUtils.isNotEmpty(status) && !dateCompare(tjsj, rwqsr, rwjsr)
															&& (InspectionConstant.INSPECTION_RESULTS_TOCHECK_STATUS.equals(status)
															|| InspectionConstant.INSPECTION_RESULTS_TOCOMMIT_STATUS.equals(status))) { // 时间范围内还未提交
														statusList.add(status);
														String taskId = checkResult.getRwId();
														if (StringUtils.isNotEmpty(taskId)) {
															taskIds.add(taskId);
														}
													} else if(StringUtils.isNotEmpty(status) && !dateCompare(tjsj, rwqsr, rwjsr)
															&& (!InspectionConstant.INSPECTION_RESULTS_TOCHECK_STATUS.equals(status)
															&& !InspectionConstant.INSPECTION_RESULTS_TOCOMMIT_STATUS.equals(status))) { // 任务时间范围外提交
														statusListForOverdueComplete.add(status);
													}
											});
										}
									}

									// 当前计划子任务都为未完成状态
									if (statusList.size()> 0 && statusList.size() <= showVOList.size()
											|| (statusListForOverdueComplete.size()>0 && statusListForOverdueComplete.size() != showVOList.size())) { // 只要有子任务为超期或者不全是超期则都为超期
										System.out.println("执行更新计划状态->计划名称：" + planVO.getJhName() + "  计划主键：" + planId + "为超期状态");
										// 更新计划状态
										InspectionplanVO updatePlan = new InspectionplanVO();
										updatePlan.setJhId(planId);
										updatePlan.setJhzt(InspectionConstant.PLAN_OVERDUE_STATUS);
										ResponseWrapper planResult = inspectionplanFeign
												.updateInspectionplanonly(updatePlan);
									} else if (statusListForOverdueComplete.size()>0 && statusListForOverdueComplete.size() == showVOList.size()) { // 只有所有子任务全部超期完成才更改主任务为超期完成
										System.out.println("执行更新计划状态->计划名称：" + planVO.getJhName() + "  计划主键：" + planId + "为超期完成状态");
										// 更新计划状态
										InspectionplanVO updatePlan = new InspectionplanVO();
										updatePlan.setJhId(planId);
										updatePlan.setJhzt(InspectionConstant.PLAN_OVERDUE_COMPLETE_STATUS);
										ResponseWrapper planResult = inspectionplanFeign
												.updateInspectionplanonly(updatePlan);
									}*/
									Integer planStatus = getPlanStatusUtil.getPlanStatus(showVOList, planVO);
									Log.info("执行更新计划状态->计划名称：" + planVO.getJhName() + "  计划主键：" + planId + "  最终状态值为"+planStatus);
									if(null != planStatus) {
										// 更新计划状态
										InspectionplanVO updatePlan = new InspectionplanVO();
										updatePlan.setJhId(planId);
										updatePlan.setJhzt(planStatus);
										ResponseWrapper planResult = inspectionplanFeign.updateInspectionplanonly(updatePlan);
									}
								}
							}
						}
					});
				}
			}
		}
		Log.info("===============  Execute 制定任务超期扫描任务数据结束！=============" + new Date());
	}

	/**
     * 判断日期是否在指定范围内
     *
     * @param date  需要比较的时间
     * @param date1 开始时间
     * @param date2 结束时间
     * @return true -在 ; false-不在;
     */
    //时间比较
    public static boolean dateCompare(Date date, Date date1, Date date2) {
        //是否在指定区间
        boolean isInRange = false;
        //转化数字
        long timeOne = date.getTime();
        long timeTwo = date1.getTime();
        long timeThree = date2.getTime();
        //在指定区间
        if (timeOne >= timeTwo && timeOne <= timeThree) {
            isInRange = true;
        }
        return isInRange;
    }

    public void main(String[] args) {
    	updatePlanStatus();
    }
}
