package com.unis.inspection.schedule;

import java.util.List;
import java.util.Set;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultByPlanShowVO;
import com.unis.inspectiontask.client.TaskFeign;

/**
 * 
 * @Description：检查计划定时任务
 * @author：王帅
 * @date: 2020年1月10日 下午2:51:50
 */
@Component
public class InspectionPlanSchedule {

	@Autowired
	private InspectionplanFeign inspectionplanFeign;

	@Autowired
	private DailyCheckResultApi dailyCheckResultApi;

	@Autowired
	private TaskFeign taskFeign;

	/**
	 * 
	 * @Description: 修改计划状态->所有子任务完成后修改计划为已完成(每五分钟执行一次)
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
//	@Scheduled(cron = "0 0/5 * * * ?")
	public void updatePlanStatus() {
		// 获取执行中的计划总数
		ResponseEntity<JSONObject> result = inspectionplanFeign.getPlanUnfinishedCount(InspectionConstant.PLAN_IN_PROGRESS_STATUS);
		Long count = 0L;
		if (!ObjectUtils.isEmpty(result) && HttpStatus.OK.value() == result.getStatusCodeValue()) {
			JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(result.getBody()));
			count = jsonObj.getLong("count");
		}
		// 计划数大于零，则执行查询当前状态下计划列表详情
		if (count > 0) {
			long pageSize = 20;
			long xunhuancishu = count / pageSize;
			if (count % pageSize > 0) {
				xunhuancishu = xunhuancishu + 1;
			}
			for (int i = 0; i < xunhuancishu; i++) {
				// 分页查询执行中的计划 状态为2则为执行中
				ResponseEntity<List<InspectionplanVO>> resultList = inspectionplanFeign.planUnfinishedList(Integer.valueOf(pageSize + ""), i + 1,
						InspectionConstant.PLAN_IN_PROGRESS_STATUS);
				if (!ObjectUtils.isEmpty(resultList) && HttpStatus.OK.value() == resultList.getStatusCodeValue()) {
					JSONArray arr = JSON.parseArray(JsonUtils.serialize(resultList.getBody()));
					arr.stream().forEach((obj) -> {
						InspectionplanVO planVO = JsonUtils.parse(JsonUtils.serialize(obj), InspectionplanVO.class);
						String planId = planVO.getJhId();
						if (StringUtils.isNotEmpty(planId)) {
							// 查询当前计划下的检查任务
							ResponseEntity<List<DailyCheckResultByPlanShowVO>> showVOObj = dailyCheckResultApi
									.getCheckResultListByPlanId(planId);
							if (!ObjectUtils.isEmpty(showVOObj)
									&& HttpStatus.OK.value() == showVOObj.getStatusCodeValue()) {
								List<DailyCheckResultByPlanShowVO> showVOList = (List<DailyCheckResultByPlanShowVO>) showVOObj
										.getBody();
								// 判断当前计划下的任务是否都已完成
								if (CollectionUtils.isNotEmpty(showVOList)) {
									List<String> statusList = Lists.newArrayList();
									Set<String> taskIds = Sets.newHashSet();
									showVOList.stream().forEach(checkResult -> {
										String status = checkResult.getJgTbbh();
										// 状态码为12 则表示任务已完成
										if (StringUtils.isNotEmpty(status) && InspectionConstant.INSPECTION_RESULTS_COMPLETED_STATUS.equals(status)) {
											statusList.add(status);
											String taskId = checkResult.getRwId();
											if (StringUtils.isNotEmpty(taskId)) {
												taskIds.add(taskId);
											}
										}
									});
									// 当前计划子任务都为已完成状态
									if (showVOList.size() == statusList.size()) {
										System.out.println("执行更新计划状态->计划名称：" + planVO.getJhName() + "  计划主键：" + planId);
										// 更新计划状态
										InspectionplanVO updatePlan = new InspectionplanVO();
										updatePlan.setJhId(planId);
										updatePlan.setJhzt(InspectionConstant.PLAN_AND_TASK_FINISHED_STATUS);
										ResponseWrapper planResult = inspectionplanFeign
												.updateInspectionplanonly(updatePlan);
										// 更新任务状态为已完成->状态3表示已完成
										if (planResult.isSuccess() && CollectionUtils.isNotEmpty(taskIds)) {
											taskIds.stream().forEach(id -> {
												taskFeign.inspectionTaskUpdateByEntity(id, InspectionConstant.PLAN_AND_TASK_FINISHED_STATUS);
											});
										}
									}
								}
							}
						}
					});
				}
			}
		}
	}
}
