package com.unis.inspection.service;

import java.util.List;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.common.vo.DesignatedQueryVO;
import com.unis.inspectiontask.common.vo.RandomQueryVO;
import com.unis.inspectiontask.common.vo.TaskVO;
import com.unis.inspectiontask.common.vo.TeamVO;

import io.swagger.annotations.ApiOperation;

/**
 * @ClassName: InspectionGroupService
 * @Description: 检查组抽取，查询，保存service
 * @author LiuFeng
 * @date 2019年8月28日 下午4:12:28
 */
public interface InspectionGroupService {

	/**
	 * @Title: getDoubleRandom
	 * @Description: 检查组双随机抽取
	 * @param @param designatedQueryVOs
	 * @param @return
	 * @return List<TeamVO>
	 * @throws
	 */
	ResponseWrapper getDoubleRandom(RandomQueryVO randomQueryVO);

	/**
	 * @Title: getDesignated
	 * @Description: 检查单位指定抽取
	 * @param @param designatedQueryVOs
	 * @param @return
	 * @return List<TeamVO>
	 * @throws
	 */
	ResponseWrapper getDesignated(List<DesignatedQueryVO> designatedQueryVOs);

	/**
	 * @Title: saveInspectionTeams
	 * @Description: 检查组信息保存
	 * @param teamVOs
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper saveInspectionTeams(List<TeamVO> teamVOs);

	/**
	 * @Title: getInspectionTeamList
	 * @Description: 根据任务编号查村检查组列表
	 * @param taskId 任务编号
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper getInspectionTeamList(String taskId);

	/**
	 * @Title: getInspectionUnit
	 * @Description: 根据用户获取被检单位列表
	 * @param userId
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper getInspectionUnit(String userId);

	/**
	 * @Title: getPersonInfo
	 * @Description: 根据人员编号获取人才库信息
	 * @param rybh
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper getPersonInfo(String rybh);

	/**
	 * @Title: getPersonList
	 * @Description:根据用户姓名查询人才库列表
	 * @param rymc
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper getPersonList(String rymc);

	/**
	 *
	 * @Description: 根据检查类型查询人员列表
	 * @author: 王帅
	 * @param: @param  type
	 * @param: @return 参数
	 * @return: ResponseWrapper 返回类型
	 */
	ResponseWrapper selectPersonListByType(String type, String rymc);

	/**
	 * @Title: updateInspectionTeams
	 * @Description:
	 * @param 更新检查组信息
	 * @return ResponseWrapper
	 * @throws
	 */
	ResponseWrapper updateInspectionTeams(List<TeamVO> teamVOs);

	/**
	 * 拼接子表数据
	 * @param rybh
	 * @param rwlx
	 * @return
	 */
	List<TaskVO> getTaskListMore(String rybh, String rwlx);

	TaskVO getTaskListMoreDetail(String rwid, String jhid);

	/**
	 * @param teamVOs
	 * @return
	 */
	ResponseWrapper saveInspectionPlanTeams(List<TeamVO> teamVOs);
}
