/*
 * DailyCheckResultController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-26 16:21:29 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspection.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.esotericsoftware.minlog.Log;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.unis.common.utils.*;
import com.unis.inspection.app.client.DataDictionaryFeign;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspection.app.vo.DataDictionaryDO;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspection.service.DailyCheckResultService;
import com.unis.inspection.service.InspectionGroupService;
import com.unis.inspection.service.InspectionTaskService;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.InspectionUnitVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.vo.AppVO;
import com.unis.inspectionresult.common.vo.base.PageResult;
import com.unis.inspectionresult.common.vo.resultback.*;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.client.TeamFeign;
import com.unis.inspectiontask.common.constant.TaskStatusConstant;
import com.unis.inspectiontask.common.vo.*;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * T_JCJG-检查结果
 *
 * @author lipenghe at 2019-08-26 16:21:29
 */
@Service
public class DailyCheckResultServiceImpl implements DailyCheckResultService {
    @Autowired
    private DailyCheckResultApi dailyCheckResultApi;

    @Autowired
    private InspectionplanFeign inspectionplanFeign;

    @Autowired
    private InspectionTaskService inspectionTaskService;

    @Autowired
    private InspectionTaskService InspectionTaskService;

    @Autowired
    private InspectionGroupService inspectionGroupService;

    @Autowired
    private TeamFeign teamFeign;

    @Autowired
    private DataDictionaryFeign dataDictionaryFeign;

    @Autowired
    private TaskFeign taskFeign;

    @Autowired
    private MyUserClient userClient;

    private ObjectMapper objectMapper = new ObjectMapper();

    private static final Integer INDIVIDUAL = 0;//检查项目类型：单项检查
    private static final Integer COMPREHENSIVE = 1;//检查项目类型：综合检查

    /**
     * 公用封装方法
     */
    public void getObjectMapperMethods() {
        // 序列化的时候序列对象的所有属性
        objectMapper.setSerializationInclusion(JsonInclude.Include.ALWAYS);
        // 反序列化的时候如果多了其他属性,不抛出异常
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        // 如果是空对象的时候,不抛异常
        objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
    }

    public ResponseWrapper insertEntitySelective(DailyCheckResultVO checkResultVO) {
        //通过前段传递的类型限制,又有什么作用呢
        if (checkResultVO.getType() == 1) {
            ResponseWrapper response = teamFeign.getInspectionTeam(checkResultVO.getRwId(), checkResultVO.getBjdwId());
            if (response.isSuccess()) {
                TeamVO teamVO = JsonUtils.parse(JsonUtils.serialize(response.getData()), TeamVO.class);
                if (teamVO != null) {
                    List<MemberVO> list = teamVO.getMembers();
                    int size = 0;
                    if (list != null && (size = list.size()) > 0) {
                        List<String> orgList = list.stream().map(MemberVO::getZyks).collect(Collectors.toList());
                        //不是当前的检查组,不允许添加
                        if (!orgList.contains(CurrentUtil.getOrgId())) {
                            return ResponseWrapper.error("不能处理非当前检查组的任务");
                        }
                    }
                }
            }
        } else if (checkResultVO.getType() == 2) {

        }
        if (StringUtils.isEmpty(checkResultVO.getJhid()) && StringUtils.isEmpty(checkResultVO.getRwId())) {

            InspectionplanVO planVO = new InspectionplanVO();
            planVO.setStatus(1);
            planVO.setCreateDate(new Date());
            planVO.setRefreshDate(new Date());
            planVO.setCreateor(CurrentUtil.getUserName());
            planVO.setRefresher(CurrentUtil.getUserName());
            planVO.setOrgId(CurrentUtil.getOrgId());
            planVO.setJcdw(checkResultVO.getJcdwmc());
            planVO.setJcdwId(checkResultVO.getJcdwId());
            planVO.setOrgId(CurrentUtil.getOrgId());
            planVO.setRwlxId(checkResultVO.getRwlxId());
            planVO.setRwlxmc(checkResultVO.getRwlxMc());
            planVO.setXfr(CurrentUtil.getUserName());
            planVO.setXfsj(new Date());
            planVO.setJhName(checkResultVO.getRwmc());
            planVO.setJhzt(2);
            planVO.setRwqsr(checkResultVO.getJckssj());
            planVO.setRwjsr(checkResultVO.getJcjssj());
            planVO.setIsBjjcz(0);

            List<InspectionUnitVO> jcdwList = new ArrayList<>();
            InspectionUnitVO inspectionUnitVO = new InspectionUnitVO();
            inspectionUnitVO.setJcdwId(checkResultVO.getJcdwId());
            inspectionUnitVO.setJcdwName(checkResultVO.getJcdwmc());
            jcdwList.add(inspectionUnitVO);
            planVO.setJcdwList(jcdwList);

            TaskVO taskVO = checkResultVO.getTaskVO();
            List<TaskFormVO> taskFormVO = taskVO.getTaskFormVO();
            if (taskFormVO != null) {
                List<CheckformVO> jcbd = JsonUtils.parseList(JsonUtils.serialize(taskFormVO), CheckformVO.class);
                planVO.setJcbd(jcbd);
            }


            ResponseWrapper responseWrapper = inspectionplanFeign.insert(planVO);
            if (responseWrapper.isSuccess()) {
                InspectionplanVO inspectionplanVO = JsonUtils.parse(JsonUtils.serialize(responseWrapper.getData())
                        , InspectionplanVO.class);
                if (inspectionplanVO != null) {
                    taskVO.setJhId(inspectionplanVO.getJhId());

                    taskVO.setJcdwId(checkResultVO.getJcdwId());
                    taskVO.setJcdwmc(checkResultVO.getJcdwmc());
                    taskVO.setJczqdfs(0);
                    taskVO.setSffp(0);
                    taskVO.setRwZt(2);
                    taskVO.setXfTime(checkResultVO.getJgTjsj());
                    //日常检查的其他类型,无计划id和任务id
                   /* taskVO.setRwName(checkResultVO.getRwmc());
                    taskVO.setRwlx(checkResultVO.getRwlxId());
                    taskVO.setRwlxName(checkResultVO.getRwlxMc());
                    taskVO.setJcdwId(checkResultVO.getJcdwId());
                    taskVO.setJcdwmc(checkResultVO.getJcdwmc());
                    TaskVO tskTemp=checkResultVO.getTaskVO();
                    if(tskTemp!=null){
                        taskVO.setTeamVOs(tskTemp.getTeamVOs());
                    }
                    taskVO.setJcjssjDate(checkResultVO.getJcjssj());
                    taskVO.setJckssjDate(checkResultVO.getJckssj());
                    taskVO.setJcfs(checkResultVO.getJcfs());
                    taskVO.setJczqdfs(0);
                    taskVO.setSffp(0);
                    taskVO.setRwZt(2);*/
                    ResponseWrapper rwIdMaxCodeResponse = taskFeign.inspectionTaskMaxCodeById(taskVO.getJhId());
                    if (rwIdMaxCodeResponse.getInfoCode() == 200 && rwIdMaxCodeResponse.getData() != null) {
                        taskVO.setRwId(objectMapper.convertValue(rwIdMaxCodeResponse.getData(), String.class));
                        //保存计划
                        taskFeign.inspectionTaskSave(taskVO);

                        for (TeamVO team : taskVO.getTeamVOs()) {
                            team.setRwId(taskVO.getRwId());
                            team.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                        }
                        //保存检查组
                        ResponseWrapper resp = teamFeign.saveInspectionPlanTeams(taskVO.getTeamVOs());

                        //检查结果表单
                        List<DailyCheckResultDetailVO> detailList = new ArrayList<DailyCheckResultDetailVO>();
                        //获取任务检查表单
                        if (taskFormVO != null) {
                            for (TaskFormVO taskFormVOList : taskFormVO) {
                                DailyCheckResultDetailVO dailyCheckResultDetailVO = new DailyCheckResultDetailVO();
                                dailyCheckResultDetailVO.setBdId(taskFormVOList.getBdId());
                                dailyCheckResultDetailVO.setBdName(taskFormVOList.getBdName());
                                dailyCheckResultDetailVO.setBdLu(taskFormVOList.getBdLu());
                                detailList.add(dailyCheckResultDetailVO);
                            }
                        }
                        checkResultVO.setDetailList(detailList);

                        checkResultVO.setJhid(taskVO.getJhId());
                        checkResultVO.setRwId(taskVO.getRwId());
                        ResponseWrapper resWrapper = dailyCheckResultApi.insertEntitySelective(checkResultVO);
                        return resWrapper;
                    }
                }
            }
            return ResponseWrapper.error("保存失败");
        } else {
            ResponseWrapper responseWrapper = dailyCheckResultApi.insertEntitySelective(checkResultVO);
            return responseWrapper;
        }
    }

    public ResponseWrapper selectPageByEntityForKSH(int pageNum, int pageSize, DailyCheckSearchVO dailyCheckSearchVO) {
        ResponseWrapper responseWrapper = dailyCheckResultApi.dailyCheckResultPageForKSH(pageNum, pageSize, dailyCheckSearchVO);
        return responseWrapper;
    }

    public ResponseWrapper selectPageByEntity(int pageNum, int pageSize, DailyCheckResultVO checkResultVO) {
        // 日常检查
        // 是否可修改 限定条件->检查组成员
        // 列表查看权限->1：检查组成员（任务派发和新增数据） 2：当前登录用户所在部门所有用户（任务制定人所在部门）
        // 权限->当前部门下所有人员相关的任务都要展示，不是检查组成员就不能编辑
        Set<String> taskIds = Sets.newHashSet();
        String departmentId = CurrentUtil.getDeptId();
        String userId = CurrentUtil.getUserId();
        StringBuilder userIdStr = new StringBuilder();
        userIdStr.append(userId);
        if (StringUtils.isNotEmpty(departmentId)) {
            JSONObject obj = new JSONObject();
            obj.put("deptCode", departmentId);
            ResponseWrapper result = userClient.findByDeptCode(obj, 1, 10000);
            if (result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
                Object content = result.getData();
                JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(content));
                JSONArray jsonArray = jsonObj.getJSONArray("content");
                if (CollectionUtils.isNotEmpty(jsonArray)) {
                    List<String> makers = Lists.newArrayList();
                    jsonArray.stream().forEach(member -> {
                        JSONObject memberObj = (JSONObject) member;
                        String userCode = memberObj.getString("userCode");
                        if (StringUtils.isNotEmpty(userCode)) {
                            makers.add(userCode);
                            userIdStr.append("," + userCode);
                        }
                    });
                    ResponseWrapper taskResult = taskFeign.getTaskIdsByMakers(makers);
                    if (taskResult.isSuccess() && !ObjectUtils.isEmpty(taskResult.getData())) {
                        Object taskIdsObj = taskResult.getData();
                        JSONArray arr = JSON.parseArray(JsonUtils.serialize(taskIdsObj));
                        arr.stream().forEach(taskId -> {
                            taskIds.add((String) taskId);
                        });
                    }
                }
            }
        }
        ResponseWrapper teamResult = teamFeign.getTaskIdsListByMemberId(userIdStr.toString());
        Set<String> taskIdsByUserId = Sets.newHashSet();
        if (teamResult.isSuccess() && !ObjectUtils.isEmpty(teamResult.getData())) {
            Object teamObj = teamResult.getData();
            JSONArray arr = JSON.parseArray(JsonUtils.serialize(teamObj));
            arr.stream().forEach(taskId -> {
                taskIdsByUserId.add((String) taskId);
                taskIds.add((String) taskId);
            });
        }
        //监管区域数据
        ResponseWrapper territorialSupervisionResult = dailyCheckResultApi.getTerritorialSupervisionByOrgId(CurrentUtil.getOrgId());
        Object territorialSupervisionObj = territorialSupervisionResult.getData();
        Set<String> territorialSupervisionSet = Sets.newHashSet();
        if (territorialSupervisionResult.isSuccess() && !ObjectUtils.isEmpty(territorialSupervisionObj)) {
            JSONArray arr = JSON.parseArray(JsonUtils.serialize(territorialSupervisionObj));
            arr.stream().forEach(record -> {
                DailyCheckTerritorialSupervisionVO showVO = JsonUtils.parse(JsonUtils.serialize(record), DailyCheckTerritorialSupervisionVO.class);
                String resultId = showVO.getJgId();
                if (StringUtils.isNotEmpty(resultId)) {
                    territorialSupervisionSet.add(resultId);
                }
            });
        }
        if (CollectionUtils.isNotEmpty(taskIds)) {
            checkResultVO.setTaskIds(taskIds);
        } else {
            checkResultVO.setTaskIds(null);
        }
        if (CollectionUtils.isEmpty(taskIdsByUserId)) {
            checkResultVO.setTeamTaskIds(null);
        } else {
            checkResultVO.setTeamTaskIds(taskIdsByUserId);
        }
        //检查结果数据集
        if (CollectionUtils.isNotEmpty(territorialSupervisionSet)) {
            checkResultVO.setResultIds(territorialSupervisionSet);
        }
        checkResultVO.setTeamMember("\"zyId\":\"" + CurrentUtil.getUserId() + "\"");
        ResponseWrapper response = dailyCheckResultApi.selectPageByEntity(pageNum, pageSize, checkResultVO);
        Object obj = response.getData();
        // 添加检查组
        if (response.isSuccess() && !ObjectUtils.isEmpty(obj)) {
            JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(obj));
            JSONArray items = jsonObj.getJSONArray("items");
            long total = jsonObj.getLongValue("total");
            int totalPage = jsonObj.getIntValue("totalPage");
            int currentPage = jsonObj.getIntValue("currentPage");
            if (CollectionUtils.isNotEmpty(items)) {
                List<DailyCheckResultListVO> list = Lists.newArrayList();
                items.forEach(item -> {
                    DailyCheckResultListVO listVO = JsonUtils.parse(JsonUtils.serialize(item),
                            DailyCheckResultListVO.class);
                    String taskId = listVO.getRwId();
                    TaskVO taskVO = new TaskVO();
					/*try {
						taskVO = inspectionTaskService.getTaskInfo(taskId, listVO.getJhid());
					} catch (Exception e) {
						e.printStackTrace();
					}*/
                    try {
                        ResponseWrapper wrapper = teamFeign.getInspectionTeam(taskId, listVO.getBjdwId());
                        if (wrapper.isSuccess()) {
                            Object teamObj = wrapper.getData();
                            TeamVO teamVO = null;
							/*if (ObjectUtils.isEmpty(teamObj)) {
								if (null != taskVO) {
									List<TeamVO> teamVOList = taskVO.getTeamVOs();
									for (TeamVO vo : teamVOList) {
										List<MemberVO> memberList = vo.getMembers();
										if (CollectionUtils.isNotEmpty(memberList)) {
											for (MemberVO member : memberList) {
												String memberId = member.getZyId();
												if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)
														&& userId.equals(memberId)) {
													int memberType = member.getZylx();
													if(0 == memberType) {
														listVO.setIsTeamLeader(true);
													}
													teamVO = vo;
													break;
												}
											}
										}
									}
								}
							} else {
								teamVO = JsonUtils.parse(JsonUtils.serialize(teamObj), TeamVO.class);
								List<MemberVO> memberList = teamVO.getMembers();
								if (CollectionUtils.isNotEmpty(memberList)) {
									for (MemberVO member : memberList) {
										String memberId = member.getZyId();
										if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)
												&& userId.equals(memberId)) {
											int memberType = member.getZylx();
											if(0 == memberType) {
												listVO.setIsTeamLeader(true);
											}
											break;
										}
									}
								}
							}*/
                            if (!ObjectUtils.isEmpty(teamObj)) {
                                teamVO = JsonUtils.parse(JsonUtils.serialize(teamObj), TeamVO.class);
                                List<MemberVO> memberList = teamVO.getMembers();
                                if (CollectionUtils.isNotEmpty(memberList)) {
                                    boolean isMember = false;
                                    for (MemberVO member : memberList) {
                                        String memberId = member.getZyId();
                                        if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)
                                                && userId.equals(memberId)) {
                                            isMember = true;
                                            int memberType = member.getZylx();
                                            if (0 == memberType) {
                                                listVO.setIsTeamLeader(true);
                                                break;
                                            }
                                        }
                                    }
                                    listVO.setRevisable(isMember ? 1 : 0);
                                }
                            }
                            listVO.setTeamVO(teamVO);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                    String teamVO = listVO.getJczcy();
                    if (StringUtils.isNotEmpty(taskId) && StringUtils.isNotEmpty(teamVO)) {
                        TeamVO team = com.unis.inspectionresult.common.utils.JsonUtils.parse(JsonUtils.serialize(teamVO), TeamVO.class);
                        if (team != null) {
                            List<MemberVO> memberList = team.getMembers();
                            //LPH修改,添加权限判断
                            boolean isMember = false;
                            if (CollectionUtils.isNotEmpty(memberList)) {
                                for (MemberVO member : memberList) {
                                    String memberId = member.getZyId();
                                    if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)) {
                                        if (userId.equals(memberId)) {
                                            int memberType = member.getZylx();
                                            isMember = true;
                                            if (0 == memberType) {
                                                listVO.setIsTeamLeader(true);
                                                break;
                                            }
                                        }
                                    }
                                }
                            }
                            listVO.setRevisable(isMember ? 1 : 0);
                            listVO.setTeamVO(team);
                        }
                    }
                    //添加监管区域
                    String jgqy = listVO.getJgqy();
                    if (StringUtils.isNotEmpty(jgqy)) {
                        listVO.setJgqyObj(JSON.parseObject(JsonUtils.serialize(jgqy)));
                    }
                    list.add(listVO);
                });
                PageResult<DailyCheckResultListVO> checkResultListVOPageResult = new PageResult<>(total, totalPage, currentPage, list);
                return ResponseWrapper.success(checkResultListVOPageResult);
            }
        }
        return response;
    }


    public ResponseWrapper selectTeamPageByEntity(int pageNum, int pageSize, DailyCheckResultVO checkResultVO) {
        //检查组
        ResponseWrapper responseWrapper = teamFeign.getInspectionUnit(CurrentUtil.getUserId());
        if (responseWrapper.isSuccess()) {
            List<OrganizeVO> organizeVOList = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData())
                    , OrganizeVO.class);
            if (organizeVOList != null) {
                checkResultVO.setBjdwList(organizeVOList.stream().map(OrganizeVO::getBjdwId).collect(Collectors.toList()));
            }
            responseWrapper = dailyCheckResultApi.selectTeamPageByEntity(pageNum, pageSize, checkResultVO);
            if (responseWrapper.isSuccess() && !ObjectUtils.isEmpty(responseWrapper.getData())) {
                Object obj = responseWrapper.getData();
                JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(obj));
                JSONArray jsonArr = jsonObj.getJSONArray("items");
                if (CollectionUtils.isNotEmpty(jsonArr)) {
                    PageResult<DailyCheckResultListVO> pageResult = new PageResult<DailyCheckResultListVO>();
                    List<DailyCheckResultListVO> list = Lists.newArrayList();
                    jsonArr.forEach(item -> {
                        DailyCheckResultListVO checkResult = JsonUtils.parse(JsonUtils.serialize(item), DailyCheckResultListVO.class);
                        TaskVO taskVO = inspectionTaskService.getTaskInfo(checkResult.getRwId(), checkResult.getJhid());
                        checkResult.setTaskVO(taskVO);
                        list.add(checkResult);
                    });
                    pageResult.setTotal(jsonObj.getLong("total"));
                    pageResult.setCurrentPage(pageNum);
                    pageResult.setTotalPage(jsonObj.getInteger("totalPage"));
                    pageResult.setItems(list);
                    return ResponseWrapper.success(pageResult);
                }
            }
            return responseWrapper;
        }
        return ResponseWrapper.error("请分配检查组");
    }

    @Override
    public PageInfo getDailyCheckResultPageList(String rybh, int pageNum, int pageSize) throws IOException {
        this.getObjectMapperMethods();
        DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
        PageInfo<DailyCheckResultVO> pageInfo = new PageInfo<>();
        List<DailyCheckResultVO> taskVOList = new ArrayList<>();
        ResponseWrapper list = teamFeign.getTaskList(rybh);
        List<TaskVO> parseList = JsonUtils.parseList(JsonUtils.serialize(list.getData()), TaskVO.class);
//            int total = 0;
        List<DailyCheckResultVO> listData = new ArrayList<>();
        for (TaskVO taskVO : parseList) {
            dailyCheckResultVO.setRwId(taskVO.getRwId());
            ResponseWrapper responseWrapper = dailyCheckResultApi.selectPageByEntity(pageNum, pageSize, dailyCheckResultVO);
            LinkedHashMap pageInfoMap = (LinkedHashMap) responseWrapper.getData();
//                total += (Integer) pageInfoMap.get("total");
            List<DailyCheckResultVO> items = (List<DailyCheckResultVO>) pageInfoMap.get("items");
            listData.addAll(items);
        }
        return Pager(pageNum, pageSize, listData);
    }

    /**
     * 检查工作开展情况统计
     *
     * @param developmentSituationQueryVO
     * @return
     */
    @Override
    public ResponseWrapper developmentSituationList(DevelopmentSituationQueryVO developmentSituationQueryVO) {
        Map<String, DevelopmentSituationVO> developmentSituationMap = new HashMap<>();
        List<String> dictCodeList = this.getDataDictionary();
//        String year = DateUtil.getYearString().toString();
//        String month = DateUtil.getMonthString().toString();
        String[] mo = developmentSituationQueryVO.getTjsj().split("-");
        //当前年累计时间
        if (StringUtils.isEmpty(developmentSituationQueryVO.getJcksDate()) && StringUtils.isEmpty(developmentSituationQueryVO.getJcjsDate())) {
            developmentSituationQueryVO.setJcksDate(mo[0] + "-01-01");
            developmentSituationQueryVO.setJcjsDate(DateUtil.getDateFormat(new Date(), "yyyy-MM-dd"));
        }
        //当前月查询时间
        DevelopmentSituationQueryVO monthDevelopmentSituationQuery = new DevelopmentSituationQueryVO();
        LsBeanUtils.copyAllProperties(developmentSituationQueryVO, monthDevelopmentSituationQuery);
//        if (mo[1].length() > 1){
        monthDevelopmentSituationQuery.setJcksDate(developmentSituationQueryVO.getTjsj() + "-01");
//        } else {
//            monthDevelopmentSituationQuery.setJcksDate(year+"-0"+mo[1]+"-01");
//        }
        monthDevelopmentSituationQuery.setJcjsDate(developmentSituationQueryVO.getTjsj() + "-32");
        //记录总计检查内容
        List<DevelopmentSituationVO> totalDevelopmentSituationList = new ArrayList<>();
        DevelopmentSituationVO totalSituation = new DevelopmentSituationVO(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
        //记录单项检查内容数据
        List<DevelopmentSituationVO> subtotalDevelopmentSituationList = new ArrayList<>();
        DevelopmentSituationVO subtotalSituation = new DevelopmentSituationVO(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
        //单项检查内容
        if (dictCodeList != null && dictCodeList.size() > 0) {
            for (String dictCode : dictCodeList) {
                DevelopmentSituationVO yearIndividual = this.getDevelopmentSituation(developmentSituationQueryVO, dictCode, INDIVIDUAL);
                DevelopmentSituationVO monthIndividual = this.getDevelopmentSituation(monthDevelopmentSituationQuery, dictCode, INDIVIDUAL);
                DevelopmentSituationVO individual = this.updateDevelopmentSituation(yearIndividual, monthIndividual);
                developmentSituationMap.put(dictCode, individual);
                subtotalDevelopmentSituationList.add(individual);
            }
            if (subtotalDevelopmentSituationList != null && subtotalDevelopmentSituationList.size() > 0) {
                for (DevelopmentSituationVO oldSituation : subtotalDevelopmentSituationList) {
                    subtotalSituation = this.sumDevelopmentSituation(oldSituation, subtotalSituation);
                }
            }
        }
        developmentSituationMap.put("小计", subtotalSituation);
        totalDevelopmentSituationList.add(subtotalSituation);
        //综合检查内容
        developmentSituationQueryVO.setDxjcnr(null);
        monthDevelopmentSituationQuery.setDxjcnr(null);
        DevelopmentSituationVO yearComprehensive = this.getDevelopmentSituation(developmentSituationQueryVO, null, COMPREHENSIVE);
        DevelopmentSituationVO monthComprehensive = this.getDevelopmentSituation(monthDevelopmentSituationQuery, null, COMPREHENSIVE);
        DevelopmentSituationVO comprehensive = this.updateDevelopmentSituation(yearComprehensive, monthComprehensive);
        developmentSituationMap.put("综合检查", comprehensive);
        totalDevelopmentSituationList.add(comprehensive);
        if (totalDevelopmentSituationList != null && totalDevelopmentSituationList.size() > 0) {
            for (DevelopmentSituationVO developmentSituation : totalDevelopmentSituationList) {
                totalSituation = this.sumDevelopmentSituation(developmentSituation, totalSituation);
            }
        }
        developmentSituationMap.put("总计", totalSituation);
        return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), developmentSituationMap);
    }

    public ResponseWrapper selectById(DailyCheckResultVO checkResultVO) {
        ResponseWrapper responseWrapper = dailyCheckResultApi.selectById(checkResultVO);
        if (responseWrapper.isSuccess()) {
            DailyCheckResultShowVO resultShowVO = JsonUtils.parse(JsonUtils.serialize(responseWrapper.getData())
                    , DailyCheckResultShowVO.class);
            String taskId = resultShowVO.getRwId();
            if (resultShowVO != null && StringUtils.isNotEmpty(taskId)) {
                TaskVO taskVO = null;
                try {
                    taskVO = inspectionTaskService.getTaskInfo(resultShowVO.getRwId(), resultShowVO.getJhid());
                    resultShowVO.setTaskVO(taskVO);
                } catch (Exception e) {
                    e.printStackTrace();
                }

                try {
                    ResponseWrapper wrapper = teamFeign.getInspectionTeam(resultShowVO.getRwId(), resultShowVO.getBjdwId());
                    if (wrapper.isSuccess()) {
                        Object obj = wrapper.getData();
                        TeamVO teamVO = null;
                        if (ObjectUtils.isEmpty(obj)) {
                            String userId = CurrentUtil.getUserId();
                            if (null != taskVO) {
                                List<TeamVO> teamVOList = taskVO.getTeamVOs();
                                for (TeamVO vo : teamVOList) {
                                    List<MemberVO> memberList = vo.getMembers();
                                    if (CollectionUtils.isNotEmpty(memberList)) {
                                        for (MemberVO member : memberList) {
                                            String memberId = member.getZyId();
                                            if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId) && userId.equals(memberId)) {
                                                teamVO = vo;
                                                break;
                                            }
                                        }
                                    }
                                }
                            }
                        } else {
                            teamVO = JsonUtils.parse(JsonUtils.serialize(obj), TeamVO.class);
                        }
                        resultShowVO.setTeamVO(teamVO);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            String teamVO = resultShowVO.getJczcy();
            if (StringUtils.isEmpty(taskId) && StringUtils.isNotEmpty(teamVO)) {
                TeamVO team = com.unis.inspectionresult.common.utils.JsonUtils.parse(JsonUtils.serialize(teamVO), TeamVO.class);
                resultShowVO.setTeamVO(team);
            }
            return ResponseWrapper.success(resultShowVO);
        }
        return responseWrapper;
    }

    public void dataCallBackOnFinish(ResponseWrapper responseWrapper) {
        if (responseWrapper.isSuccess()) {
            DailyCheckResultVO checkResultVO = JsonUtils.parse(
                    JsonUtils.serialize(responseWrapper.getData()), DailyCheckResultVO.class);
            String rwId = checkResultVO.getRwId();

            if (checkResultVO != null && checkResultVO.getCallBackOnFinish() != null
                    && checkResultVO.getCallBackOnFinish()) {
                ResponseWrapper responseTask = taskFeign.inspectionTaskUpdateByEntity(rwId, Integer.valueOf(TaskStatusConstant.DOSAVE.getValue()));
                if (responseTask.isSuccess()) {
                    System.out.println("任务完成");
                    //优先改任务
                    ResponseWrapper respon = taskFeign.inspectionPlanList(checkResultVO.getJhid());
                    if (respon.isSuccess() && respon.getData() != null) {
                        List<TaskPlanVo> taskList = JsonUtils.parseList(JsonUtils.serialize(respon.getData()), TaskPlanVo.class);
                        boolean goNext = true;
                        if (taskList != null && taskList.size() > 0) {
                            for (TaskPlanVo planVO : taskList) {
                                String rwIdTemp = planVO.getRwId();
                                if (!rwIdTemp.equals(rwId)) {
                                    if (planVO.getRwZt() == null ||
                                            (planVO.getRwZt() != Integer.valueOf(TaskStatusConstant.DOSAVE.getValue())
                                                    && planVO.getRwZt() != Integer.valueOf(TaskStatusConstant.ARTIMESAVE.getValue())
                                                    && planVO.getRwZt() != Integer.valueOf(TaskStatusConstant.ARGOD.getValue())
                                                    && planVO.getRwZt() != Integer.valueOf(TaskStatusConstant.STOP.getValue())
                                            )) {
                                        goNext = false;
                                    }
                                }
                            }
                            if (goNext) {
                                //ResponseWrapper responseTask=taskFeign.inspectionTaskUpdateByEntity(rwId, Integer.valueOf(TaskStatusConstant.DOSAVE.getValue()));
                                //if(responseTask.isSuccess()){
                                //System.out.println("任务完成");
                                //此处是改计划
                                //全部结果已经完成,调用任务接口回调
                                ResponseWrapper resp = InspectionTaskService.inspectionTaskFinish(checkResultVO.getJhid(), Integer.parseInt(TaskStatusConstant.DOSAVE.getValue()));
                                if (resp.isSuccess()) {
                                    System.out.println("计划完成");
                                } else {
                                    System.out.println("计划完成出现错误");
                                }
                                /*}else{
                                    System.out.println("任务完成出现错误");
                                }*/
                            }
                        }
                    }
                } else {
                    System.out.println("任务完成出现错误");
                }
            }
        }
    }

    public void fillAppVO(String checkResultStatus, String taskTypeId, AppVO appVO) {
        if ("5000110".equals(taskTypeId)) {
            //日常检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000110");
                    appVO.setAction("待检查");
                    break;
                case "17":       //区粮办办结处理
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("区粮办办结处理");
                    break;
                case "23":       //办结处理
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("办结处理");
                    break;
                case "18":       //组长审批
                    appVO.setIspad("1");
                    appVO.setTyname("REVIEW-5000110");
                    appVO.setAction("组长审批");
                    break;
                case "31":       //待送达
                    appVO.setIspad("1");
                    appVO.setTyname("ACCEPT-5000110");
                    appVO.setAction("待送达");
                    break;
                default:
                    break;
            }

        } else if ("5000120".equals(taskTypeId)) {
            //防汛检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000120");
                    appVO.setAction("待检查");
                    break;
                case "1":       //待检查
                    appVO.setIspad("0");
                    appVO.setTyname("SUB-5000120");
                    appVO.setAction("被检单位盖章");
                    break;
                case "7":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("BJG-5000120");
                    appVO.setAction("检查单位盖章");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        }
        //LPH  已删除
        /*else if("5000140".equals(taskTypeId)){
            //专项检查-监督检查处
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000140");
                    appVO.setAction("待检查");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000140");
                    appVO.setAction("待验收");
                    break;
                case "31":       //待送达
                    appVO.setIspad("1");
                    appVO.setTyname("ACCEPT-5000140");
                    appVO.setAction("待送达");
                    break;
                default:
                    break;
            }
        }*/
        else if ("5000150".equals(taskTypeId)) {
            //市级储备成品粮油检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000150");
                    appVO.setAction("待检查");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000150");
                    appVO.setAction("新增");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000150");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        } else if ("5000160".equals(taskTypeId)) {
            //专项检查-粮食储备处
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000160");
                    appVO.setAction("待检查");
                    break;
                case "7":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("BJG-5000160");
                    appVO.setAction("被检单位盖章");
                    break;
                case "1":       //待检查
                    appVO.setIspad("0");
                    appVO.setTyname("SUB-5000160");
                    appVO.setAction("检查单位盖章");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000160");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        } else if ("5000170".equals(taskTypeId)) {
            //市级储备原粮检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000170");
                    appVO.setAction("待检查");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000170");
                    appVO.setAction("新增");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000170");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        } else if ("5000180".equals(taskTypeId)) {
            //安全生产检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000180");
                    appVO.setAction("待检查");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000180");
                    appVO.setAction("新增");
                    break;
                default:
                    break;
            }
        }
    }


    public static PageInfo Pager(int pageSize, int pageNum, List list) {
        PageInfo pageInfo = new PageInfo();
        int totalCount = list.size();
        int pageCount;
        int m = totalCount % pageSize;
        if (m > 0) {
            pageCount = totalCount / pageSize + 1;
        } else {
            pageCount = totalCount / pageSize;
        }
        int totalPage = totalCount % pageSize; // 一共多少页
        if (totalPage > 0) {
            totalPage = totalCount / pageSize + 1;
        } else {
            totalPage = totalCount / pageSize;
        }
        List<Integer> subList = new ArrayList<>();
        for (int i = 1; i <= pageCount; i++) {
            if (m == 0) {
                subList = list.subList((i - 1) * pageSize, pageSize * (i));
            } else {
                if (i == pageCount) {
                    subList = list.subList((i - 1) * pageSize, totalCount);
                } else {
                    subList = list.subList((i - 1) * pageSize, pageSize * i);
                }
            }
        }
        pageInfo.setTotal(totalCount);
        pageInfo.setPages(totalPage);
        pageInfo.setPageSize(pageSize);
        pageInfo.setPageNum(pageNum);
        pageInfo.setList(subList);
        return pageInfo;
    }

    /**
     * 获取字典code列表
     *
     * @return
     */
    public List<String> getDataDictionary() {
        List<String> dictCodeList = new ArrayList<>();
        ResponseWrapper responseWrapper = dataDictionaryFeign.findByGroupId("50004");
        if (responseWrapper.getInfoCode() == 200) {
            List<DataDictionaryDO> dataDictionaryList = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), DataDictionaryDO.class);
            if (dataDictionaryList != null && dataDictionaryList.size() > 0) {
                for (DataDictionaryDO dataDictionaryDO : dataDictionaryList) {

                    dictCodeList.add(dataDictionaryDO.getDictCode());
                }
            }
        }/* else {
            dictCodeList.add("5000201");
            dictCodeList.add("5000202");
            dictCodeList.add("5000203");
            dictCodeList.add("5000204");
            dictCodeList.add("5000205");
            dictCodeList.add("5000206");
            dictCodeList.add("5000207");
            dictCodeList.add("5000208");


        }*/
        return dictCodeList;
    }

    /**
     * 查询当月或累计统计次数
     *
     * @param developmentSituationQueryVO
     * @param dictCode
     * @param jcxmlx
     * @return
     */
    public DevelopmentSituationVO getDevelopmentSituation(DevelopmentSituationQueryVO developmentSituationQueryVO, String dictCode, Integer jcxmlx) {
        DevelopmentSituationVO developmentSituationVO = new DevelopmentSituationVO();
        if (dictCode != null) {
            developmentSituationQueryVO.setDxjcnr(dictCode);
        }
        if (jcxmlx != null) {
            developmentSituationQueryVO.setJcxmlx(jcxmlx);
        }
        ResponseWrapper dailyWrapper = dailyCheckResultApi.developmentSituation(developmentSituationQueryVO);
        if (dailyWrapper.getInfoCode() == 200) {
            developmentSituationVO = JsonUtils.parse(JsonUtils.serialize(dailyWrapper.getData()), DevelopmentSituationVO.class);
            ResponseWrapper rwIdListWrapper = dailyCheckResultApi.developmentSituationByRwIdList(developmentSituationQueryVO);
            if (rwIdListWrapper.getInfoCode() == 200) {
                List<String> rwIdList = JsonUtils.parseList(JsonUtils.serialize(rwIdListWrapper.getData()), String.class);
                if (rwIdList != null && rwIdList.size() > 0) {
                    ResponseWrapper countWrapper = taskFeign.getCountByRwIdList(rwIdList);
                    if (countWrapper.getInfoCode() == 200) {
                        Integer count = (Integer) countWrapper.getData();
                        developmentSituationVO.setDyjcrc(count);
                    }
                } else {
                    developmentSituationVO.setDyjcrc(0);
                }
            }
        }
        return developmentSituationVO;
    }

    /**
     * 赋值数据
     *
     * @param yearDevelopmentSituation
     * @param monthDevelopmentSituation
     * @return
     */
    public DevelopmentSituationVO updateDevelopmentSituation(DevelopmentSituationVO yearDevelopmentSituation, DevelopmentSituationVO monthDevelopmentSituation) {
        monthDevelopmentSituation.setLjjccs(yearDevelopmentSituation.getDyjccs());
        monthDevelopmentSituation.setLjjcrc(yearDevelopmentSituation.getDyjcrc());
        monthDevelopmentSituation.setLjjcgs(yearDevelopmentSituation.getDyjcgs());
        monthDevelopmentSituation.setDyjcjg(0);
        monthDevelopmentSituation.setLjjcjg(0);
        monthDevelopmentSituation.setLjjczg(yearDevelopmentSituation.getDyjczg());
        monthDevelopmentSituation.setDyjcfm(0);
        monthDevelopmentSituation.setLjjcfm(0);
        monthDevelopmentSituation.setDyjcqt(0);
        monthDevelopmentSituation.setLjjcqt(0);
        return monthDevelopmentSituation;
    }

    /**
     * 合计数据
     *
     * @param oldSituation
     * @param newSituation
     * @return
     */
    public DevelopmentSituationVO sumDevelopmentSituation(DevelopmentSituationVO oldSituation, DevelopmentSituationVO newSituation) {
        newSituation.setDyjccs(newSituation.getDyjccs() + oldSituation.getDyjccs());
        newSituation.setDyjcrc(newSituation.getDyjcrc() + oldSituation.getDyjcrc());
        newSituation.setDyjcgs(newSituation.getDyjcgs() + oldSituation.getDyjcgs());
        newSituation.setDyjcjg(newSituation.getDyjcjg() + oldSituation.getDyjcjg());
        newSituation.setDyjczg(newSituation.getDyjczg() + oldSituation.getDyjczg());
        newSituation.setDyjcfm(newSituation.getDyjcfm() + oldSituation.getDyjcfm());
        newSituation.setDyjcqt(newSituation.getDyjcqt() + oldSituation.getDyjcqt());
        newSituation.setLjjccs(newSituation.getLjjccs() + oldSituation.getLjjccs());
        newSituation.setLjjcrc(newSituation.getLjjcrc() + oldSituation.getLjjcrc());
        newSituation.setLjjcgs(newSituation.getLjjcgs() + oldSituation.getLjjcgs());
        newSituation.setLjjcjg(newSituation.getLjjcjg() + oldSituation.getLjjcjg());
        newSituation.setLjjczg(newSituation.getLjjczg() + oldSituation.getLjjczg());
        newSituation.setLjjcfm(newSituation.getLjjcfm() + oldSituation.getLjjcfm());
        newSituation.setLjjcqt(newSituation.getLjjcqt() + oldSituation.getLjjcqt());
        return newSituation;
    }

    /**
     * 企业信息库-检查信息
     */
    public ResponseWrapper dailyCheckResultPageForQYXXK(int pageNum, int pageSize, DailyCheckResultVO checkResultVO) {
        // 日常检查
        // 是否可修改 限定条件->检查组成员
        // 列表查看权限->1：检查组成员（任务派发和新增数据） 2：当前登录用户所在部门所有用户（任务制定人所在部门）
        // 权限->当前部门下所有人员相关的任务都要展示，不是检查组成员就不能编辑
        Set<String> taskIds = Sets.newHashSet();
        String departmentId = CurrentUtil.getDeptId();
        String userId = CurrentUtil.getUserId();
        StringBuilder userIdStr = new StringBuilder();
        userIdStr.append(userId);
        if (StringUtils.isNotEmpty(departmentId)) {
            JSONObject obj = new JSONObject();
            obj.put("deptCode", departmentId);
            ResponseWrapper result = userClient.findByDeptCode(obj, 1, 10000);
            if (result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
                Object content = result.getData();
                JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(content));
                JSONArray jsonArray = jsonObj.getJSONArray("content");
                if (CollectionUtils.isNotEmpty(jsonArray)) {
                    List<String> makers = Lists.newArrayList();
                    jsonArray.stream().forEach(member -> {
                        JSONObject memberObj = (JSONObject) member;
                        String userCode = memberObj.getString("userCode");
                        if (StringUtils.isNotEmpty(userCode)) {
                            makers.add(userCode);
                            userIdStr.append("," + userCode);
                        }
                    });
                    ResponseWrapper taskResult = taskFeign.getTaskIdsByMakers(makers);
                    if (taskResult.isSuccess() && !ObjectUtils.isEmpty(taskResult.getData())) {
                        Object taskIdsObj = taskResult.getData();
                        JSONArray arr = JSON.parseArray(JsonUtils.serialize(taskIdsObj));
                        arr.stream().forEach(taskId -> {
                            taskIds.add((String) taskId);
                        });
                    }
                }
            }
        }
        ResponseWrapper teamResult = teamFeign.getTaskIdsListByMemberId(userIdStr.toString());
        Set<String> taskIdsByUserId = Sets.newHashSet();
        if (teamResult.isSuccess() && !ObjectUtils.isEmpty(teamResult.getData())) {
            Object teamObj = teamResult.getData();
            JSONArray arr = JSON.parseArray(JsonUtils.serialize(teamObj));
            arr.stream().forEach(taskId -> {
                taskIdsByUserId.add((String) taskId);
                taskIds.add((String) taskId);
            });
        }
        //监管区域数据
        ResponseWrapper territorialSupervisionResult = dailyCheckResultApi.getTerritorialSupervisionByOrgId(CurrentUtil.getOrgId());
        Object territorialSupervisionObj = territorialSupervisionResult.getData();
        Set<String> territorialSupervisionSet = Sets.newHashSet();
        if (territorialSupervisionResult.isSuccess() && !ObjectUtils.isEmpty(territorialSupervisionObj)) {
            JSONArray arr = JSON.parseArray(JsonUtils.serialize(territorialSupervisionObj));
            arr.stream().forEach(record -> {
                DailyCheckTerritorialSupervisionVO showVO = JsonUtils.parse(JsonUtils.serialize(record), DailyCheckTerritorialSupervisionVO.class);
                String resultId = showVO.getJgId();
                if (StringUtils.isNotEmpty(resultId)) {
                    territorialSupervisionSet.add(resultId);
                }
            });
        }
        if (CollectionUtils.isNotEmpty(taskIds)) {
            checkResultVO.setTaskIds(taskIds);
        } else {
            checkResultVO.setTaskIds(null);
        }
        if (CollectionUtils.isEmpty(taskIdsByUserId)) {
            checkResultVO.setTeamTaskIds(null);
        } else {
            checkResultVO.setTeamTaskIds(taskIdsByUserId);
        }
        //检查结果数据集
        if (CollectionUtils.isNotEmpty(territorialSupervisionSet)) {
            checkResultVO.setResultIds(territorialSupervisionSet);
        }
        checkResultVO.setTeamMember("\"zyId\":\"" + CurrentUtil.getUserId() + "\"");

        // 市局-查看菜单权限对应任务类型
        String orgLevel = CurrentUtil.getOrgLevel();
        if (StringUtils.isNotEmpty(orgLevel) && InspectionConstant.CITY_BUREAU_ORGANIZATIONAL.equals(orgLevel)) {
            checkResultVO.setIsMenuPermission(true);
            checkResultVO.setCurrentUserCode(CurrentUtil.getUserId());
        }
        // 区粮办-获取当前组织下任务
        if (!InspectionConstant.GRAIN_RESERVE_CORPORATION_ORGANIZATION_CODE.equals(CurrentUtil.getOrgId())
                && StringUtils.isNotEmpty(orgLevel) && InspectionConstant.AREA_FOOD_DO_ORGANIZATIONAL.equals(orgLevel)) {
            checkResultVO.setIsQlb(true);
        }
        ResponseWrapper response = dailyCheckResultApi.selectPageByEntity(pageNum, pageSize, checkResultVO);
        Object obj = response.getData();
        // 添加检查组
        if (response.isSuccess() && !ObjectUtils.isEmpty(obj)) {
            JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(obj));
            JSONArray items = jsonObj.getJSONArray("items");
            long total = jsonObj.getLongValue("total");
            int totalPage = jsonObj.getIntValue("totalPage");
            int currentPage = jsonObj.getIntValue("currentPage");
            if (CollectionUtils.isNotEmpty(items)) {
                List<DailyCheckResultListVO> list = Lists.newArrayList();
                items.forEach(item -> {
                    DailyCheckResultListVO listVO = JsonUtils.parse(JsonUtils.serialize(item),
                            DailyCheckResultListVO.class);
                    String taskId = listVO.getRwId();
                    TaskVO taskVO = new TaskVO();
                    try {
                        ResponseWrapper wrapper = teamFeign.getInspectionTeam(taskId, listVO.getBjdwId());
                        if (wrapper.isSuccess()) {
                            Object teamObj = wrapper.getData();
                            TeamVO teamVO = null;
                            if (!ObjectUtils.isEmpty(teamObj)) {
                                teamVO = JsonUtils.parse(JsonUtils.serialize(teamObj), TeamVO.class);
                                List<MemberVO> memberList = teamVO.getMembers();
                                if (CollectionUtils.isNotEmpty(memberList)) {
                                    boolean isMember = false;
                                    for (MemberVO member : memberList) {
                                        String memberId = member.getZyId();
                                        if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)
                                                && userId.equals(memberId)) {
                                            isMember = true;
                                            int memberType = member.getZylx();
                                            if (0 == memberType) {
                                                listVO.setIsTeamLeader(true);
                                                break;
                                            }
                                        }
                                    }
                                    listVO.setRevisable(isMember ? 1 : 0);
                                }
                            }
                            listVO.setTeamVO(teamVO);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                    String teamVO = listVO.getJczcy();
                    if (StringUtils.isNotEmpty(taskId) && StringUtils.isNotEmpty(teamVO)) {
                        TeamVO team = com.unis.inspectionresult.common.utils.JsonUtils
                                .parse(JsonUtils.serialize(teamVO), TeamVO.class);
                        if (team != null) {
                            List<MemberVO> memberList = team.getMembers();
                            //LPH修改,添加权限判断
                            boolean isMember = false;
                            if (CollectionUtils.isNotEmpty(memberList)) {
                                for (MemberVO member : memberList) {
                                    String memberId = member.getZyId();
                                    if (StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId)) {
                                        if (userId.equals(memberId)) {
                                            int memberType = member.getZylx();
                                            isMember = true;
                                            if (0 == memberType) {
                                                listVO.setIsTeamLeader(true);
                                                break;
                                            }
                                        }
                                    }
                                }
                            }
                            listVO.setRevisable(isMember ? 1 : 0);
                            listVO.setTeamVO(team);
                        }
                    }
                    //添加监管区域
                    String jgqy = listVO.getJgqy();
                    if (StringUtils.isNotEmpty(jgqy)) {
                        listVO.setJgqyObj(JSON.parseObject(JsonUtils.serialize(jgqy)));
                    }
                    list.add(listVO);
                });
                PageResult<DailyCheckResultListVO> checkResultListVOPageResult = new PageResult<>(total, totalPage,
                        currentPage, list);
                return ResponseWrapper.success(checkResultListVOPageResult);
            }
        }
        return response;
    }

    /**
     * 更新检查人信息
     */
    @Override
    public void updateTJczzy(TaskVO taskVO) {
        ResponseWrapper responseTask = taskFeign.updateTJczzy(taskVO);
        Log.info("更新检查人信息结果:" + responseTask.toString());
    }
}
