package com.unis.inspection.service.impl;

import java.io.IOException;
import java.util.*;

import com.fasterxml.jackson.databind.JavaType;
import com.unis.common.utils.*;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.common.vo.*;
import com.unis.intelligence.common.vo.PerformanceAndNumberVO;
import com.unis.intelligence.common.vo.TalentStoreVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.unis.base.client.CompanyFeign;
import com.unis.base.common.vo.RandomCompanyQuery;
import com.unis.inspection.service.InspectionGroupService;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.TypesofInspectedUnitsVO;
import com.unis.inspectiontask.client.EvasionFeign;
import com.unis.inspectiontask.client.TeamFeign;
import com.unis.intelligence.client.PersonRandomFeign;
import com.unis.intelligence.common.vo.PersonRandomQueryVO;

/** 
 * @ClassName: InspectionGroupServiceImpl 
 * @Description: 检查组抽取，查询，保存service实现类 
 * @author LiuFeng 
 * @date 2019年8月28日 下午4:13:46  
 */
@Service
public class InspectionGroupServiceImpl implements InspectionGroupService{

	@Autowired
	private CompanyFeign companyFeign;
	
	@Autowired
	private EvasionFeign evasionFeign;
	
	@Autowired
	private TeamFeign teamFeign;

    @Autowired
    private TaskFeign taskFeign;
	
	@Autowired
	private PersonRandomFeign personRandomFeign;
	
	@Autowired
	private InspectionplanFeign inspectionplanFeign;
	
	//对象Mapper
	private ObjectMapper objectMapper = new ObjectMapper();
	/**
	 * <p>Title: getDoubleRandom</p> 
	 * <p>Description: </p> 
	 * @param randomQueryVO
	 * @return 
	 */
	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	public ResponseWrapper getDoubleRandom(RandomQueryVO randomQueryVO) {
		//检查组抽取结果列表
		List<TeamVO> teamVOList = new ArrayList<TeamVO>();
		
		//人员规避列表  
		List<EvasionVO> ryEvasionList = new ArrayList<>();
		if(randomQueryVO.getRygbList() != null)
			ryEvasionList.addAll(randomQueryVO.getRygbList());
		
		//被检单位规避列表
		List<EvasionVO> bjdwEvasionList = new ArrayList<>();
		if(randomQueryVO.getBjdwgbList() != null){
			bjdwEvasionList.addAll(randomQueryVO.getBjdwgbList());
		}

		
		//保存规避记录
		List<EvasionVO> evasionRecords = new ArrayList<>();
		if(ryEvasionList != null) {
			for(EvasionVO ryVO:ryEvasionList) {
				ryVO.setCreator(CurrentUtil.getUserName());
				ryVO.setCreatorCode(CurrentUtil.getUserId());
				ryVO.setCreateDate(new Date());
				ryVO.setGblx(0);
			}
			evasionRecords.addAll(ryEvasionList);
		}
			
		
		if(bjdwEvasionList != null) {
			for(EvasionVO bjVO:bjdwEvasionList) {
				bjVO.setCreator(CurrentUtil.getUserName());
				bjVO.setCreatorCode(CurrentUtil.getUserId());
				bjVO.setCreateDate(new Date());
				bjVO.setGblx(1);
			}
			evasionRecords.addAll(bjdwEvasionList);
		}
			
		
		for(EvasionVO evo:evasionRecords) {
			evo.setCreateDate(new Date());
			evo.setCreator(CurrentUtil.getUserName());
			evo.setCreatorCode(CurrentUtil.getUserId());
			evo.setStatus(1);
		}
		
		if (evasionRecords != null && evasionRecords.size() > 0) 
			evasionFeign.saveRecords(evasionRecords);

		//企业类型
		List<CompanyTypeVO> companyTypeList = randomQueryVO.getCompanyTypeList();
		String[] qylxList = null;
		if(companyTypeList != null && companyTypeList.size() > 0) {
			qylxList = new String[companyTypeList.size()];
			
			for(int index=0;index < companyTypeList.size() ; index++) {
				qylxList[index] = companyTypeList.get(index).getQylx();
			}
		}
		
		//规避企业区域编号数组
		List<String> qygbqyList = randomQueryVO.getQygbqyList();
		String[] qyjgdmList = null;
		if(qygbqyList != null && qygbqyList.size() > 0) {
			qyjgdmList = qygbqyList.toArray(new String[qygbqyList.size()]);
		}
	
		//检查组规则列表
		List<CheckRuleVO> ruleList = randomQueryVO.getJczgzList();

		//部门规避列表，每抽取一次，规避列表也相应增加
		String[] bjdwGbList = null;
		if(bjdwEvasionList != null && bjdwEvasionList.size() > 0) {
			bjdwGbList = new String[bjdwEvasionList.size()];
			for(int index = 0;index < bjdwGbList.length;index++) {
				bjdwGbList[index] = bjdwEvasionList.get(index).getGbCode();
			}
		}

		//封装抽取企业条件,不传数量了,后面需要自行去重
		RandomCompanyQuery companyQuery = new RandomCompanyQuery();
		companyQuery.setBjqyxzfs(randomQueryVO.getBjqyxzfs());
		//companyQuery.setQysl(ruleVO.getBjdwNumber());
		companyQuery.setOrgId(randomQueryVO.getOrgId());
		//企业in的集合
		companyQuery.setQyxxList(bjdwGbList);
		companyQuery.setQylxList(qylxList);
		//区域规避列表
		companyQuery.setQyjgdmList(qyjgdmList);
		companyQuery.setSfjysgzg(randomQueryVO.getSfjysgzg());
		companyQuery.setRtzt(randomQueryVO.getRtzt());
		companyQuery.setSfzdzgqy(randomQueryVO.getSfzdzgqy());
		//检查组被检单位列表用于结果返回
		List<OrganizeVO> organizeVOs = new ArrayList<>();

		int requireCompanyNum=0;
		int requirePersonNum=0;
		int czrNum=0;
		List<String> list=new ArrayList<>();
		List<List<PersonalPerformanceAndNumberVO>> performanceList=new ArrayList<>();
		for(CheckRuleVO ruleVO:ruleList) {
			requireCompanyNum+=ruleVO.getBjdwNumber();
			int perTeam=0;
			if(ruleVO.getCzryNumber()!=null){
				perTeam=ruleVO.getCzryNumber();
				czrNum+=ruleVO.getCzryNumber();
			}
			for(PersonalPerformanceAndNumberVO person:ruleVO.getPersonalPerformanceAndNumberVOS()){
				if(person.getPersonalNumber()!=null){
					perTeam+=person.getPersonalNumber();
				}
				if(!list.contains(person.getPersonalPerformance())){
					list.add(person.getPersonalPerformance());
				}
			}
			performanceList.add(ruleVO.getPersonalPerformanceAndNumberVOS());
			requirePersonNum+=perTeam;
		}
		companyQuery.setQysl(requireCompanyNum);
		ResponseWrapper randomResponse = companyFeign.randomcompany(companyQuery);
		if(randomResponse.getInfoCode() == 200) {
			List<LinkedHashMap> companyVOs = (List<LinkedHashMap>)randomResponse.getData();

			for (LinkedHashMap companyVO : companyVOs) {

				//规避对象 抽取一次企业，下次将抽取过的企业作规避对象
				EvasionVO evasionVO = new EvasionVO();
				evasionVO.setGbCode(companyVO.get("tyshxydm").toString());
				evasionVO.setGbName(companyVO.get("qymc").toString());
				bjdwEvasionList.add(evasionVO);
				//用于结果返回的被检单位对象
				OrganizeVO organizeVO = new OrganizeVO();
//					ResponseWrapper randomResponse2 =companyFeign.getCompanyBytyshxydm(companyVO.get("tyshxydm").toString());
//					if(randomResponse2.getInfoCode() == 200) {
//						LinkedHashMap map = (LinkedHashMap) randomResponse2.getData();
//						String qyjgdm = map.get("qyjgdm").toString();
//						organizeVO.setBjdwId(qyjgdm);
//					}
				organizeVO.setBjdwId(companyVO.get("qyjgdm") != null? companyVO.get("qyjgdm").toString():null);
				organizeVO.setBjdwName(companyVO.get("qymc") != null? companyVO.get("qymc").toString():null);
				organizeVO.setBjdwAddress(companyVO.get("qytxdz") != null? companyVO.get("qytxdz").toString():null);//设置企业通讯地址
				organizeVO.setZzjgdm(companyVO.get("zzjgdm") != null? companyVO.get("zzjgdm").toString():null);//设置粮食收购许可证（组织机构代码）
				organizeVO.setBjdwFzr(companyVO.get("fddbr") != null? companyVO.get("fddbr").toString():null);//设置被检企业法定代表人
				organizeVO.setBjdwLxdh(companyVO.get("bgdh") != null? companyVO.get("bgdh").toString():null);//设置联系电话
				organizeVOs.add(organizeVO);
			}
		}

		int companySize=organizeVOs.size();

		if(companySize>=requireCompanyNum){
			//后悔不该拆出来,循环调feign改动小............
			//人员列表
			List<String> ryGbList = null;
			if(ryEvasionList != null && ryEvasionList.size() > 0) {
				ryGbList = new ArrayList();
				for(EvasionVO evasion : ryEvasionList) {
					ryGbList.add(evasion.getGbCode()) ;
				}
			}
			List<String> excludePersonList=new ArrayList<>();
			PersonRandomQueryVO personQuery = new PersonRandomQueryVO();
			personQuery.setCzrysl(czrNum);
			//人员列表
			personQuery.setRybhList(null);
			//这个才是人员排除的列表
			personQuery.setGbRybhList(ryGbList);
			personQuery.setOrgId(randomQueryVO.getOrgId());
			//组员数量
			personQuery.setZysl(requirePersonNum);
			personQuery.setProfessionList(list);
			//任务类型id
			personQuery.setRwlxId(randomQueryVO.getRwlxId());
			//各个组的人员集合 TS
//			personQuery.setPersonalPerformanceAndNumberVOS(randomQueryVO.getJczgzList());
			personQuery.setPersonalPerformanceAndNumberVOS(null);

			if(randomQueryVO.getRylx() != null && randomQueryVO.getRylx().size() > 0) {
				personQuery.setRylxList(randomQueryVO.getRylx());
			}
			if(randomQueryVO.getRygbqyList() != null && randomQueryVO.getRygbqyList().size() > 0) {
				personQuery.setRygbqyList(randomQueryVO.getRygbqyList());
			}

			//人员抽取列表用于结果返回
			//List<MemberVO> members = new ArrayList<>();
			ResponseWrapper personResponse = personRandomFeign.personRandom(personQuery);
			List<LinkedHashMap> personVOs =null;
			if(personResponse.getInfoCode() == 200) {
				personVOs=(List<LinkedHashMap>)personResponse.getData();

				/*if(personVOs != null && personVOs.size() > 0 ) {
					for (Map<String,List<TalentStoreVO>> zz : personVOs) {
						//规避对象 抽取一次企业，下次将抽取过的人员作规避对象
						EvasionVO evasionVO = new EvasionVO();
						evasionVO.setGbCode(zz.get("rybh")!= null?zz.get("rybh").toString():"");
						evasionVO.setGbName(zz.get("ryxm")!= null?zz.get("ryxm").toString():"");
						ryEvasionList.add(evasionVO);

						//用于结果返回的被检人员单位对象
						MemberVO member = new MemberVO();
						member.setZydw(zz.get("zzjgmc")!= null?zz.get("zzjgmc").toString():"");
						member.setZyId(zz.get("rybh")!= null?zz.get("rybh").toString():"");
						member.setZyks(zz.get("bmmc")!= null?zz.get("bmmc").toString():"");
						member.setZylx(0);
						member.setZyName(zz.get("ryxm")!= null?zz.get("ryxm").toString():"");
						member.setIsCz("1".equals(zz.get("sfyz").toString())?1:0);
						member.setZfzbh(zz.get("zfzbh")!= null?zz.get("zfzbh").toString():"");
						member.setCityCardNum(zz.get("szfzbh")!= null?zz.get("szfzbh").toString():"" );
						members.add(member);
					}
				}*/
				int i = 0;
				//按每组检查组规则抽取
				for(CheckRuleVO ruleVO:ruleList) {
					TeamVO teamVO = new TeamVO();
					teamVO.setJczName("检查组"+i);

					//teamVO.setMembers(members);
					if(personVOs!=null && personVOs.size()>0){
						teamVO.setMemberMap(personVOs.get(i));
					}
					teamVO.setOrganizes(randomCompany(organizeVOs,ruleVO.getBjdwNumber()));
					teamVOList.add(teamVO);
					i++;
				}
				return ResponseWrapper.success(teamVOList);
			}else{
				return personResponse;
			}
		}else{
			return ResponseWrapper.error("符合条件的企业总数量是"+companySize+",小于要求的"+requireCompanyNum);
		}
	}

	private List<OrganizeVO> randomCompany(List<OrganizeVO> organizeVOs,Integer num){
		int size=0;
		List<OrganizeVO> resList=new ArrayList<>();
		if(organizeVOs!=null && (size=organizeVOs.size())>0 && num!=null && size>=num){
			while(num>0){
				Random random=new Random();
				int index=random.nextInt(organizeVOs.size());
				resList.add(organizeVOs.get(index));
				organizeVOs.remove(index);
				num--;
			}
		}
		return resList;
	}

	/**
	 * <p>Title: getDesignated</p> 
	 * <p>Description: </p> 
	 * @param designatedQueryVOs
	 * @return 
	 */
	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Override
	public ResponseWrapper getDesignated(List<DesignatedQueryVO> designatedQueryVOs) {
		//检查组抽取结果列表
		List<TeamVO> teamVOList = new ArrayList<TeamVO>();
		int i = 1;
		for(DesignatedQueryVO designatedQueryVO : designatedQueryVOs) {
			TeamVO teamVO = new TeamVO();
			teamVO.setJczName("检查组"+i);
			
			List<MemberVO> members = new ArrayList<>();
			if(designatedQueryVO.getZzList() != null && designatedQueryVO.getZzList().size() > 0) {
				for(MemberVO memberVO:designatedQueryVO.getZzList()){
					memberVO.setZylx(0);
				}
				members.addAll(designatedQueryVO.getZzList());
			}
			
			if(designatedQueryVO.getZyList() != null && designatedQueryVO.getZyList().size() > 0) {
				for(MemberVO memberVO:designatedQueryVO.getZyList()){
					memberVO.setZylx(1);
				}
				members.addAll(designatedQueryVO.getZyList());
			}
				
			if(designatedQueryVO.getWbryList() != null && designatedQueryVO.getWbryList().size() > 0) {
				for(MemberVO memberVO:designatedQueryVO.getWbryList()){
					memberVO.setZylx(2);
				}
				members.addAll(designatedQueryVO.getWbryList());
			}
			teamVO.setMembers(members);
			
			//被检单位规避列表
			List<EvasionVO> bjdwEvasionList = new ArrayList<>();
			if(designatedQueryVO.getBjdwgbList() != null && designatedQueryVO.getBjdwgbList().size() > 0) {
				bjdwEvasionList.addAll(designatedQueryVO.getBjdwgbList());
				for(EvasionVO bjVO : bjdwEvasionList) {
						bjVO.setCreateDate(new Date());
						bjVO.setCreator(CurrentUtil.getUserName());
						//bjVO.setGbCode(CurrentUtil.getUserId());
						bjVO.setGblx(1);
				}
				evasionFeign.saveRecords(bjdwEvasionList);
			}
				
			
			//企业类型
			List<CompanyTypeVO> companyTypeList = new ArrayList<>();
			if(designatedQueryVO.getCompanyTypeList() != null) {
				companyTypeList.addAll(designatedQueryVO.getCompanyTypeList());
			}
			String[] qylxList = null;
			if(companyTypeList != null && companyTypeList.size() > 0) {
				qylxList = new String[companyTypeList.size()];
				for(int index = 0;index < companyTypeList.size();index++) {
					qylxList[index] = companyTypeList.get(index).getQylx();
				}
			}
			
			//部门规避列表，每抽取一次，规避列表也相应增加
			String[] bjdwGbList = null;
			if(bjdwEvasionList != null && bjdwEvasionList.size() > 0) {
				bjdwGbList = new String[bjdwEvasionList.size()];
				for(int index = 0;index < bjdwGbList.length;index++) {
					bjdwGbList[index] = bjdwEvasionList.get(index).getGbCode();
				}
				
			}

			//规避企业区域编号数组
			List<String> qygbqyList = designatedQueryVO.getQygbqyList();

							
			//封装抽取企业条件
			RandomCompanyQuery companyQuery = new RandomCompanyQuery();
			companyQuery.setBjqyxzfs(designatedQueryVO.getBjqyxzfs());
			companyQuery.setQysl(designatedQueryVO.getBjdwNumber());
			companyQuery.setOrgId(designatedQueryVO.getOrgId());
			companyQuery.setQyxxList(bjdwGbList);
			companyQuery.setRtzt(designatedQueryVO.getRtzt());
			companyQuery.setSfjysgzg(designatedQueryVO.getSfjysgzg());
			companyQuery.setSfzdzgqy(designatedQueryVO.getSfzdzgqy());
			if(qygbqyList!=null && qygbqyList.size()>0){
				companyQuery.setQyjgdmList(qygbqyList.toArray(new String[]{}));
			}

			companyQuery.setQylxList(qylxList);
			ResponseWrapper randomResponse = companyFeign.randomcompany(companyQuery);
			if(randomResponse.getInfoCode() == 200) {
				List<LinkedHashMap> companyVOs = (List<LinkedHashMap>)randomResponse.getData();
				
				//检查组被检单位列表用于结果返回
				List<OrganizeVO> organizeVOs = new ArrayList<>();
				for (LinkedHashMap companyVO : companyVOs) {
					
					//规避对象 抽取一次企业，下次将抽取过的企业作规避对象
					EvasionVO evasionVO = new EvasionVO();
					evasionVO.setGbCode(companyVO.get("tyshxydm").toString());
					evasionVO.setGbName(companyVO.get("qymc").toString());
					bjdwEvasionList.add(evasionVO); 
					
					//用于结果返回的被检单位对象
					OrganizeVO organizeVO = new OrganizeVO();
					organizeVO.setBjdwId(companyVO.get("qyjgdm").toString());
					organizeVO.setBjdwName(companyVO.get("qymc").toString());
					organizeVO.setBjdwAddress(companyVO.get("qytxdz").toString());//设置企业通讯地址
					organizeVO.setZzjgdm(companyVO.get("zzjgdm").toString());//设置粮食收购许可证（组织机构代码）
					organizeVO.setBjdwFzr(companyVO.get("fddbr").toString());//设置被检企业法定代表人
					organizeVO.setBjdwLxdh(companyVO.get("bgdh").toString());//设置联系电话
					organizeVOs.add(organizeVO);
				}
				teamVO.setOrganizes(organizeVOs);
				teamVOList.add(teamVO);
				i++;
			}else{
				return randomResponse;
			}
		}
		return ResponseWrapper.success(teamVOList);
	}

	/**
	 * <p>Title: saveInspectionTeams</p> 
	 * <p>Description: </p> 
	 * @param teamVOs
	 * @return 
	 */
	@Override
	public ResponseWrapper saveInspectionTeams(List<TeamVO> teamVOs) {

		for(TeamVO teamVO: teamVOs) {
			teamVO.setCreateDate(new Date());
			teamVO.setCreator(CurrentUtil.getUserName());
			teamVO.setCreatorCode(CurrentUtil.getUserId());
			teamVO.setStatus(1);
		}
		return teamFeign.saveInspectionTeams(teamVOs);
	}

	/**
	 * <p>Title: getInspectionTeamList</p> 
	 * <p>Description: </p> 
	 * @param taskId
	 * @return 
	 * @see com.unis.inspection.service.InspectionGroupService#getInspectionTeamList(java.lang.String) 
	 */
	@Override
	public ResponseWrapper getInspectionTeamList(String taskId) {
		return teamFeign.getIinspectionTeamList(taskId);
	}

	/**
	 * <p>Title: getInspectionUnit</p> 
	 * <p>Description: </p> 
	 * @param userId
	 * @return 
	 * @see com.unis.inspection.service.InspectionGroupService#getInspectionUnit(java.lang.String) 
	 */
	@Override
	public ResponseWrapper getInspectionUnit(String userId) {
		return teamFeign.getInspectionUnit(userId);
	}

	/**
	 * <p>Title: getPersonInfo</p> 
	 * <p>Description: </p> 
	 * @param rybh
	 * @return 
	 * @see com.unis.inspection.service.InspectionGroupService#getPersonInfo(java.lang.String) 
	 */
	@Override
	public ResponseWrapper getPersonInfo(String rybh) {

		return personRandomFeign.personInfo(rybh);
	}

	/**
	 * <p>Title: getPersonList</p> 
	 * <p>Description: </p> 
	 * @param rymc
	 * @return 
	 * @see com.unis.inspection.service.InspectionGroupService#getPersonList(java.lang.String) 
	 */
	@Override
	public ResponseWrapper getPersonList(String rymc) {
		
		return personRandomFeign.personList(rymc);
	}

	/**
	 * <p>Title: updateInspectionTeams</p> 
	 * <p>Description: </p> 
	 * @param teamVOs
	 * @return 
	 * @see com.unis.inspection.service.InspectionGroupService#updateInspectionTeams(java.util.List) 
	 */
	@Override
	public ResponseWrapper updateInspectionTeams(List<TeamVO> teamVOs) {

		for(TeamVO teamVO: teamVOs) {
			teamVO.setRefreshTime(new Date());
			teamVO.setRefresher(CurrentUtil.getUserName());
			teamVO.setRefresherCode(CurrentUtil.getUserId());
		}
		return teamFeign.updateInspectionTeams(teamVOs);
	}

	/**
	 * 拼接子表数据
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<TaskVO> getTaskListMore(String rybh, String rwlx) {
			// 序列化的时候序列对象的所有属性
			objectMapper.setSerializationInclusion(Include.ALWAYS);
			// 反序列化的时候如果多了其他属性,不抛出异常
			objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
			// 如果是空对象的时候,不抛异常
			objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
			// 获取详细信息
			ResponseWrapper rwTaskPageList = teamFeign.getTaskListMore(rybh, rwlx)	;
			List<TaskVO> taskVOList=null;
            if (rwTaskPageList.getInfoCode() == 200 && rwTaskPageList.getData() != null) {
                taskVOList =JsonUtils.parseList(JsonUtils.serialize(rwTaskPageList.getData() ), TaskVO.class);
            }
			/*//查询列表数据
			if (rwTaskPageList.getInfoCode() == 200 && rwTaskPageList.getData() != null) {
				List<TaskVO> taskVOL =JsonUtils.parseList(JsonUtils.serialize(rwTaskPageList.getData() ), TaskVO.class);
				//转换成json
				Iterator<TaskVO> iterator = taskVOL.iterator();
				while (iterator.hasNext()) {
					Object taskvo =iterator.next();
					TaskVO taskVO = (TaskVO) taskvo;
					TaskVO taskV = new TaskVO();
					LsBeanUtils.copyAllProperties(taskVO, taskV);
					//检查组查询
					ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(taskVO.getRwId());
					if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
						List<TeamVO> list = objectMapper.convertValue(teamVOResponse.getData(), List.class);
						taskV.setTeamVOs(list);
					}
					
					//计划表单查询
					ResponseWrapper planVOResponse = inspectionplanFeign.getInspectionplan(taskVO.getJhId());
					if (planVOResponse.getInfoCode() == 200 && planVOResponse.getData() != null) {
						// 获取检查计划结果InspectionplanVO
						InspectionplanVO inspectionplanVO = objectMapper.convertValue(planVOResponse.getData(),InspectionplanVO.class);
						// 被检单位类型列表
						List<TypesofInspectedUnitsVO> bjdwlxList = inspectionplanVO.getBjdwlxList();
						if (bjdwlxList != null) {
							List<InspectedUnitsTypeVO> inspectedUnitsTypeList = new ArrayList<InspectedUnitsTypeVO>();
							LsBeanUtils.copyCollection(bjdwlxList, inspectedUnitsTypeList, InspectedUnitsTypeVO.class);
							taskV.setInspectedUnitsType(inspectedUnitsTypeList);
						}
						
						// 检查表单列表
						List<CheckformVO> jcbdList = inspectionplanVO.getJcbd();
						if (jcbdList != null) {
							List<TaskFormVO> taskFormVOList = new ArrayList<TaskFormVO>();
							LsBeanUtils.copyCollection(jcbdList, taskFormVOList, TaskFormVO.class);
							taskV.setTaskFormVO(taskFormVOList);
						}
					}	
					taskVOList.add(taskV);
				}
			}*/
		return taskVOList;
	}

	@Override
	public TaskVO getTaskListMoreDetail(String rwid, String jhid){
        ResponseWrapper responseWrapper= taskFeign.getTaskInfoByrwbh(rwid, jhid);
        TaskVO taskVO=null;
        if(responseWrapper.isSuccess()){
            taskVO=JsonUtils.parse(JsonUtils.serialize(responseWrapper.getData()), TaskVO.class);
            if(taskVO!=null){
                //检查组查询
                ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(rwid);
                if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
                    List<TeamVO> list = objectMapper.convertValue(teamVOResponse.getData(), List.class);
                    taskVO.setTeamVOs(list);
                }

                //计划表单查询
                ResponseWrapper planVOResponse = inspectionplanFeign.getInspectionplan(jhid);
                if (planVOResponse.getInfoCode() == 200 && planVOResponse.getData() != null) {
                    // 获取检查计划结果InspectionplanVO
                    InspectionplanVO inspectionplanVO = objectMapper.convertValue(planVOResponse.getData(),InspectionplanVO.class);
                    // 被检单位类型列表
                    List<TypesofInspectedUnitsVO> bjdwlxList = inspectionplanVO.getBjdwlxList();
                    if (bjdwlxList != null) {
                        List<InspectedUnitsTypeVO> inspectedUnitsTypeList = new ArrayList<InspectedUnitsTypeVO>();
                        LsBeanUtils.copyCollection(bjdwlxList, inspectedUnitsTypeList, InspectedUnitsTypeVO.class);
                        taskVO.setInspectedUnitsType(inspectedUnitsTypeList);
                    }

                    // 检查表单列表
                    List<CheckformVO> jcbdList = inspectionplanVO.getJcbd();
                    if (jcbdList != null) {
                        List<TaskFormVO> taskFormVOList = new ArrayList<TaskFormVO>();
                        LsBeanUtils.copyCollection(jcbdList, taskFormVOList, TaskFormVO.class);
                        taskVO.setTaskFormVO(taskFormVOList);
                    }
                }
            }
        }
        return taskVO;
    }

	/**
	 * 制定任务的暂存
	 */
	@Override
	public ResponseWrapper saveInspectionPlanTeams(List<TeamVO> teamVOs) {

		for(TeamVO teamVO: teamVOs) {
			teamVO.setCreateDate(new Date());
			teamVO.setCreator(CurrentUtil.getUserName());
			teamVO.setCreatorCode(CurrentUtil.getUserId());
			teamVO.setStatus(1);
		}
		return teamFeign.saveInspectionPlanTeams(teamVOs);
	}

	@Override
	public ResponseWrapper selectPersonListByType(String type, String rymc) {
		//  TODO ts
//		return personRandomFeign.selectPersonListByType(type, rymc);
		return null;
	}
	
}
