package com.unis.inspection.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.unis.base.client.CompanyFeign;
import com.unis.base.common.vo.CompanyQueryVO;
import com.unis.base.common.vo.CompanyVO;
import com.unis.common.utils.*;
import com.unis.flowable.client.FlowTodoClient;
import com.unis.flowable.common.vo.StartTodoVO;
import com.unis.inspection.app.myuser.MyUserClient;
import com.unis.inspection.app.vo.AppVO;
import com.unis.inspection.app.vo.ReserveGrainVO;
import com.unis.inspection.constant.InspectionConstant;
import com.unis.inspection.service.InspectionTaskService;
import com.unis.inspection.service.backlog.BacklogMQService;
import com.unis.inspection.service.user.UserService;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.TypesofInspectedUnitsVO;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.constant.DailyCheckStatusConstant;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckInspectionTimeAndResultIdVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultDetailVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.client.TeamFeign;
import com.unis.inspectiontask.common.constant.TaskStatusConstant;
import com.unis.inspectiontask.common.vo.*;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;

import lombok.extern.slf4j.Slf4j;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.text.ParseException;
import java.util.*;

/**
 * @author 张琪
 * @date 2019年8月27日 下午6:53:37
 * @description APP 业务逻辑处理 InspectionTaskServiceImpl
 */
@Service
@Slf4j
public class InspectionTaskServiceImpl implements InspectionTaskService {

    public final static String CORRECT = "1";
    public final static String FAULT = "0";

    /*****************注入方法******************/
    @Autowired
    private TaskFeign taskFeign;
    @Autowired
    private InspectionplanFeign inspectionplanFeign;
    @Autowired
    private DailyCheckResultApi dailyCheckResultApi;
    @Autowired
    private TeamFeign teamFeign;
    @Autowired
    private FlowTodoClient flowTodoClient;
    @Autowired
    private CompanyFeign companyFeign;
    
    @Autowired
    private MyUserClient userClient;
    
    @Autowired
    private BacklogMQService backlogService;
    
    @Autowired
    private UserService userService;

    /***************** 全局对象******************/
    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * 公用封装方法
     */
    public void getObjectMapperMethods() {
        // 序列化的时候序列对象的所有属性
        objectMapper.setSerializationInclusion(Include.ALWAYS);
        // 反序列化的时候如果多了其他属性,不抛出异常
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        // 如果是空对象的时候,不抛异常
        objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
    }

    /**
     * Session取值公用方法
     */
    @Override
    public TaskVO setSessionAll(TaskVO taskVO) {
        taskVO.setCreateDate(DateUtil.getNowDate());
        taskVO.setCreator(CurrentUtil.getUserName());
        taskVO.setCreatorCode(CurrentUtil.getUserId());
        taskVO.setRefresher(CurrentUtil.getUserName());
        taskVO.setRefreshTime(DateUtil.getNowDate());
        taskVO.setRefresherCode(CurrentUtil.getUserId());
        // taskVO.setOrgId(CurrentUtil.getOrgId());
        // ===========================================
        // 分配不修改任务orgid
        if(StringUtils.isBlank(taskVO.getOrgId())) {
        	taskVO.setOrgId(CurrentUtil.getOrgId());
        }
        return taskVO;
    }


    /**
     * 分页列表拼接
     */
    @SuppressWarnings("unchecked")
    @Override
    public PageInfo<TaskVO> getRwTaskPageList(TaskQueryVO taskQueryVO, Integer pageNum, Integer pageSize) {

        this.getObjectMapperMethods();

        String orgCode = CurrentUtil.getOrgId();
		String orgLevel = CurrentUtil.getOrgLevel();
		if(StringUtils.isNotEmpty(orgCode) && InspectionConstant.GRAIN_RESERVE_CORPORATION_ORGANIZATION_CODE.equals(orgCode)) {
			//当登录账号属于储备粮公司时 只能查看 日常检查-储备粮公司
			taskQueryVO.setRwlx("5000150");
		} else {
			//区粮办
			if(StringUtils.isNotEmpty(orgLevel) && InspectionConstant.AREA_FOOD_DO_ORGANIZATIONAL.equals(orgLevel)) {
				// 获取当前组织下任务
				taskQueryVO.setOrgId(orgCode);
			} else if(StringUtils.isNotEmpty(orgLevel) && InspectionConstant.CITY_BUREAU_ORGANIZATIONAL.equals(orgLevel)) {//市局
				// 根据当前登录用户所在部门查询该部门下所有用户，然后根据用户集合查询计划主键集合
				String departmentId = CurrentUtil.getDeptId();
				if(StringUtils.isNotEmpty(departmentId)) {
					JSONObject obj = new JSONObject();
					obj.put("deptCode", departmentId);
					ResponseWrapper result = userClient.findByDeptCode(obj, 1, 10000);
					if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
						Object content = result.getData();
						JSONObject jsonObj = JSON.parseObject(JsonUtils.serialize(content));
						JSONArray jsonArray = jsonObj.getJSONArray("content");
						if(CollectionUtils.isNotEmpty(jsonArray)) {
							List<String> makers = Lists.newArrayList();
							jsonArray.stream().forEach( member -> {
								JSONObject memberObj = (JSONObject)member;
								String userCode = memberObj.getString("userCode");
								if(StringUtils.isNotEmpty(userCode)) {
									makers.add(userCode);
								}
							});
							taskQueryVO.setUserIds(makers);
						}
					}
				}
			}
		}
        
        // 获取详细信息
        ResponseWrapper taskVOPageList = taskFeign.getRwTaskPageList(taskQueryVO, pageNum, pageSize);

        PageInfo<TaskVO> pageInfo = new PageInfo<TaskVO>();
        List<TaskVO> taskVOList = new ArrayList<TaskVO>();

        if (taskVOPageList.getInfoCode() == 200 && taskVOPageList.getData() != null) {
            pageInfo = objectMapper.convertValue(taskVOPageList.getData(), PageInfo.class);
            // 分页查询列表数据
            List<TaskVO> taskVOL = JsonUtils.parseList(JsonUtils.serialize(pageInfo.getList()), TaskVO.class);
            // 转换成json
            Iterator<TaskVO> iterator = taskVOL.iterator();
            while (iterator.hasNext()) {
                Object taskvo = iterator.next();
                TaskVO taskVO = (TaskVO) taskvo;
                TaskVO taskV = new TaskVO();
                LsBeanUtils.copyAllProperties(taskVO, taskV);

            /*    // 检查组查询
                ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(taskVO.getRwId());
                if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
                    List<TeamVO> list = objectMapper.convertValue(teamVOResponse.getData(), List.class);
                    taskV.setTeamVOs(list);
                }*/

                // 计划表单查询
               /* ResponseWrapper planVOResponse = inspectionplanFeign.getInspectionplan(taskVO.getJhId());
                if (planVOResponse.getInfoCode() == 200 && planVOResponse.getData() != null) {

                    // 获取检查计划结果InspectionplanVO
                    InspectionplanVO inspectionplanVO = objectMapper.convertValue(planVOResponse.getData(),
                            InspectionplanVO.class);

                    // 被检单位类型列表
                    List<TypesofInspectedUnitsVO> bjdwlxList = inspectionplanVO.getBjdwlxList();
                    if (bjdwlxList != null) {
                        List<InspectedUnitsTypeVO> inspectedUnitsTypeList = new ArrayList<InspectedUnitsTypeVO>();
                        LsBeanUtils.copyCollection(bjdwlxList, inspectedUnitsTypeList, InspectedUnitsTypeVO.class);
                        taskV.setInspectedUnitsType(inspectedUnitsTypeList);
                    }

                    // 检查表单列表
                    List<CheckformVO> jcbdList = inspectionplanVO.getJcbd();
                    if (jcbdList != null) {
                        List<TaskFormVO> taskFormVOList = new ArrayList<TaskFormVO>();
                        LsBeanUtils.copyCollection(jcbdList, taskFormVOList, TaskFormVO.class);
                        taskV.setTaskFormVO(taskFormVOList);
                    }
                }*/
                taskVOList.add(taskV);
            }
        }
        // 分页设置
        pageInfo.setList(taskVOList);
        return pageInfo;
    }

    /**
     * 根据任务编号和计划ID 查询
     *
     * @throws ParseException
     */
    @Override
    public TaskVO getTaskInfo(String rwId, String jhId) {

        this.getObjectMapperMethods();
        TaskVO taskVO = new TaskVO();
        
        // 获取详细信息
        ResponseWrapper taskVOResponse = taskFeign.getTaskInfoByrwbh(rwId, jhId);
        if (taskVOResponse.getInfoCode() == 200 && taskVOResponse.getData() != null) {
            taskVO = objectMapper.convertValue(taskVOResponse.getData(), TaskVO.class);
            //检查组查询
            ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(taskVO.getRwId());
            if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
                @SuppressWarnings("unchecked")
                List<TeamVO> list = JsonUtils.parseList(JsonUtils.serialize(teamVOResponse.getData()),TeamVO.class);

                //遍历被检单位，根据rwId,bjdwId获取检查时间
                Map<String, String> queryMap = new HashMap<>();
                for (TeamVO teamVO: list){
                    if (teamVO.getOrganizes() != null && teamVO.getOrganizes().size() > 0) {
                        for (OrganizeVO organizeVO : teamVO.getOrganizes()) {
//                            queryMap.put("rwId",teamVO.getRwId());
//                            queryMap.put("bjdwId",organizeVO.getBjdwId());
                            //调用feign,获取检查时间
                            String bjdwId = organizeVO.getBjdwId();
                            ResponseWrapper inspectionTimeRW = dailyCheckResultApi.getInspectionTime(rwId, bjdwId);
                            Object obj = inspectionTimeRW.getData();
                            if (inspectionTimeRW.isSuccess() && !ObjectUtils.isEmpty(obj)){
                            	DailyCheckInspectionTimeAndResultIdVO data = JsonUtils.parse(JsonUtils.serialize(obj), DailyCheckInspectionTimeAndResultIdVO.class);
                                if (data != null) {
                                	Date checkDate = data.getJcsj();
                                	if(!ObjectUtils.isEmpty(checkDate)) {
                                		organizeVO.setJcsj(DateUtil.DateToStr(checkDate, "yyyy-MM-dd"));
                                	}
                                	organizeVO.setJgId(data.getJgId());
                                }
                            }
                        }
                    }
                }
                taskVO.setTeamVOs(list);
            }
        }

        ResponseWrapper planVOResponse = inspectionplanFeign.getInspectionplan(jhId);
        if (planVOResponse.getInfoCode() == 200 && planVOResponse.getData() != null) {
            // 获取检查计划结果InspectionplanVO
            InspectionplanVO inspectionplanVO = objectMapper.convertValue(planVOResponse.getData(), InspectionplanVO.class);
            // 被检单位类型列表
            List<TypesofInspectedUnitsVO> bjdwlxList = inspectionplanVO.getBjdwlxList();
            if (bjdwlxList != null) {
                List<InspectedUnitsTypeVO> inspectedUnitsTypeList = new ArrayList<InspectedUnitsTypeVO>();
                LsBeanUtils.copyCollection(bjdwlxList, inspectedUnitsTypeList, InspectedUnitsTypeVO.class);
                taskVO.setInspectedUnitsType(inspectedUnitsTypeList);
            }
            // 检查表单列表
            List<CheckformVO> jcbdList = inspectionplanVO.getJcbd();
            if (jcbdList != null) {
                List<TaskFormVO> taskFormVOList = new ArrayList<TaskFormVO>();
                LsBeanUtils.copyCollection(jcbdList, taskFormVOList, TaskFormVO.class);
                taskVO.setTaskFormVO(taskFormVOList);
            }
            //处理检查计划文件数据
            List<com.unis.inspectionplan.common.vo.FileVO> planFiles = inspectionplanVO.getFile();
            if(planFiles.size()>0) {
            	List<FileVO> fileVOs = new ArrayList<FileVO>();
            	for(com.unis.inspectionplan.common.vo.FileVO planvo:planFiles) {
            		FileVO fileVO = new FileVO();
            		fileVO.setFileId(planvo.getFileId());
            		fileVO.setFileType(planvo.getFileType());
                    fileVO.setRemark(planvo.getRemark());
                    fileVO.setId(planvo.getId());
            		fileVOs.add(fileVO);
            	}
            	taskVO.setPlanFile(fileVOs);
            }
            taskVO.setRwId(rwId);
            taskVO.setJhId(jhId);
        }

        return taskVO;
    }

    /**
     * 根据检查单位ID和计划编号查询详单数据+检查组
     */
    @Override
    public TaskVO getTaskInfoAll(String jcdwId, String jhId) {

        this.getObjectMapperMethods();
        TaskVO taskVO = new TaskVO();

        //获取计划详情
        ResponseWrapper planVOResponse = inspectionplanFeign.getInspectionplan(jhId);
        if (planVOResponse.getInfoCode() == 200 && planVOResponse.getData() != null) {
            // 获取详细信息
            ResponseWrapper taskVOResponse = taskFeign.getTaskInfoAll(jcdwId, jhId);
            if (taskVOResponse.getInfoCode() == 200 && taskVOResponse.getData() != null) {
                taskVO = objectMapper.convertValue(taskVOResponse.getData(), TaskVO.class);
                //检查组查询
                ResponseWrapper teamVOResponse = teamFeign.getIinspectionTeamList(taskVO.getRwId());
                if (teamVOResponse.getInfoCode() == 200 && teamVOResponse.getData() != null) {
                    @SuppressWarnings("unchecked")
                    List<TeamVO> list = objectMapper.convertValue(teamVOResponse.getData(), List.class);
                    taskVO.setTeamVOs(list);
                }
            }

            // 获取检查计划结果InspectionplanVO
            InspectionplanVO inspectionplanVO = objectMapper.convertValue(planVOResponse.getData(), InspectionplanVO.class);

            // 被检单位类型列表
            List<TypesofInspectedUnitsVO> bjdwlxList = inspectionplanVO.getBjdwlxList();
            if (bjdwlxList != null) {
                List<InspectedUnitsTypeVO> inspectedUnitsTypeList = new ArrayList<InspectedUnitsTypeVO>();
                LsBeanUtils.copyCollection(bjdwlxList, inspectedUnitsTypeList, InspectedUnitsTypeVO.class);
                taskVO.setInspectedUnitsType(inspectedUnitsTypeList);
            }

            // 检查表单列表
            List<CheckformVO> jcbdList = inspectionplanVO.getJcbd();
            if (jcbdList != null) {
                List<TaskFormVO> taskFormVOList = new ArrayList<TaskFormVO>();
                LsBeanUtils.copyCollection(jcbdList, taskFormVOList, TaskFormVO.class);
                taskVO.setTaskFormVO(taskFormVOList);
            }
            taskVO.setJcdwId(jcdwId);
            taskVO.setJhId(jhId);
            taskVO.setInspectionplanVO(inspectionplanVO);
        }
        return taskVO;
    }

    /**
     * rwId 任务检查根据 rwId撤回
     */
    @Override
    public ResponseWrapper inspectionTaskReturn(String rwId, Integer rwZt) {
        DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
        checkResultVO.setRwId(rwId);
        ResponseWrapper responseWrapper= dailyCheckResultApi.deleteBackByEntity(checkResultVO);
        if(responseWrapper.isSuccess()){
            if(responseWrapper.isSuccess()){
                ResponseWrapper inspectionTaskUpdateByEntity = taskFeign.inspectionTaskUpdateByEntity(rwId, rwZt);
                if (inspectionTaskUpdateByEntity.getInfoCode() != 200) {
                    return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "回撤失败", null);
                }
                // 完成 超期完成 更新 计划完成
                TaskVO taskVO = objectMapper.convertValue(inspectionTaskUpdateByEntity.getData(), TaskVO.class);
                //查询一个jhid下是否全部完成然后再更新状态
                if (rwZt == Integer.parseInt(TaskStatusConstant.DOSAVE.getValue()) && taskVO.getRemark().equals(TaskStatusConstant.TO_FP.getValue())) {
                    // 更新计划状态
                    InspectionplanVO inspectionplan = new InspectionplanVO();
                    inspectionplan.setJhId(taskVO.getJhId());
                    inspectionplan.setJhzt(taskVO.getRwZt());
                    inspectionplanFeign.updateInspectionplanonly(inspectionplan);
                    if(responseWrapper.getInfoCode()==200) {
						inspectionplanFeign.backlog(taskVO.getRwId());
					}
                }
                return ResponseWrapper.success(HttpStatus.OK.value(), "回撤成功", taskVO);
            }
        }
        return responseWrapper;
    }

    /**
     * jhid 任务完成
     */
    @Override
    public ResponseWrapper inspectionTaskFinish(String jhid, Integer rwZt) {
        InspectionplanVO planVO=new InspectionplanVO();
        planVO.setJhId(jhid);
        planVO.setJhzt(rwZt);
        ResponseWrapper resp= inspectionplanFeign.getInspectionplan(jhid);
        if(resp.isSuccess() && resp.getData()!=null){
            InspectionplanVO inspectionplanVO=JsonUtils.parse(JsonUtils.serialize(resp.getData()), InspectionplanVO.class);
            if(inspectionplanVO!=null){
                Date rwjsr=inspectionplanVO.getRwjsr();
                if(rwjsr!=null && rwjsr.compareTo(new Date())<0){
                    planVO.setJhzt(Integer.parseInt(TaskStatusConstant.ARTIMESAVE.getValue()));
                }
            }

        }
        return inspectionplanFeign.updateInspectionplanonly(planVO);
    }

/*
    @Override
    public ResponseWrapper inspectionTaskReturn(String rwId, Integer rwZt) {
        //if ("1".equals(type)) {
        // 回撤待下发
        if (rwZt == Integer.parseInt(TaskStatusConstant.TO_DXF.getValue())) {
            DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
            try {
                checkResultVO.setRwId(rwId);
                dailyCheckResultApi.deleteByEntity(checkResultVO);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        ResponseWrapper inspectionTaskUpdateByEntity = taskFeign.inspectionTaskUpdateByEntity(rwId, rwZt);
        if (inspectionTaskUpdateByEntity.getInfoCode() != 200) {
            return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "回撤失败", null);
        }
        // 完成 超期完成 更新 计划完成
        TaskVO taskVO = objectMapper.convertValue(inspectionTaskUpdateByEntity.getData(), TaskVO.class);
        //查询一个jhid下是否全部完成然后再更新状态
        if (rwZt == Integer.parseInt(TaskStatusConstant.DOSAVE.getValue()) && taskVO.getRemark().equals(TaskStatusConstant.TO_FP.getValue())) {
            // 更新计划状态
            InspectionplanVO inspectionplan = new InspectionplanVO();
            inspectionplan.setJhId(taskVO.getJhId());
            inspectionplan.setJhzt(taskVO.getRwZt());
            inspectionplanFeign.updateInspectionplanonly(inspectionplan);
        }
        return ResponseWrapper.success(HttpStatus.OK.value(), "回撤成功", taskVO);
        //}

        //if ("2".equals(type)) {
			*/
/*ResponseWrapper inspectionTaskDelete = taskFeign.inspectionTaskDelete(rwId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", inspectionTaskDelete);*//*

		*/
/*}
		return null;*//*

    }
*/

    /**
     * 制定任务 下发 检查组的新增保存/删除
     */
    /*
    public TaskTeamVO inspectionTaskInsertTeamImp(TaskTeamVO taskTeamVO) {
        //增加 rwzt==1 的  判断,使可以暂存---lph修改
        if (taskTeamVO.getRwZt() == 0 || taskTeamVO.getRwZt() == 1) {
            TaskVO taskVOv = new TaskVO();
            LsBeanUtils.copyAllProperties(taskTeamVO, taskVOv);
            taskVOv.setStatus(1);
            //第一步：是否分配检查组  非空 且  0
            //去除该判定,该判断会导致暂存  rwzt==1 的 时候无法保存数据---lph修改
            //if (taskVOv.getSffp() == 0) {
            //根据任务编号是否为空判断是否新增/(主表)更新（子列表删除）     （暂存 0 /  下发1   /下一步2）
            //隐藏
            taskVOv.setSfxs(Integer.parseInt(TaskStatusConstant.HIDE.getValue()));
            //检查任务 已下发
            taskVOv.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
            taskVOv = setSessionAll(taskVOv);

            if (StringUtils.isNotBlank(taskVOv.getJhId())){
                //修改计划
                inspectionplanFeign.updateInspectionplan(taskTeamVO.getInspectionplanVO());
            }else{
                //新增检查计划
                if(taskTeamVO.getInspectionplanVO() !=null){
                    ResponseWrapper responseWrapper= inspectionplanFeign.insert(taskTeamVO.getInspectionplanVO());
                    if(responseWrapper.isSuccess()){
                        InspectionplanVO inspectionplanVO=JsonUtils.parse(JsonUtils.serialize(responseWrapper.getData())
                                ,InspectionplanVO.class);
                        if(inspectionplanVO !=null){
                            taskTeamVO.setJhId(inspectionplanVO.getJhId());
                            taskVOv.setJhId(inspectionplanVO.getJhId());
                        }
                    }
                }
            }
            if(StringUtils.isEmpty(taskVOv.getJhId())){
                //没有计划id,则不能保存和继续执行
                return null;
            }

            //根据检查单位ID和计划ID判重
            TaskVO taskVOs = new TaskVO();
            ResponseWrapper taskInfoAllResponse = taskFeign.getTaskInfoAll(taskVOv.getJcdwId(), taskVOv.getJhId());
            if (taskInfoAllResponse.getInfoCode() == 200 && taskInfoAllResponse.getData() != null) {
                taskVOs = objectMapper.convertValue(taskInfoAllResponse.getData(), TaskVO.class);
            }
            if (StringUtils.isNotBlank(taskVOv.getRwId()) && taskVOs.getRwId() != null) {
                taskFeign.updateInspectionTask(taskVOv);
            } else if (StringUtils.isEmpty(taskVOv.getRwId()) && taskVOv.getRwId() == null) {
                //新增主键生成策略
                ResponseWrapper rwIdMaxCodeResponse = taskFeign.inspectionTaskMaxCodeById(taskVOv.getJhId());
                if (rwIdMaxCodeResponse.getInfoCode() == 200 && rwIdMaxCodeResponse.getData() != null) {
                    taskVOv.setRwId(objectMapper.convertValue(rwIdMaxCodeResponse.getData(), String.class));
                    taskFeign.inspectionTaskSave(taskVOv);
                }
            }
            //新增检查子项目
            if (taskVOv.getTaskCheckItemsVO() != null) {
                //新增之前现先根据任务ID 清除数据检查子项目数据
                taskFeign.taskCheckItemsVODelete(taskVOv.getRwId());
                TaskCheckItemsVO taskCheckItemsVO = new TaskCheckItemsVO();
                List<TaskCheckItemsVO> taskCheckItemsVOList = taskVOv.getTaskCheckItemsVO();
                for (TaskCheckItemsVO taskCheckItemsList : taskCheckItemsVOList) {
                    taskCheckItemsVO.setRwId(taskVOv.getRwId());
                    taskCheckItemsVO.setJcxmId(taskCheckItemsList.getJcxmId());
                    taskCheckItemsVO.setJcxmName(taskCheckItemsList.getJcxmName());
                    taskCheckItemsVO.setCreateDate(taskVOv.getCreateDate());
                    taskCheckItemsVO.setCreator(taskVOv.getCreator());
                    taskCheckItemsVO.setCreatorCode(taskVOv.getCreatorCode());
                    taskCheckItemsVO.setRefresher(taskVOv.getRefresher());
                    taskCheckItemsVO.setRefreshTime(taskVOv.getRefreshTime());
                    taskCheckItemsVO.setRefresherCode(taskVOv.getRefresherCode());
                    taskFeign.taskCheckItemsVOSave(taskCheckItemsVO);
                }
            }

            //新增检查内容
            if (taskVOv.getCheckContentVO() != null) {
                //新增之前现先根据任务ID 清除数据检查内容
                taskFeign.checkContentVODelete(taskVOv.getRwId());
                CheckContentVO checkContentVO = new CheckContentVO();
                List<CheckContentVO> checkContentVOList = taskVOv.getCheckContentVO();
                for (CheckContentVO checkContentList : checkContentVOList) {
                    checkContentVO.setRwId(taskVOv.getRwId());
                    checkContentVO.setJcnrId(checkContentList.getJcnrId());
                    checkContentVO.setJcnrName(checkContentList.getJcnrName());
                    checkContentVO.setCreateDate(taskVOv.getCreateDate());
                    checkContentVO.setCreator(taskVOv.getCreator());
                    checkContentVO.setCreatorCode(taskVOv.getCreatorCode());
                    checkContentVO.setRefresher(taskVOv.getRefresher());
                    checkContentVO.setRefreshTime(taskVOv.getRefreshTime());
                    checkContentVO.setRefresherCode(taskVOv.getRefresherCode());
                    taskFeign.checkContentVOSave(checkContentVO);
                }
            }
            List<TeamVO> teamVO = new ArrayList<TeamVO>();
            if (taskVOv.getTeamVOs() != null) {
                for (TeamVO team : taskVOv.getTeamVOs()) {
                    team.setRwId(taskVOv.getRwId());
                    teamVO.add(team);
                }
                //删除后新增
                teamFeign.deleteInspectionTeams(taskVOv.getRwId());
                teamFeign.saveInspectionPlanTeams(teamVO);
            }
            LsBeanUtils.copyAllProperties(taskVOv, taskTeamVO);
            //}
        } else {
            //下发为拥有检查组的
            //检查单位List
            List<InspectionUnitVO> inspectionUnitVOList = taskTeamVO.getInspectionUnitVO();
            if (inspectionUnitVOList == null) {
                return null;
            }
            for (InspectionUnitVO inspectionUnitVO : inspectionUnitVOList) {
                taskTeamVO.setJcdwId(inspectionUnitVO.getJcdwId());
                taskTeamVO.setJcdwmc(inspectionUnitVO.getJcdwName());
                TaskVO taskVO = new TaskVO();
                LsBeanUtils.copyAllProperties(taskTeamVO, taskVO);
                taskVO.setStatus(1);
                //第一步：是否分配检查组  非空 且  0
                if (taskVO.getSffp() == 0 ) {
                    //根据任务编号是否为空判断是否新增/(主表)更新（子列表删除）     （暂存 0 /  待下发1   /已下发2）
                    taskVO.setSfxs(0);
                    if (inspectionUnitVO.getJcdwId().equals(CurrentUtil.getOrgId())) {
                        //检查任务 待下发
                        // int i = Integer.parseInt(TaskStatusConstant.ARYXF.getValue());
                        taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));

                    } else {
                        //代表待分配
                        taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.TO_FP.getValue()));
                    }

                    taskVO = setSessionAll(taskVO);
                    //根据检查单位ID和计划ID判重
                    TaskVO taskVOs = new TaskVO();
                    ResponseWrapper taskInfoAllResponse = taskFeign.getTaskInfoAll(taskVO.getJcdwId(), taskVO.getJhId());
                    if (taskInfoAllResponse.getInfoCode() == 200 && taskInfoAllResponse.getData() != null) {
                        taskVOs = objectMapper.convertValue(taskInfoAllResponse.getData(), TaskVO.class);
                    }

                    if (taskVOs.getRwId() == null) {
                        //新增主键生成策略
                        ResponseWrapper rwIdMaxCodeResponse = taskFeign.inspectionTaskMaxCodeById(taskVO.getJhId());
                        if (rwIdMaxCodeResponse.getInfoCode() == 200 && rwIdMaxCodeResponse.getData() != null) {
                            taskVO.setRwId(objectMapper.convertValue(rwIdMaxCodeResponse.getData(), String.class));
                            //新增一条检查任务
                            taskFeign.inspectionTaskSave(taskVO);
                        }
                        //新增检查子项目
                        if (taskVO.getTaskCheckItemsVO() != null && taskVO.getRwId() != null) {
                            //新增之前现先根据任务ID 清除数据检查子项目数据
                            taskFeign.taskCheckItemsVODelete(taskVO.getRwId());
                            TaskCheckItemsVO taskCheckItemsVO = new TaskCheckItemsVO();
                            List<TaskCheckItemsVO> taskCheckItemsVOList = taskVO.getTaskCheckItemsVO();
                            for (TaskCheckItemsVO taskCheckItemsList : taskCheckItemsVOList) {
                                taskCheckItemsVO.setRwId(taskVO.getRwId());
                                taskCheckItemsVO.setJcxmId(taskCheckItemsList.getJcxmId());
                                taskCheckItemsVO.setJcxmName(taskCheckItemsList.getJcxmName());
                                taskCheckItemsVO.setCreateDate(taskVO.getCreateDate());
                                taskCheckItemsVO.setCreator(taskVO.getCreator());
                                taskCheckItemsVO.setCreatorCode(taskVO.getCreatorCode());
                                taskCheckItemsVO.setRefresher(taskVO.getRefresher());
                                taskCheckItemsVO.setRefreshTime(taskVO.getRefreshTime());
                                taskCheckItemsVO.setRefresherCode(taskVO.getRefresherCode());
                                taskFeign.taskCheckItemsVOSave(taskCheckItemsVO);
                            }
                        }

                        //新增检查内容
                        if (taskVO.getCheckContentVO() != null && taskVO.getRwId() != null) {
                            //新增之前现先根据任务ID 清除数据检查内容
                            taskFeign.checkContentVODelete(taskVO.getRwId());
                            CheckContentVO checkContentVO = new CheckContentVO();
                            List<CheckContentVO> checkContentVOList = taskVO.getCheckContentVO();
                            for (CheckContentVO checkContentList : checkContentVOList) {
                                checkContentVO.setRwId(taskVO.getRwId());
                                checkContentVO.setJcnrId(checkContentList.getJcnrId());
                                checkContentVO.setJcnrName(checkContentList.getJcnrName());
                                checkContentVO.setCreateDate(taskVO.getCreateDate());
                                checkContentVO.setCreator(taskVO.getCreator());
                                checkContentVO.setCreatorCode(taskVO.getCreatorCode());
                                checkContentVO.setRefresher(taskVO.getRefresher());
                                checkContentVO.setRefreshTime(taskVO.getRefreshTime());
                                checkContentVO.setRefresherCode(taskVO.getRefresherCode());
                                taskFeign.checkContentVOSave(checkContentVO);
                            }
                        }
                        //判断是否是本级检查组
                        if (inspectionUnitVO.getJcdwId().equals(CurrentUtil.getOrgId())) {
                            List<TeamVO> teamVO = new ArrayList<TeamVO>();
                            if (taskVO.getTeamVOs() != null) {
                                for (TeamVO team : taskVO.getTeamVOs()) {
                                    team.setRwId(taskVO.getRwId());
                                    team.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                                    teamVO.add(team);
                                }
                                //删除后新增
                                teamFeign.deleteInspectionTeams(taskVO.getRwId());

                                teamFeign.saveInspectionPlanTeams(teamVO);
                            }
                        }
                    } else {
                        taskVO.setRwId(taskVOs.getRwId());
                        taskFeign.updateInspectionTask(taskVO);
                    }

                }
                LsBeanUtils.copyAllProperties(taskVO, taskTeamVO);
                //下发
                TaskVO taskInfo = this.getTaskInfo(taskVO.getRwId(), taskVO.getJhId());
                this.inspectionTaskResultInsert(taskInfo);
            }
        }
        return taskTeamVO;
    }*/

    /**
     * 制定任务 下发 检查组的新增保存/删除
     */
    @Override
    public TaskTeamVO inspectionTaskInsertTeamImp(TaskTeamVO taskTeamVO) {
        //如果是暂存,可直接保存
        boolean  temp=taskTeamVO.getInspectionplanVO().getJhzt() !=2;

        //下发为拥有检查组的
        //检查单位List
        List<InspectionUnitVO> inspectionUnitVOList = taskTeamVO.getInspectionUnitVO();
        if (inspectionUnitVOList == null && !temp) {
            return null;
        }
        if (StringUtils.isNotBlank(taskTeamVO.getJhId())){
            //修改计划
            inspectionplanFeign.updateInspectionplan(taskTeamVO.getInspectionplanVO());
        }else{
            //新增检查计划
            if(taskTeamVO.getInspectionplanVO() !=null){
                InspectionplanVO planVO=taskTeamVO.getInspectionplanVO();
                planVO.setStatus(1);
                planVO.setCreateDate(new Date());
                planVO.setRefreshDate(new Date());
                planVO.setCreateor(CurrentUtil.getUserName());
                planVO.setRefresher(CurrentUtil.getUserName());
                planVO.setOrgId(CurrentUtil.getOrgId());
                ResponseWrapper responseWrapper=null;
                if(StringUtils.isEmpty(taskTeamVO.getJhId())){
                    responseWrapper= inspectionplanFeign.insert(planVO);
                }else{
                    responseWrapper= inspectionplanFeign.updateInspectionplan(planVO);
                }
                if(responseWrapper.isSuccess()){
                    InspectionplanVO inspectionplanVO=JsonUtils.parse(JsonUtils.serialize(responseWrapper.getData())
                            ,InspectionplanVO.class);
                    if(inspectionplanVO !=null){
                        taskTeamVO.setJhId(inspectionplanVO.getJhId());
                    }
                }
            }
        }
        if(StringUtils.isEmpty(taskTeamVO.getJhId())){
            //没有计划id,则不能保存和继续执行
            return null;
        }
        boolean insert=StringUtils.isEmpty( taskTeamVO.getRwId());
        List<String> inspectionUnitIdList = Lists.newArrayList();
        inspectionUnitIdList.isEmpty();
        if(inspectionUnitVOList!=null && inspectionUnitVOList.size()>0){
            for (InspectionUnitVO inspectionUnitVO : inspectionUnitVOList) {
            	String inspectionUnitId = inspectionUnitVO.getJcdwId();
            	if(StringUtils.isNotEmpty(inspectionUnitId) && !"LS001".equals(inspectionUnitId)) {
            		inspectionUnitIdList.add(inspectionUnitId);
            	}
                taskTeamVO.setJcdwId(inspectionUnitId);
                taskTeamVO.setJcdwmc(inspectionUnitVO.getJcdwName());
                TaskVO taskVO = new TaskVO();
                LsBeanUtils.copyAllProperties(taskTeamVO, taskVO);
                taskVO.setStatus(1);
                //第一步：是否分配检查组  非空 且  0
                if (insert) {
                    //根据任务编号是否为空判断是否新增/(主表)更新（子列表删除）     （暂存 0 /  待下发1   /已下发2）
                    taskVO.setSfxs(0);
                    //0分配检查组,1不分配则保持原样
                    if(taskVO.getSffp()==0){
                        if (inspectionUnitId.equals(CurrentUtil.getOrgId())) {
                            //检查任务 待下发
                            // int i = Integer.parseInt(TaskStatusConstant.ARYXF.getValue());
                            taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));

                        } else {
                            //代表待分配
                            taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.TO_FP.getValue()));
                        }
                    }
                    if(temp){
                        taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.TEMP.getValue()));
                    }

                    taskVO = setSessionAll(taskVO);
                    //根据检查单位ID和计划ID判重
//                    TaskVO taskVOs = new TaskVO();
//                    ResponseWrapper taskInfoAllResponse = taskFeign.getTaskInfoAll(taskVO.getJcdwId(), taskVO.getJhId());
//                    if (taskInfoAllResponse.getInfoCode() == 200 && taskInfoAllResponse.getData() != null) {
//                        taskVOs = objectMapper.convertValue(taskInfoAllResponse.getData(), TaskVO.class);
//                    }

                    //if (taskVOs.getRwId() == null) {
                    //新增主键生成策略
                    ResponseWrapper rwIdMaxCodeResponse = taskFeign.inspectionTaskMaxCodeById(taskVO.getJhId());
                    if (rwIdMaxCodeResponse.getInfoCode() == 200 && rwIdMaxCodeResponse.getData() != null) {
                        taskVO.setRwId(objectMapper.convertValue(rwIdMaxCodeResponse.getData(), String.class));
                        //新增一条检查任务
                        taskFeign.inspectionTaskSave(taskVO);
                    }
                  /* //新增检查子项目
                    if (taskVO.getTaskCheckItemsVO() != null && taskVO.getRwId() != null) {
                        //新增之前现先根据任务ID 清除数据检查子项目数据
                        taskFeign.taskCheckItemsVODelete(taskVO.getRwId());
                        TaskCheckItemsVO taskCheckItemsVO = new TaskCheckItemsVO();
                        List<TaskCheckItemsVO> taskCheckItemsVOList = taskVO.getTaskCheckItemsVO();
                        for (TaskCheckItemsVO taskCheckItemsList : taskCheckItemsVOList) {
                            taskCheckItemsVO.setRwId(taskVO.getRwId());
                            taskCheckItemsVO.setJcxmId(taskCheckItemsList.getJcxmId());
                            taskCheckItemsVO.setJcxmName(taskCheckItemsList.getJcxmName());
                            taskCheckItemsVO.setCreateDate(taskVO.getCreateDate());
                            taskCheckItemsVO.setCreator(taskVO.getCreator());
                            taskCheckItemsVO.setCreatorCode(taskVO.getCreatorCode());
                            taskCheckItemsVO.setRefresher(taskVO.getRefresher());
                            taskCheckItemsVO.setRefreshTime(taskVO.getRefreshTime());
                            taskCheckItemsVO.setRefresherCode(taskVO.getRefresherCode());
                            taskFeign.taskCheckItemsVOSave(taskCheckItemsVO);
                        }
                    }*/
                  /*  //新增检查内容
                    if (taskVO.getCheckContentVO() != null && taskVO.getRwId() != null) {
                        //新增之前现先根据任务ID 清除数据检查内容
                        taskFeign.checkContentVODelete(taskVO.getRwId());
                        CheckContentVO checkContentVO = new CheckContentVO();
                        List<CheckContentVO> checkContentVOList = taskVO.getCheckContentVO();
                        for (CheckContentVO checkContentList : checkContentVOList) {
                            checkContentVO.setRwId(taskVO.getRwId());
                            checkContentVO.setJcnrId(checkContentList.getJcnrId());
                            checkContentVO.setJcnrName(checkContentList.getJcnrName());
                            checkContentVO.setCreateDate(taskVO.getCreateDate());
                            checkContentVO.setCreator(taskVO.getCreator());
                            checkContentVO.setCreatorCode(taskVO.getCreatorCode());
                            checkContentVO.setRefresher(taskVO.getRefresher());
                            checkContentVO.setRefreshTime(taskVO.getRefreshTime());
                            checkContentVO.setRefresherCode(taskVO.getRefresherCode());
                            taskFeign.checkContentVOSave(checkContentVO);
                        }
                    }*/
                    //判断是否是本级检查组
                    if (inspectionUnitVO.getJcdwId().equals(CurrentUtil.getOrgId())) {
                        List<TeamVO> teamVO = new ArrayList<TeamVO>();
                        if (taskVO.getTeamVOs() != null && taskVO.getTeamVOs().size()>0) {
                            for (TeamVO team : taskVO.getTeamVOs()) {
                                team.setRwId(taskVO.getRwId());
                                team.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                                teamVO.add(team);
                            }
                            //删除后新增
                            teamFeign.deleteInspectionTeams(taskVO.getRwId());

                            teamFeign.saveInspectionPlanTeams(teamVO);
                        }
                    }
                } else {
                	if(taskTeamVO.getRwZt() ==2) {
                    	taskVO.setSfxs(0);
                	}
                    taskFeign.updateInspectionTask(taskVO);
                    if (inspectionUnitVO.getJcdwId().equals(CurrentUtil.getOrgId())) {
                        List<TeamVO> teamVO = new ArrayList<TeamVO>();
                        if (taskVO.getTeamVOs() != null && taskVO.getTeamVOs().size()>0) {
                            for (TeamVO team : taskVO.getTeamVOs()) {
                                if(StringUtils.isEmpty(team.getRwId())){
                                    team.setRwId(taskVO.getRwId());
                                    team.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                                }
                                teamVO.add(team);
                            }
                            //删除后新增
                            teamFeign.deleteInspectionTeams(taskVO.getRwId());

                            teamFeign.saveInspectionPlanTeams(teamVO);
                        }
                    }
                }
                //2是下发
                if(taskTeamVO.getRwZt() ==2){
                    LsBeanUtils.copyAllProperties(taskVO, taskTeamVO);
                    //下发
                    TaskVO taskInfo = this.getTaskInfo(taskVO.getRwId(), taskVO.getJhId());

                    taskInfo.setItemQuery(taskTeamVO.getItemQuery());
                    taskInfo.setItemUrl(taskTeamVO.getItemUrl());
                    taskInfo.setItemQueryHaveDone(taskTeamVO.getItemQueryHaveDone());
                    taskInfo.setItemUrlHaveDone(taskTeamVO.getItemUrlHaveDone());
                    // 添加待办
                    this.addBacklogUserList(taskTeamVO, taskInfo, insert, inspectionUnitIdList);
                    this.inspectionTaskResultInsert(taskInfo);
                }
                // 待分配添加待办
                InspectionplanVO  planVO = taskTeamVO.getInspectionplanVO();
                taskVO.setUserList(new ArrayList<ReceiverCollectionVO>());
                if(0 == taskTeamVO.getRwZt() && !ObjectUtils.isEmpty(planVO) && 2 == planVO.getJhzt()) {
                	taskVO.setItemQuery(taskTeamVO.getItemQuery());
                    taskVO.setItemUrl(taskTeamVO.getItemUrl());
                    taskVO.setItemQueryHaveDone(taskTeamVO.getItemQueryHaveDone());
                    taskVO.setItemUrlHaveDone(taskTeamVO.getItemUrlHaveDone());
                    this.addBacklogUserList(taskTeamVO, taskVO, insert, inspectionUnitIdList);

                	// 添加待办 事项主键生成规则 任务id + 计划Id + 当前状态码
                	backlogService.addNeedToDeals(taskVO.getRwId() + "-" + taskVO.getRwName() + "-" + taskVO.getBacklogTaskStatus(), taskVO.getTitle(), taskVO.getBacklogTaskStatus(), taskVO.getStatusName()
                            ,null,null
                            ,taskVO.getItemUrl(), taskVO.getItemQuery(),taskVO.getItemQueryHaveDone(),taskVO.getItemUrlHaveDone(), null, taskVO.getUserList());
                }
            }
        }
        return taskTeamVO;
    }
    
    public void addBacklogUserList(TaskTeamVO taskTeamVO, TaskVO task, boolean insert, List<String> inspectionUnitIdList) {
    	/**
         * 制定任务待办
         * 一.待分配 二.已下发（1.分配本级检查组 2.检查单位包含下级单位时）
         */
        //当操作为新增 且下发时生成待办
        if(insert) { 
        	//待分配 当本级不分配检查组时为待分配
        	Integer isAllocation = task.getSffp();
        	if(null == isAllocation) {
        		isAllocation = taskTeamVO.getSffp();
        	}
        	List<ReceiverCollectionVO> userList = Lists.newArrayList();
        	if(null != isAllocation && 1 == isAllocation) {
        		// 待分配 : 待办接收人为 任务对应的市局或区粮办
        		for(String unitId : inspectionUnitIdList) {
        			this.addBacklogUserList(unitId, userList,false);
        		}
        		String taskTypeId = task.getRwlx();
        		if("5000110".equals(taskTypeId) && task.getJcdwId().equals("LS001")) { // 日常检查 待办推送给监督检查处
        			this.addBacklogUserList("DP353", userList,true);
        		} else if(("5000120".equals(taskTypeId) || "5000160".equals(taskTypeId)) && task.getJcdwId().equals("LS001")) { // 防汛或专项检查 待办推送到粮食储备处
        			this.addBacklogUserList("DP355", userList,true);
        		}
        		task.setTitle("制定任务（"+task.getRwName()+"）待分配");
        		task.setBacklogTaskStatus(TaskStatusConstant.TO_FP.getValue());
        		task.setStatusName(TaskStatusConstant.TO_FP.getName());
        	} else if (null != isAllocation && 0 == isAllocation) {
        		// 已下发  分配检查组 检查单位包含下级
        		// 添加检查组成员
        		if(task.getJcdwId().equals("LS001")) {
        			List<TeamVO> teamVOList = taskTeamVO.getTeamVOs();
            		teamVOList.parallelStream().forEach( team -> {
            			List<MemberVO> members = team.getMembers();
            			members.forEach(user -> {
            				ReceiverCollectionVO vo = new ReceiverCollectionVO();
            				vo.setUserId(user.getZyId());
            				vo.setUserName(user.getZyName());
            				userList.add(vo);
            			});
            		});
            		task.setBacklogTaskStatus(TaskStatusConstant.ARYXF.getValue());
            		task.setStatusName(TaskStatusConstant.ARYXF.getName());
        		} else {
            		task.setBacklogTaskStatus(TaskStatusConstant.TO_FP.getValue());
            		task.setStatusName(TaskStatusConstant.TO_FP.getName());
            		task.setItemQuery(taskTeamVO.getItemQueryTwo());
            		task.setItemUrl(taskTeamVO.getItemUrlTwo());
            		task.setItemQueryHaveDone(taskTeamVO.getItemQueryHaveDoneTwo());
            		task.setItemUrlHaveDone(taskTeamVO.getItemUrlHaveDoneTwo());
        		}
        		// 添加下级检查单位人员
        		for(String unitId : inspectionUnitIdList) {
        			this.addBacklogUserList(unitId, userList, false);
        		}
        		task.setTitle(task.getRwlxName()+"（"+task.getRwName()+"）待分配");
        	}
        	task.setUserList(userList);
        }
    }
    
    public void addBacklogUserList(String unitId, List<ReceiverCollectionVO> userList,boolean isDepartment) {
    	String tag = "";
    	if(!isDepartment) {
    		tag = "1";
    	}
    	ResponseWrapper result = userClient.findUserDeptId(unitId, tag, "");
		if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
			Object obj = result.getData();
			JSONArray arr = JSON.parseArray(JsonUtils.serialize(obj));
			arr.forEach( user -> {
				JSONObject userObj = (JSONObject)user;
				ReceiverCollectionVO vo = new ReceiverCollectionVO();
				vo.setUserId(userObj.getString("userCode"));
				vo.setUserName(userObj.getString("userName"));
				userList.add(vo);
			});
		}
    }

    /**
     * 制定任务 下发 检查组的新增保存/删除
     */
    @Override
    public ResponseWrapper inspectionTaskTeamDistributes(TaskTeamVO taskTeamVO) {
        TaskVO taskVO = new TaskVO();
        LsBeanUtils.copyAllProperties(taskTeamVO, taskVO);
        ResponseWrapper responseWrapper=taskFeign.updateInspectionTask(taskVO);
        if(responseWrapper.isSuccess()){
            List<TeamVO> teamVO = new ArrayList<TeamVO>();
            if (taskVO.getTeamVOs() != null && taskVO.getTeamVOs().size()>0) {
                for (TeamVO team : taskVO.getTeamVOs()) {
                    if(StringUtils.isEmpty(team.getRwId())){
                        team.setRwId(taskVO.getRwId());
                        team.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                    }
                    teamVO.add(team);
                }
                //删除后新增
                teamFeign.deleteInspectionTeams(taskVO.getRwId());

                teamFeign.saveInspectionPlanTeams(teamVO);
            }
            if(taskTeamVO.getRwZt() ==2){
                TaskVO taskInfo = this.getTaskInfo(taskTeamVO.getRwId(), taskTeamVO.getJhId());
                taskInfo.setItemQuery(taskTeamVO.getItemQuery());
                taskInfo.setItemUrl(taskTeamVO.getItemUrl());
                taskInfo.setItemQueryHaveDone(taskTeamVO.getItemQueryHaveDone());
                taskInfo.setItemUrlHaveDone(taskTeamVO.getItemUrlHaveDone());
                //清理待办 表示待分配状态清楚
                backlogService.addDeals(taskTeamVO.getRwId() + "-" + taskTeamVO.getRwName() + "-0", null, TaskStatusConstant.ARYXF.getValue(), TaskStatusConstant.ARYXF.getName());
                // 添加待办
                this.addBacklogUserList(taskTeamVO, taskInfo, true, Lists.newArrayList());
                ResponseWrapper resp=inspectionTaskResultInsert(taskInfo);
                return resp;
            }
        }
        return responseWrapper;
    }

    /**
     * 日常检查-储备粮新增更新
     */
    @Override
    public ReserveGrainVO inspectionTaskCbl(ReserveGrainVO reserveGrainVO) {
        try {
            //Copy
            TaskVO taskVO = new TaskVO();
            LsBeanUtils.copyAllProperties(reserveGrainVO, taskVO);
            //新增任务表返回数据
            ResponseWrapper inspectionTaskEditVO = taskFeign.inspectionTaskEdit(taskVO);
            if (inspectionTaskEditVO.getInfoCode() == 200 && inspectionTaskEditVO.getData() != null) {
                TaskVO taskV = objectMapper.convertValue(inspectionTaskEditVO.getData(), TaskVO.class);
                //调用接口
                if (StringUtils.isNotBlank(taskV.getRwId())) {
                    reserveGrainVO.setRwId(taskV.getRwId());
                    //封装 DailyCheckResultVO
                    DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
                    LsBeanUtils.copyAllProperties(reserveGrainVO, dailyCheckResultVO);
                    // 添加待办(储备粮日常检查 待整改)
                    String checkStatus = dailyCheckResultVO.getJgTbbh();
                    String taskTypeId = dailyCheckResultVO.getRwlxId();
					if (StringUtils.isNotEmpty(checkStatus) && "3".equals(checkStatus)
							&& StringUtils.isNotEmpty(taskTypeId) && "5000150".equals(taskTypeId)) {
						ResponseWrapper result = userClient.findUserDeptId(dailyCheckResultVO.getBjdwId(), "1", "");
	        			if(result.isSuccess() && !ObjectUtils.isEmpty(result.getData())) {
	        				Object obj = result.getData();
	        				List<ReceiverCollectionVO> userList = Lists.newArrayList();
	        				JSONArray arr = JSON.parseArray(JsonUtils.serialize(obj));
	        				arr.forEach( user -> {
	        					JSONObject userObj = (JSONObject)user;
	        					ReceiverCollectionVO vo = new ReceiverCollectionVO();
	        					vo.setUserId(userObj.getString("userCode"));
	        					vo.setUserName(userObj.getString("userName"));
	        					userList.add(vo);
	        				});
	        				dailyCheckResultVO.setUserList(userList);
	        				dailyCheckResultVO.setItemUrl(reserveGrainVO.getItemUrl());
	        				dailyCheckResultVO.setItemQuery(reserveGrainVO.getItemQuery());

	        				dailyCheckResultVO.setItemQueryHaveDone(reserveGrainVO.getItemQueryHaveDone());
	        				dailyCheckResultVO.setItemUrlHaveDone(reserveGrainVO.getItemUrlHaveDone());
	        			}
					}

					if( ("5000180".equals(taskTypeId)
                            && ("7".equals(checkStatus) || "12".equals(checkStatus)) )
                        || ( ("5000170".equals(taskTypeId) || "5000150".equals(taskTypeId)) &&  ("1".equals(checkStatus) || "7".equals(checkStatus)) )
                        ){
                        String userName=CurrentUtil.getUserName();
                        String userId=CurrentUtil.getUserId();

                        List<ReceiverCollectionVO> userList=new ArrayList<>();
                        ReceiverCollectionVO receiverCollectionVO=new ReceiverCollectionVO();
                        receiverCollectionVO.setUserName(userName);
                        receiverCollectionVO.setUserId(userId);
                        userList.add(receiverCollectionVO);
                        dailyCheckResultVO.setUserList(userList);
                    }

                    //返回结果新增
                    ResponseWrapper inspectionTaskResultInsert = dailyCheckResultApi.insertEntitySelective(dailyCheckResultVO);
                    if (inspectionTaskResultInsert.getInfoCode() == 200) {
                        // 更新任务状态
                        taskV.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                        taskV.setXfTime(DateUtil.getNowDate());
                        taskV.setUserId(CurrentUtil.getUserId());
                        taskV.setUserName(CurrentUtil.getUserName());
                        taskV = setSessionAll(taskV);
                        taskFeign.updateInspectionTask(taskV);

                        DailyCheckResultVO dailyCheckResultVO2 = JsonUtils.parse(JsonUtils.serialize(inspectionTaskResultInsert.getData()), DailyCheckResultVO.class);

                        reserveGrainVO.setJgId(dailyCheckResultVO2.getJgId());

                        AppVO appVO=new AppVO();
                        // 日常检查等
                        fillAppVO(checkStatus,taskTypeId,appVO);

                        //添加待办
                        if(dailyCheckResultVO.getJgTbbh().equals("1")|| dailyCheckResultVO.getJgTbbh().equals("2")) {//直接提交添加待办
                        	//R0000164       储备粮公司

                            String nm=null;
                            if(dailyCheckResultVO.getJgTbbh().equals("1")){
                                nm="待盖章";
                            }else{
                                nm="编辑";
                            }

                            //只有待盖章的状态是给角色，其他任何状态都是给检查组，这里不分类型
                        	//userService.addRoleUserList2(dailyCheckResultVO, "R0000164");
                            List<MemberVO> members = reserveGrainVO.getMembers();
                            List<ReceiverCollectionVO> receiverCollectionVOs = new ArrayList<ReceiverCollectionVO>();
                            for(MemberVO memberVO: members) {
                                ReceiverCollectionVO vo = new ReceiverCollectionVO();
                                vo.setUserId(memberVO.getZyId());
                                vo.setUserName(memberVO.getZyName());
                                receiverCollectionVOs.add(vo);

                            }

                        	backlogService.addNeedToDeals(dailyCheckResultVO2.getJgId()+"-"+dailyCheckResultVO2.getRwlxId() + "-" + dailyCheckResultVO2.getJgTbbh(), dailyCheckResultVO2.getRwlxMc()+"（"+dailyCheckResultVO2.getRwmc()+"）"+nm, taskVO.getBacklogTaskStatus(), dailyCheckResultVO2.getJgTbmc()
                                    ,appVO.getIspad(),appVO.getTyname()
                                    ,taskVO.getItemUrl(), taskVO.getItemQuery(),taskVO.getItemQueryHaveDone(),taskVO.getItemUrlHaveDone(), reserveGrainVO.getBjdwName(),receiverCollectionVOs);
                            
                        } else if(dailyCheckResultVO.getJgTbbh().equals("7")) {//直接提交添加待办
                            //R0000141         承储企业盖章
                        	userService.addRoleUserList2(dailyCheckResultVO, "R0000141");
                        	backlogService.addNeedToDeals(dailyCheckResultVO2.getJgId()+"-"+dailyCheckResultVO2.getRwlxId() + "-" + dailyCheckResultVO2.getJgTbbh(), dailyCheckResultVO2.getRwlxMc()+"（"+dailyCheckResultVO2.getRwmc()+"）待盖章", taskVO.getBacklogTaskStatus(), dailyCheckResultVO2.getJgTbmc()
                                    ,appVO.getIspad(),appVO.getTyname()
                                    , taskVO.getItemUrl(), taskVO.getItemQuery(),taskVO.getItemQueryHaveDone(),taskVO.getItemUrlHaveDone() ,reserveGrainVO.getBjdwName(),dailyCheckResultVO.getUserList());


                        }
                        //这部分加的不对,应该还是要在结果反馈加
                        /*else if("5000110".equals(taskTypeId) && dailyCheckResultVO.getJgTbbh().equals("17")){


                        }else{
                            if(StringUtils.isNotEmpty(appVO.getAction())){
                                List<MemberVO> members = reserveGrainVO.getMembers();
                                List<ReceiverCollectionVO> receiverCollectionVOs = new ArrayList<ReceiverCollectionVO>();
                                for(MemberVO memberVO: members) {
                                    ReceiverCollectionVO vo = new ReceiverCollectionVO();
                                    vo.setUserId(memberVO.getZyId());
                                    vo.setUserName(memberVO.getZyName());
                                    receiverCollectionVOs.add(vo);

                                }
                                backlogService.addNeedToDeals(dailyCheckResultVO2.getJgId()+"-"+dailyCheckResultVO2.getRwlxId() + "-" + dailyCheckResultVO2.getJgTbbh(), dailyCheckResultVO2.getRwlxMc()+"（"+dailyCheckResultVO2.getRwmc()+"）"+appVO.getAction(), taskVO.getBacklogTaskStatus(), dailyCheckResultVO2.getJgTbmc()
                                        ,appVO.getIspad(),appVO.getTyname()
                                        ,taskVO.getItemUrl(), taskVO.getItemQuery(),taskVO.getItemQueryHaveDone(),taskVO.getItemUrlHaveDone(), receiverCollectionVOs);
                            }
                        }*/
                    }else{

                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
        return reserveGrainVO;
    }

    /**
     * 安全生产检查回调
     * @return
     */
    public void callBackOnFinish(String jhid){
        DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
        dailyCheckResultVO.setJhid(jhid);
        ResponseWrapper responseWrapper = dailyCheckResultApi.selectByEntity(dailyCheckResultVO);
        if(responseWrapper.isSuccess()){
            List<DailyCheckResultVO> resultVOList=JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), DailyCheckResultVO.class);
            boolean done = true;
            for (DailyCheckResultVO temp : resultVOList) {
                if (!(DailyCheckStatusConstant.OVERDUE_FINISH.getValue().equals(temp.getJgTbbh())
                        || DailyCheckStatusConstant.FINISHED.getValue().equals(temp.getJgTbbh()))) {
                    done = false;
                    break;
                }
            }
            InspectionplanVO planVO=new InspectionplanVO();
            if(done){
                planVO.setJhId(jhid);
                planVO.setJhzt(Integer.parseInt(TaskStatusConstant.DOSAVE.getValue()));
                inspectionplanFeign.updateInspectionplanonly(planVO);
            }else{
                planVO.setJhId(jhid);
                planVO.setJhzt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
                inspectionplanFeign.updateInspectionplanonly(planVO);
            }
        }
    }

    private  void fillAppVO(String checkResultStatus, String taskTypeId, AppVO appVO){
        if("5000110".equals(taskTypeId)) {
            //日常检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000110");
                    appVO.setAction("待检查");
                    break;
                case "17":       //区粮办办结处理
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("区粮办办结处理");
                    break;
                case "23":       //办结处理
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("办结处理");
                    break;
                case "18":       //组长审批
                    appVO.setIspad("1");
                    appVO.setTyname("REVIEW-5000110");
                    appVO.setAction("组长审批");
                    break;
                case "31":       //待送达
                    appVO.setIspad("1");
                    appVO.setTyname("ACCEPT-5000110");
                    appVO.setAction("待送达");
                    break;
                default:
                    break;
            }

        }else if("5000120".equals(taskTypeId)){
            //防汛检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000120");
                    appVO.setAction("待检查");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000110");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        }else if("5000140".equals(taskTypeId)){
            //专项检查-监督检查处
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000140");
                    appVO.setAction("待检查");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000140");
                    appVO.setAction("待验收");
                    break;
                case "31":       //待送达
                    appVO.setIspad("1");
                    appVO.setTyname("ACCEPT-5000140");
                    appVO.setAction("待送达");
                    break;
                default:
                    break;
            }
        }else if("5000150".equals(taskTypeId)){
            //市级储备成品粮油检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000150");
                    appVO.setAction("待检查");
                    break;
                case "1":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("SUB-5000150");
                    appVO.setAction("检查单位盖章办结");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000150");
                    appVO.setAction("新增");
                    break;
                case "7":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("BJG-5000150");
                    appVO.setAction("被检单位盖章");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000150");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        }else if("5000160".equals(taskTypeId)){
            //专项检查-粮食储备处
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000160");
                    appVO.setAction("待检查");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000160");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        }else if("5000170".equals(taskTypeId)){
            //市级储备原粮检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000170");
                    appVO.setAction("待检查");
                    break;
                case "1":       //pad提交
                    appVO.setIspad("1");
                    appVO.setTyname("SUB-5000170");
                    appVO.setAction("检查单位盖章提交");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000170");
                    appVO.setAction("新增");
                    break;
                case "7":       //pad提交
                    appVO.setIspad("1");
                    appVO.setTyname("BJG-5000170");
                    appVO.setAction("被检单位盖章提交");
                    break;
                case "10":       //待验收
                    appVO.setIspad("1");
                    appVO.setTyname("DEAL-5000170");
                    appVO.setAction("待验收");
                    break;
                default:
                    break;
            }
        }else if("5000180".equals(taskTypeId)){
            //安全生产检查
            switch (checkResultStatus) {
                case "0":       //待检查
                    appVO.setIspad("1");
                    appVO.setTyname("CHECK-5000180");
                    appVO.setAction("待检查");
                    break;
                case "2":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("ADD-5000180");
                    appVO.setAction("新增");
                    break;
                case "7":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("BJG-5000180");
                    appVO.setAction("被检单位盖章");
                    break;
                case "12":       //新增
                    appVO.setIspad("1");
                    appVO.setTyname("JGT-5000180");
                    appVO.setAction("结果填报新增");
                    break;
                default:
                    break;
            }
        }
    }

    /**
     * 任务下发
     *
     * @return
     */
    @Override
    public ResponseWrapper inspectionTaskResultInsert(TaskVO taskVO) {
        //封装 DailyCheckResultVO
        DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
        //任务ID
        dailyCheckResultVO.setRwId(taskVO.getRwId());
        dailyCheckResultVO.setRwlxMc(taskVO.getRwlxName());
        dailyCheckResultVO.setJhid(taskVO.getJhId());
        dailyCheckResultVO.setRwmc(taskVO.getRwName());
        dailyCheckResultVO.setJcdwId(taskVO.getJcdwId());
        dailyCheckResultVO.setJcdwmc(taskVO.getJcdwmc());
        dailyCheckResultVO.setJcfs(taskVO.getJcfs());
        dailyCheckResultVO.setRwlxId(taskVO.getRwlx());
        dailyCheckResultVO.setJckssj(taskVO.getJckssjDate());
        dailyCheckResultVO.setJcjssj(taskVO.getJcjssjDate());
        //检查结果表单
        List<DailyCheckResultDetailVO> detailList = new ArrayList<DailyCheckResultDetailVO>();
        //获取任务检查表单
        List<TaskFormVO> taskFormVO = taskVO.getTaskFormVO();
        if (taskFormVO != null) {
            for (TaskFormVO taskFormVOList : taskFormVO) {
                DailyCheckResultDetailVO dailyCheckResultDetailVO = new DailyCheckResultDetailVO();
                dailyCheckResultDetailVO.setBdId(taskFormVOList.getBdId());
                dailyCheckResultDetailVO.setBdName(taskFormVOList.getBdName());
                dailyCheckResultDetailVO.setBdLu(taskFormVOList.getBdLu());
                detailList.add(dailyCheckResultDetailVO);
            }
        }
        dailyCheckResultVO.setDetailList(detailList);
        //获取被检企业列表rwlxId
        List<InspectedUnitsVO> bjcdwList = taskVO.getInspectedUnitsVO();

        //遍历bjcdwList
        if (bjcdwList != null && bjcdwList.size() > 0) {
            for (InspectedUnitsVO inspectedUnitsVOList : bjcdwList) {
                //通过企业名称获取企业详情
                String bjdwName = inspectedUnitsVOList.getBjdwName();
                if (StringUtils.isNotEmpty(bjdwName)) {
                    CompanyQueryVO companyQueryVO = new CompanyQueryVO();
                    companyQueryVO.setQymc(bjdwName);
                    ResponseWrapper companyByBjdwName = companyFeign.getCompanyList(companyQueryVO);
                    if (companyByBjdwName.isSuccess()) {
                        //企业信息
                        List<CompanyVO> companyVOList = JsonUtils.parseList(JsonUtils.serialize(companyByBjdwName.getData()), CompanyVO.class);
                        if (companyVOList != null && companyVOList.size() == 1) {
                            CompanyVO companyVO = companyVOList.get(0);
                            String qyzyyw = companyVO.getQyzyyw();
                            if ("地方储备粮承储".equals(qyzyyw)) {
                                dailyCheckResultVO.setDfcblccqy(CORRECT);//是地方储备粮承储
                            } else {
                                dailyCheckResultVO.setDfcblccqy(FAULT);//不是地方储备粮承储
                            }
                            dailyCheckResultVO.setBjdwZz(companyVO.getQytxdz());//被检单位地址
                            dailyCheckResultVO.setZzjgdm(companyVO.getZzjgdm());//粮食收购许可证
                            dailyCheckResultVO.setBjdwFddbr(companyVO.getFddbr());//法定代表人
                            dailyCheckResultVO.setBjdwLxdh(companyVO.getBgdh());//联系电话
                            dailyCheckResultVO.setQyzcd(companyVO.getQygszcd());//企业注册地
                            dailyCheckResultVO.setQyszd(companyVO.getQytxdz());//企业所在地
                        }
                    }
                }

                dailyCheckResultVO.setBjdwId(inspectedUnitsVOList.getBjdwId());
                dailyCheckResultVO.setBjdwName(inspectedUnitsVOList.getBjdwName());
                ResponseWrapper resp=companyFeign.getSlqy(inspectedUnitsVOList.getBjdwId());
                String tyshxydm=null;
                if(resp.isSuccess() && resp.getData()!=null){
                    Map map=  (Map)resp.getData();
                    if(map!=null){
                        tyshxydm=(String)map.get("tyshxydm");
                    }
                }
                if(tyshxydm!=null){
                    dailyCheckResultVO.setBjdwTyshxydm(tyshxydm);
                }else{
                    dailyCheckResultVO.setBjdwTyshxydm("xydm");
                }
                try {
                    //进taskFeign
                    //调用接口
                    ResponseWrapper inspectionTaskResultInsert = dailyCheckResultApi.insertEntitySelective(dailyCheckResultVO);
                    if(inspectionTaskResultInsert.isSuccess()) {
                    	//返回数据解析
                    	DailyCheckResultVO dailyCheckResultVO2 = JsonUtils.parse(JsonUtils.serialize(inspectionTaskResultInsert.getData()), DailyCheckResultVO.class);
                    	ResponseWrapper wrapper=teamFeign.getInspectionTeam(dailyCheckResultVO2.getRwId(),dailyCheckResultVO2.getBjdwId());
                    	if(wrapper.isSuccess()) {
                    		TeamVO teamVO = JsonUtils.parse(JsonUtils.serialize(wrapper.getData()),TeamVO.class);
                    		List<MemberVO> members = teamVO.getMembers();
                        	List<ReceiverCollectionVO> receiverCollectionVOs = new ArrayList<ReceiverCollectionVO>();
                    		for(MemberVO memberVO: members) {
                        		ReceiverCollectionVO vo = new ReceiverCollectionVO();
                        		vo.setUserId(memberVO.getZyId());
                        		vo.setUserName(memberVO.getZyName());
                        		receiverCollectionVOs.add(vo);
                        		
                        	}

                            AppVO appVO=new AppVO();
                            // 日常检查等
                            String checkStatus = dailyCheckResultVO2.getJgTbbh();
                            String taskTypeId = dailyCheckResultVO2.getRwlxId();
                            fillAppVO(checkStatus,taskTypeId,appVO);

                        	// 添加待办 事项主键生成规则 结果id + 任务Id  + 当前状态码
                        	backlogService.addNeedToDeals(dailyCheckResultVO2.getJgId()+"-"+dailyCheckResultVO2.getRwlxId() + "-" + dailyCheckResultVO2.getJgTbbh(), dailyCheckResultVO2.getRwlxMc()+"（"+dailyCheckResultVO2.getRwmc()+"）待检查", taskVO.getBacklogTaskStatus(), dailyCheckResultVO2.getJgTbmc()
                                    ,appVO.getIspad(),appVO.getTyname()
                                    ,taskVO.getItemUrl(), taskVO.getItemQuery(),taskVO.getItemQueryHaveDone(),taskVO.getItemUrlHaveDone(), bjdwName, receiverCollectionVOs);
                            
                    	} else {
                         		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败", null);
                    	}
                    }
//                    if (inspectionTaskResultInsert.getInfoCode() != 200) {
//                        return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "下发失败", null);
//                    }
//                    if (taskVO.getRwZt().equals(0)||taskVO.getRwZt().equals(2)) {
//                        StartTodoVO startTodoVO = new StartTodoVO();
//                        startTodoVO.setBusinessName(taskVO.getRwName());
//                        startTodoVO.setBusinessType("CHECK" + "-" + taskVO.getRwlx());
//                        startTodoVO.setBusinessTypeName(taskVO.getRwlxName());
//                        DailyCheckResultVO dailyCheckResultVO1 = new DailyCheckResultVO();
//                        startTodoVO.setCompleteStatus("待检查");
//                        startTodoVO.setMessage("审核状态");
//                        startTodoVO.setDueDate(String.valueOf(taskVO.getJckssjDate()));
//                        DailyCheckResultVO dailyCheckResultVO2 = JsonUtils.parse(JsonUtils.serialize(inspectionTaskResultInsert.getData()), DailyCheckResultVO.class);
//                        dailyCheckResultVO1.setJgId(dailyCheckResultVO2.getJgId());
//                        ResponseWrapper dailyCheckResultVOS = dailyCheckResultApi.selectById(dailyCheckResultVO1);
//                        DailyCheckResultVO dailyCheckResult = JsonUtils.parse(JsonUtils.serialize(dailyCheckResultVOS.getData()), DailyCheckResultVO.class);
//                        startTodoVO.setCompanyName(dailyCheckResult.getBjdwName());
//                        if (dailyCheckResultVO1 != null) {
//                            startTodoVO.setId(dailyCheckResultVO1.getJgId());
//                        }
//                        List<String> list = new ArrayList<>();
//                        //判断是否为本级下发   teamVOs不为空则非本级检查组反之则是本级检查组
//                        if (taskVO.getTeamVOs() == null) {
//                            ResponseWrapper teamResponseWrapper = teamFeign.getIinspectionTeamList(taskVO.getRwId());
//                            List<TeamVO> teamVO = JsonUtils.parseList(JsonUtils.serialize(teamResponseWrapper.getData()), TeamVO.class);
//                            ArrayList<MemberVO> memberVOS = new ArrayList<>();
//                            for (TeamVO teamvos : teamVO) {
//                                LsBeanUtils.copyCollection(teamvos.getMembers(), memberVOS, MemberVO.class);
//                            }
//                            list.add("U0000260");
//                            for (MemberVO taskVO1 : memberVOS) {
//                                list.add(taskVO1.getZyId());
//                            }
//                            String str = list.toString();
//                            startTodoVO.setRoleId(str);
//                        }
//                        //组员集合
//                        else {
//                            ArrayList<MemberVO> memberVOS = new ArrayList<>();
//                            for (TeamVO teamvos : taskVO.getTeamVOs()) {
//                                LsBeanUtils.copyCollection(teamvos.getMembers(), memberVOS, MemberVO.class);
//                            }
//                            list.add("U0000260");
//                            for (MemberVO taskVO1 : memberVOS) {
//                                list.add(taskVO1.getZyId());
//                            }
//                            String str = list.toString();
//                            startTodoVO.setRoleId(str);
//                    }

//                        ResponseWrapper responseWrapper = flowTodoClient.startNewTask(startTodoVO);
//						System.out.println(responseWrapper.getInfoCode()+responseWrapper.getData().toString());
//                        log.error(responseWrapper.getInfoCode() + responseWrapper.getData().toString());
//                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败", null);
                }
            }
            // 更新任务状态
            taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()));
            taskVO.setXfTime(DateUtil.getNowDate());
            taskVO.setUserId(CurrentUtil.getUserId());
            taskVO.setUserName(CurrentUtil.getUserName());
            taskVO = this.setSessionAll(taskVO);
            ResponseWrapper result = taskFeign.updateInspectionTask(taskVO);
            return result;
        } else {
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败，被检企业不能为空", null);
        }
    }

    /**
     * (非 Javadoc)
     * <p>Title: inspectionJhTaskCq</p>
     * <p>Description: </p>
     *
     * @return
     * @see com.unis.inspection.service.InspectionTaskService#inspectionJhTaskCq()
     */
    @Override
    @Scheduled(cron = "0 0 1  * *  ? ")
//	@Scheduled(cron="0/300 * *  * * ? ")
    public List<TaskVO> inspectionJhTaskCq() {
        TaskQueryVO taskQueryVO = new TaskQueryVO();
        List<TaskVO> taskVOList = new ArrayList<TaskVO>();
        ResponseWrapper taskMainLists = taskFeign.inspectionJhTaskCq(taskQueryVO);
        try {

            if (taskMainLists.getInfoCode() == 200) {
                //分页查询列表数据
                taskVOList = JsonUtils.parseList(JsonUtils.serialize(objectMapper.convertValue(taskMainLists.getData(), List.class)), TaskVO.class);
                if (taskVOList.size() > 0) {
                    //转换成json
                    System.err.println("===============  Execute 注意：扫描任务数据开始！=============" + new Date());
                    //转换成json
                    Iterator<TaskVO> iterator = taskVOList.iterator();
                    while (iterator.hasNext()) {
                        Object taskvo = iterator.next();
                        TaskVO taskVO = (TaskVO) taskvo;
                        //如果超过结束时间已下发直接更新到已超期
                        if (taskVO.getJckssjDate() != null && taskVO.getJcjssjDate() != null) {

                            if (new Date().compareTo(taskVO.getJcjssjDate())>0 && taskVO.getRwZt().equals(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()))) {
                                // 更新任务状态
                                taskVO.setRwZt(Integer.parseInt(TaskStatusConstant.ARTIME.getValue()));
                                taskFeign.updateInspectionTask(taskVO);
                            }

                        }
                    }
                    System.err.println("===============  Execute 注意：任务派发扫描数据结束！=============" + new Date());
                }
            }

            // ====================主任务超期检查使用InspectionPlanOverdueSchedule========================================
            /*InspectionplanQueryVO inspectionplanQueryVo = new InspectionplanQueryVO();
            List<InspectionplanVO> inspectionplanVOList = new ArrayList<InspectionplanVO>();
            ResponseWrapper inspectionplanMainLists = inspectionplanFeign.inspectionplanMain(inspectionplanQueryVo);
            if (inspectionplanMainLists.getInfoCode() == 200) {
                //分页查询列表数据
                inspectionplanVOList = JsonUtils.parseList(JsonUtils.serialize(objectMapper.convertValue(inspectionplanMainLists.getData(), List.class)), InspectionplanVO.class);
                if (inspectionplanVOList.size() > 0) {
                    //转换成json
                    System.err.println("===============  Execute 注意：扫描计划数据开始！=============" + new Date());
                    //转换成json
                    Iterator<InspectionplanVO> iterator = inspectionplanVOList.iterator();
                    while (iterator.hasNext()) {
                        Object inspectionplan = iterator.next();
                        InspectionplanVO inspectionplanVO = (InspectionplanVO) inspectionplan;
                        //如果超过结束时间已下发直接更新到已超期
                        if (inspectionplanVO.getRwqsr() != null && inspectionplanVO.getRwjsr() != null) {
                            if (!dateCompare(DateUtil.getNowDate(), inspectionplanVO.getRwqsr(), inspectionplanVO.getRwjsr()) && inspectionplanVO.getJhzt().equals(Integer.parseInt(TaskStatusConstant.ARYXF.getValue()))) {
                                // 更新任务状态
                                inspectionplanVO.setJhzt(Integer.parseInt(TaskStatusConstant.ARTIME.getValue()));
                                inspectionplanFeign.updateInspectionplanonly(inspectionplanVO);
                            }
                        }
                    }
                    System.err.println("===============  Execute 注意：制定计划扫描数据结束！=============" + new Date());
                }
            }*/
        } catch (Exception e) {
            System.err.println("===============  Execute 注意：异常处理中！=============" + new Date());
        }
        return taskVOList;
    }

    /**
     * 判断日期是否在指定范围内
     *
     * @param date  需要比较的时间
     * @param date1 开始时间
     * @param date2 结束时间
     * @return true -在 ; false-不在;
     */
    //时间比较
    public static boolean dateCompare(Date date, Date date1, Date date2) {
        //是否在指定区间
        boolean isInRange = false;
        //转化数字
        long timeOne = date.getTime();
        long timeTwo = date1.getTime();
        long timeThree = date2.getTime();
        //在指定区间
        if (timeOne >= timeTwo && timeOne <= timeThree) {
            isInRange = true;
        }
        return isInRange;
    }
}
