package com.unis.inspection.service.impl;

import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.service.InspectionplanService;
import com.unis.inspectionplan.client.InspectionplanFeign;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.common.vo.TaskVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author WangZL
 * @date 2019年8月27日 下午6:53:37
 * @description APP
 */
@Service
@Slf4j
public class InspectionplanServiceImpl implements InspectionplanService {

    /*****************注入方法******************/
    @Autowired
    private InspectionplanFeign inspectionplanFeign;

    @Autowired
    private TaskFeign taskFeign;

    /***************** 全局对象******************/
    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * 公用封装方法
     */
    public void getObjectMapperMethods() {
        // 序列化的时候序列对象的所有属性
        objectMapper.setSerializationInclusion(Include.ALWAYS);
        // 反序列化的时候如果多了其他属性,不抛出异常
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        // 如果是空对象的时候,不抛异常
        objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
    }

    /**
     * 分页查询归档列表
     * @param queryvo
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseWrapper inspectionplanplace(InspectionplanQueryVO queryvo, Integer pageNum, Integer pageSize) {
        ResponseWrapper placeWrapper = inspectionplanFeign.inspectionplanplace(queryvo, pageNum, pageSize);
        String bjdwId = queryvo.getBjdwId();
        if (StringUtils.isNotEmpty(bjdwId)) {
            if (placeWrapper.getInfoCode() != 200) {
                return placeWrapper;
            }
            Map<String, Object> jcjhMap = JsonUtils.parseMap(JsonUtils.serialize(placeWrapper.getData()), String.class, Object.class);
            List<LinkedHashMap> inspectionplanVOlist = (List<LinkedHashMap>) jcjhMap.get("InspectionplanVOlist");
            PageInfo<LinkedHashMap> pageInfo = new PageInfo<LinkedHashMap>();
            List<LinkedHashMap> inspectionplanList = new ArrayList<>();
            if (inspectionplanVOlist != null && inspectionplanVOlist.size() > 0) {
                for (LinkedHashMap inspectionplan : inspectionplanVOlist) {
                    ResponseWrapper taskResponse = taskFeign.getTaskInfoByjhId(String.valueOf(inspectionplan.get("jhId")),bjdwId);
                    if (taskResponse.getInfoCode() == 200 && taskResponse.getData() != null) {
                        List<TaskVO> taskVOL = JsonUtils.parseList(JsonUtils.serialize(taskResponse.getData()), TaskVO.class);
                        if (taskVOL != null && taskVOL.size() > 0){
                            inspectionplanList.add(inspectionplan);
                        }
                    }
                }
            }
            pageInfo.setPageNum(pageNum);
            pageInfo.setSize(pageSize);
            pageInfo.setTotal(inspectionplanList.size());
            pageInfo.setList(inspectionplanList);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfo);
        } else {
            return placeWrapper;
        }
    }

    @Override
    public ResponseWrapper getInspectionplanList(String rwlxbh, String jcsj) {

        ResponseWrapper responseWrapper = inspectionplanFeign.getInspectionplanList(rwlxbh);
        if (responseWrapper.getInfoCode() != 200) {
            return responseWrapper;
        }
        List<InspectionplanVO> inspectionplanVOlist = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), InspectionplanVO.class);
        if(inspectionplanVOlist != null && inspectionplanVOlist.size() > 0){
            Date jcsjDate = null;
            if(StringUtils.isEmpty(jcsj)){
                jcsjDate = new Date();
            }else {
                SimpleDateFormat sdf = new SimpleDateFormat();
                sdf.applyPattern("yyyy-MM-dd");
                try {
                    jcsjDate = sdf.parse(jcsj);
                } catch (ParseException e) {
                    return ResponseWrapper.invalid();
                }
            }
            Date finalJcsjDate = jcsjDate;
            inspectionplanVOlist = inspectionplanVOlist.stream()
                    .filter(inspectionplanVO -> inspectionplanVO.getRwqsr() != null && inspectionplanVO.getRwqsr().before(finalJcsjDate))
                    .filter(inspectionplanVO -> (inspectionplanVO.getRwjsr() != null && inspectionplanVO.getRwjsr().after(finalJcsjDate)) || inspectionplanVO.getRwjsr() == null).collect(Collectors.toList());
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), inspectionplanVOlist);
        }
        return null;
    }
}
