package com.unis.inspection.service.impl;

import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.*;
import com.unis.inspection.app.client.DataDictionaryFeign;
import com.unis.inspection.app.vo.DataDictionaryDO;
import com.unis.inspection.service.PerformanceService;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultPerformanceVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectiontask.client.PerformanceFeign;
import com.unis.inspectiontask.client.TaskFeign;
import com.unis.inspectiontask.common.vo.*;
import com.unis.intelligence.client.CheckTalentLibFeign;
import com.unis.intelligence.client.PersonRandomFeign;
import com.unis.intelligence.common.vo.CheckTalentLibQueryVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author 张琪
 * @date 2019年8月27日 下午6:53:37
 * @description APP 业务逻辑处理 InspectionTaskServiceImpl
 */
@Service
@Slf4j
public class PerformanceServiceImpl implements PerformanceService {

    private static final Integer PERSONNEL_PERFORMANCE = 1;//操作状态：人员履职
    private static final Integer PERFORMANCE = 2;//操作状态：履职情况

    /*****************注入方法******************/
    @Autowired
    private PersonRandomFeign personRandomFeign;

    @Autowired
    private CheckTalentLibFeign checkTalentLibFeign;

    @Autowired
    private PerformanceFeign performanceFeign;

    @Autowired
    private DataDictionaryFeign dataDictionaryFeign;

    @Autowired
    private TaskFeign taskFeign;

    @Autowired
    private DailyCheckResultApi dailyCheckResultApi;

    /***************** 全局对象******************/
    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * 公用封装方法
     */
    public void getObjectMapperMethods() {
        // 序列化的时候序列对象的所有属性
        objectMapper.setSerializationInclusion(Include.ALWAYS);
        // 反序列化的时候如果多了其他属性,不抛出异常
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        // 如果是空对象的时候,不抛异常
        objectMapper.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
    }

    /**
     * 获取字典code列表
     * @return
     */
    public List<String> getDataDictionary (){
        List<String> dictCodeList = new ArrayList<>();
        ResponseWrapper responseWrapper = dataDictionaryFeign.findByGroupId("50002");
        if (responseWrapper.getInfoCode() == 200){
            List<DataDictionaryDO> dataDictionaryList = JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()), DataDictionaryDO.class);
            if (dataDictionaryList != null && dataDictionaryList.size() > 0){
                for (DataDictionaryDO dataDictionaryDO : dataDictionaryList) {

                    dictCodeList.add(dataDictionaryDO.getDictCode());
                }
            }
        }/* else {
            dictCodeList.add("5000201");
            dictCodeList.add("5000202");
            dictCodeList.add("5000203");
            dictCodeList.add("5000204");
            dictCodeList.add("5000205");
            dictCodeList.add("5000206");
            dictCodeList.add("5000207");
            dictCodeList.add("5000208");


        }*/
        return dictCodeList;
    }

    /**
     * 履职情况
     * @param performanceQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseWrapper getPerformancePage(PerformanceQueryVO performanceQueryVO, Integer pageNum, Integer pageSize) {
        CheckTalentLibQueryVO checkTalentLibQueryVO = new CheckTalentLibQueryVO();
        checkTalentLibQueryVO.setZzjgmc(performanceQueryVO.getZzjgmc());
        checkTalentLibQueryVO.setRwlxId(performanceQueryVO.getRwlxId());
        checkTalentLibQueryVO.setRyzt(performanceQueryVO.getRyzt());
        checkTalentLibQueryVO.setSfyz("y");//查询有证资格的人员
        checkTalentLibQueryVO.setOrgid(CurrentUtil.getOrgId());
        if (StringUtils.isEmpty(performanceQueryVO.getJcksDate())  && StringUtils.isEmpty(performanceQueryVO.getJcjsDate())){
            performanceQueryVO.setJcksDate(this.getLastYear());
            performanceQueryVO.setJcjsDate(DateUtil.getDateFormat(new Date(),"yyyy-MM-dd"));
        }
        //获取人员信息列表
        ResponseWrapper responseWrapper = checkTalentLibFeign.getCheckTalentLib(checkTalentLibQueryVO, pageNum, pageSize);
        PageInfo<PerformanceVO> pageInfo = new PageInfo<PerformanceVO>();
        pageInfo.setPageNum(pageNum);
        pageInfo.setPageSize(pageSize);
        List<PerformanceVO> performancePageList = new ArrayList<>();
        if(responseWrapper.getInfoCode()==200){
            LinkedHashMap linkedHashMap = (LinkedHashMap) responseWrapper.getData();
            List<LinkedHashMap> linkedHashMapList = (List<LinkedHashMap>)linkedHashMap.get("talentStoreVOS");
            if (linkedHashMapList != null && linkedHashMapList.size() > 0){
                for (LinkedHashMap talentStore : linkedHashMapList) {
                    PerformanceVO performanceVO = new PerformanceVO();
                    String rybh = talentStore.get("rybh").toString();
                    performanceVO.setRybh(rybh);
                    performanceVO.setRyxm(talentStore.get("ryxm").toString());
                    Map<String,Integer> rwnrList = new HashMap<>();
                    //通过检查组人员编号查询对应任务数据
                    ResponseWrapper taskWrapper = taskFeign.getTaskListByZyId(rybh);
                    if (taskWrapper.getInfoCode() != 200) {
                        return taskWrapper;
                    }
                    List<String> rwIdList = JsonUtils.parseList(JsonUtils.serialize(taskWrapper.getData()),String.class);
                    List<String> dictCodeList = this.getDataDictionary();
                    if (rwIdList != null && rwIdList.size() > 0){
                        performanceQueryVO.setRwIdList(rwIdList);
                        performanceQueryVO.setSflzqk(1);
                        //通过任务列表查询对应状态的结果数据
                        ResponseWrapper dailyWrapper = dailyCheckResultApi.getinspectionList(performanceQueryVO);
                        if (dailyWrapper.getInfoCode() != 200){
                            return dailyWrapper;
                        }
                        List<DailyCheckResultPerformanceVO> dailyCheckResultVOList = JsonUtils.parseList(JsonUtils.serialize(dailyWrapper.getData()),DailyCheckResultPerformanceVO.class);
                        if (dailyCheckResultVOList != null && dailyCheckResultVOList.size() > 0){
                            for (DailyCheckResultPerformanceVO dailyCheckResultPerformanceVO : dailyCheckResultVOList) {
                                JSONArray checkContentArr = JSON.parseArray(dailyCheckResultPerformanceVO.getJcnr());
                                if (checkContentArr != null) {
                                    for (int i = 0; i < checkContentArr.size(); i++) {
                                        String value = checkContentArr.getJSONObject(i).get("jcnrId").toString();
                                        if (dictCodeList.contains(value)) {
                                            int a = 1;
                                            if (rwnrList.containsKey(value)) {
                                                a = Integer.parseInt(rwnrList.get(value).toString());
                                                rwnrList.put(value, a+1);
                                            } else {
                                                rwnrList.put(value, a);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                    //补全字典表剩余字典数据
                    for (String dictCode : dictCodeList) {
                        if (!rwnrList.containsKey(dictCode)){
                            rwnrList.put(dictCode,0);
                        }
                    }
                    performanceVO.setRwnrList(rwnrList);
                    performancePageList.add(performanceVO);
                }
            }
        }
        pageInfo.setTotal(performancePageList.size());
        pageInfo.setList(performancePageList);
        return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfo);
    }

    /**
     * 人员履职情况
     * @param performanceQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseWrapper getPersonnelPerformanceList(PerformanceQueryVO performanceQueryVO, Integer pageNum, Integer pageSize) {
        CheckTalentLibQueryVO checkTalentLibQueryVO = new CheckTalentLibQueryVO();
        checkTalentLibQueryVO.setZzjgmc(performanceQueryVO.getZzjgmc());
        checkTalentLibQueryVO.setRwlxId(performanceQueryVO.getRwlxId());
        checkTalentLibQueryVO.setRyzt(performanceQueryVO.getRyzt());
        checkTalentLibQueryVO.setSfyz("y");//查询有证资格的人员
        checkTalentLibQueryVO.setOrgid(CurrentUtil.getOrgId());
        if (StringUtils.isEmpty(performanceQueryVO.getJcksDate())  && StringUtils.isEmpty(performanceQueryVO.getJcjsDate())){
            performanceQueryVO.setJcksDate(this.getLastYear());
            performanceQueryVO.setJcjsDate(DateUtil.getDateFormat(new Date(),"yyyy-MM-dd"));
        }
        ResponseWrapper responseWrapper = checkTalentLibFeign.getCheckTalentLib(checkTalentLibQueryVO, pageNum, pageSize);
        PageInfo<PersonPerformanceVO> pageInfo = new PageInfo<PersonPerformanceVO>();
        pageInfo.setPageNum(pageNum);
        pageInfo.setPageSize(pageSize);
        List<PersonPerformanceVO> personPerformancePageList = new ArrayList<>();
        if(responseWrapper.getInfoCode()==200){
            LinkedHashMap linkedHashMap = (LinkedHashMap) responseWrapper.getData();
            List<LinkedHashMap> linkedHashMapList = (List<LinkedHashMap>)linkedHashMap.get("talentStoreVOS");
            //获取人员信息列表
            if (linkedHashMapList != null && linkedHashMapList.size() > 0){
                //String jccs = "jccs";//检查次数kay
                for (LinkedHashMap talentStore : linkedHashMapList) {
                    PersonPerformanceVO personPerformanceVO = new PersonPerformanceVO();
                    String rybh = talentStore.get("rybh").toString();
                    personPerformanceVO.setRybh(rybh);
                    personPerformanceVO.setRyxm(talentStore.get("ryxm").toString());
                    personPerformanceVO.setZydw(talentStore.get("zzjgmc").toString());
                    performanceQueryVO.setRybh(rybh);
                    Object zfzbh = talentStore.get("zfzbh");
                    Object szfzbh = talentStore.get("szfzbh");
                    if (zfzbh != null && szfzbh != null){
                        personPerformanceVO.setZfzlx("国家证，市级证");
                        personPerformanceVO.setZfzbh("3");
                    } else if (zfzbh != null){
                        personPerformanceVO.setZfzlx("国家证");
                        personPerformanceVO.setZfzbh("1");
                    } else if (szfzbh != null){
                        personPerformanceVO.setZfzlx("市级证");
                        personPerformanceVO.setZfzbh("2");
                    }
                    //通过检查组人员编号查询对应任务数据
                    ResponseWrapper taskWrapper = taskFeign.getTaskListByZyId(rybh);
                    if (taskWrapper.getInfoCode() != 200) {
                        return taskWrapper;
                    }
                    Integer jccs = null;
                    List<String> rwIdList = JsonUtils.parseList(JsonUtils.serialize(taskWrapper.getData()),String.class);
                    if (rwIdList != null && rwIdList.size() > 0){
                        performanceQueryVO.setRwIdList(rwIdList);
                        //通过任务列表查询对应状态的结果数据
                        ResponseWrapper dailyWrapper = dailyCheckResultApi.getinspectionList(performanceQueryVO);
                        if (dailyWrapper.getInfoCode() != 200){
                            return dailyWrapper;
                        }
                        List<DailyCheckResultPerformanceVO> dailyCheckResultVOList = JsonUtils.parseList(JsonUtils.serialize(dailyWrapper.getData()),DailyCheckResultPerformanceVO.class);
                        if (dailyCheckResultVOList != null && dailyCheckResultVOList.size() > 0){
                            jccs = personPerformanceVO.getJccs();
                            if (jccs != null){
                                jccs = personPerformanceVO.getJccs() + dailyCheckResultVOList.size();
                                personPerformanceVO.setJccs(jccs);
                            } else {
                                jccs = dailyCheckResultVOList.size();
                                personPerformanceVO.setJccs(jccs);
                            }
                        }
                    }
                    if (jccs == null){
                        personPerformanceVO.setJccs(0);
                    }
                    personPerformancePageList.add(personPerformanceVO);
                }
            }
        }
        pageInfo.setTotal(personPerformancePageList.size());
        pageInfo.setList(personPerformancePageList);
        return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfo);
    }

    /**
     * 履职任务详情
     * @param performanceQueryVO
     * @param dataStatus
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseWrapper getPerformanceDetailsList(PerformanceQueryVO performanceQueryVO, Integer dataStatus, Integer pageNum, Integer pageSize) {
        if (dataStatus == null){
            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
        }
        //通过检查组人员编号查询对应任务数据
        ResponseWrapper taskWrapper = taskFeign.getTaskListByZyId(performanceQueryVO.getRybh());
        if (taskWrapper.getInfoCode() != 200) {
            return taskWrapper;
        }
        if (StringUtils.isEmpty(performanceQueryVO.getJcksDate())  && StringUtils.isEmpty(performanceQueryVO.getJcjsDate())){
            performanceQueryVO.setJcksDate(this.getLastYear());
            performanceQueryVO.setJcjsDate(DateUtil.getDateFormat(new Date(),"yyyy-MM-dd"));
        }
        List<String> rwIdList = JsonUtils.parseList(JsonUtils.serialize(taskWrapper.getData()),String.class);
        PageInfo<DailyCheckResultVO> pageInfo = new PageInfo<DailyCheckResultVO>();
        pageInfo.setPageNum(pageNum);
        pageInfo.setPageSize(pageSize);
        List<DailyCheckResultVO> dailyPageList = new ArrayList<>();
        if (rwIdList != null && rwIdList.size() > 0){
            performanceQueryVO.setRwIdList(rwIdList);
            List<String> jgIdList = new ArrayList<>();
            if (dataStatus.equals(PERFORMANCE)){
                performanceQueryVO.setSflzqk(1);
            }
            //通过任务列表查询对应状态的结果数据
            ResponseWrapper dailyWrapper = dailyCheckResultApi.getinspectionList(performanceQueryVO);
            if (dailyWrapper.getInfoCode() != 200){
                return dailyWrapper;
            }
            List<DailyCheckResultPerformanceVO> dailyCheckResultPerformanceList = JsonUtils.parseList(JsonUtils.serialize(dailyWrapper.getData()),DailyCheckResultPerformanceVO.class);
            if (dailyCheckResultPerformanceList != null && dailyCheckResultPerformanceList.size() > 0){
                if (dataStatus.equals(PERSONNEL_PERFORMANCE)) {//人员履职
                    for (DailyCheckResultPerformanceVO dailyCheckResultPerformanceVO : dailyCheckResultPerformanceList) {
                        jgIdList.add(dailyCheckResultPerformanceVO.getJgId());
                    }
                } else if (dataStatus.equals(PERFORMANCE)){//履职情况
                    for (DailyCheckResultPerformanceVO dailyCheckResultPerformanceVO : dailyCheckResultPerformanceList) {
                        JSONArray checkContentArr = JSON.parseArray(dailyCheckResultPerformanceVO.getJcnr());
                        if (checkContentArr != null) {
                            String dictCode = performanceQueryVO.getDictCode();
                            for (int i = 0; i < checkContentArr.size(); i++) {
                                String value = checkContentArr.getJSONObject(i).get("jcnrId").toString();
                                if (dictCode.equals(value)) {
                                    jgIdList.add(dailyCheckResultPerformanceVO.getJgId());
                                }
                            }
                        }
                    }
                }
            }
            if (jgIdList != null && jgIdList.size() > 0){
                performanceQueryVO.setJgIdList(jgIdList);
                performanceQueryVO.setPageNum(pageNum);
                performanceQueryVO.setPageSize(pageSize);
                ResponseWrapper checkWrapper = dailyCheckResultApi.getInspectionResultPageByjgIdList(performanceQueryVO);
                if (checkWrapper.getInfoCode() != 200){
                    return checkWrapper;
                }
                JSONObject obj = JSON.parseObject(JsonUtils.serialize(checkWrapper.getData()));
                dailyPageList = JsonUtils.parseList(obj.getString("list"),DailyCheckResultVO.class);
                pageInfo.setTotal(obj.getLongValue("total"));
                pageInfo.setList(dailyPageList);
            }
           
        }
        return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfo);
    }

    public LinkedHashMap addMap(LinkedHashMap linkedHashMap){
        List<String> dictCodeList = this.getDataDictionary();
        for (String dictCode : dictCodeList) {
            linkedHashMap.put(dictCode,0);
        }
        return linkedHashMap;
    }

    //获取当前时间去年时间
    public String getLastYear(){
        Calendar ca = Calendar.getInstance();//得到一个Calendar的实例
        ca.setTime(new Date()); //设置时间为当前时间
        ca.add(Calendar.YEAR, -1); //年份减1
        Date lastYear = ca.getTime();
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd");
        return sf.format(lastYear);
    }
}
