package com.unis.inspection.service.impl;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.unis.base.client.OiltankFeign;
import com.unis.base.client.WarehouseFeign;
import com.unis.base.common.vo.DCfxxsjyVO;
import com.unis.base.common.vo.OiltankQueryVO;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspection.app.client.GrainAndOilRecordClient;
import com.unis.inspection.app.vo.WarehouseOilTankVO;
import com.unis.inspection.app.vo.WarehouseVO;
import com.unis.inspection.service.WarehouseService;
import com.unis.inspectionresult.api.resultback.DailyCheckResultApi;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
@Slf4j
public class WarehouseServiceImpl implements WarehouseService {

    @Autowired
    private WarehouseFeign warehouseFeign;

    @Autowired
    private GrainAndOilRecordClient grainandoilrecordClient;

    @Autowired
    private OiltankFeign oiltankFeign;

    @Value("${project.chengpinliang}")
    private String[] chengPinLiangArray;

    @Value("${env.java-run}")
    private String env;

    private static final List<String> envIgnore = Arrays.asList("dev", "test");

    @Override
    public JSONArray getWarehouseOilTankList(DCfxxsjyVO dCfxxsjyVO) {
        ResponseWrapper responseWrapper = warehouseFeign.warehouseChengPinList(dCfxxsjyVO);
        JSONArray array = new JSONArray();
        if(responseWrapper.isSuccess()) {
            if(responseWrapper.getData()!=null) {
                array = JSONUtil.parseArray(responseWrapper.getData());
                Iterator<Object> it= array.iterator();
                JSONObject jsonObject = null;
                while (it.hasNext()) {
                    jsonObject = (JSONObject) it.next();
                    jsonObject.put("sfyg", "0");
                    String lspzmc = jsonObject.getStr("lspzmc");
                    boolean isYuanLiang = true;
                    if (StringUtils.isNotEmpty(lspzmc)) {
                        for (String s : chengPinLiangArray) {
                            if (lspzmc.contains(s)) {
                                isYuanLiang = false;
                                break;
                            }
                        }
                    }

                    String fcsl = jsonObject.getStr("fcsl");
                    if(StringUtils.isNotEmpty(fcsl)) {
                        jsonObject.put("fcsl",String.format("%.3f",Double.valueOf(fcsl)/1000d));
                    }
                    // 测试环境先关闭（否则页面一条数据都没有了，没有对应成品粮的数据），生产环境放开
                    if(isYuanLiang && !envIgnore.contains(env)){
                        it.remove();
                    }
                }
            }
        }
        JSONArray jsonArray = new JSONArray();
        ResponseWrapper olitonk = grainandoilrecordClient.selectList(dCfxxsjyVO.getKddm());
        if(olitonk.getInfoCode()!=200) {
            jsonArray = JSONUtil.parseArray(olitonk.getData());
        }

        OiltankQueryVO oiltankQueryVO = new OiltankQueryVO();
        oiltankQueryVO.setKddm(dCfxxsjyVO.getKddm());
        // 只查成品油
        oiltankQueryVO.setYglb("1");
        ResponseWrapper responseWrapper2 = oiltankFeign.getOiltankList(oiltankQueryVO);
        if(responseWrapper2.isSuccess()) {
            if(responseWrapper2.getData()!=null) {
                JSONArray array2 = JSONUtil.parseArray(responseWrapper2.getData());
                for(int i = 0;i <array2.size();i++) {
                    JSONObject jsonObject = array2.getJSONObject(i);
                    JSONObject object = new JSONObject();
                    object.put("lspzmc", "");
                    if(jsonArray!=null&&jsonArray.size()>0) {
                        for(int x=0;x<jsonArray.size();x++) {
                            JSONObject object2 = jsonArray.getJSONObject(i);
                            if(jsonObject.get("ygbh").equals(object2.getStr("ssch"))) {
                                object.put("lspzmc", object2.getStr("ccpzbm"));
                                object.put("qfh", object2.getStr("qfh"));
                                object.put("ymclgd", object2.getStr("ymclgd"));
                            }
                        }
                    }else{
                        //修改bug,说是让写死
                        //object.put("lspzmc", "大豆原油");
                        //object.put("lspzbm", "211");
                        object.put("lspzmc",jsonObject.get("lspzmc"));
                        object.put("lspzbm",jsonObject.get("lspzbm"));
                        //qfh  铅封号       ymclgd   测量高度
                    }
                    object.put("cfbh", jsonObject.get("ygbh"));
                    object.put("cflx", jsonObject.get("yglx"));
                    object.put("cfmc", jsonObject.get("ygmc"));

                    object.put("ygnzj", jsonObject.get("ygnzj"));
                    //object.put("fcsl", 0);
                    String fcsl = jsonObject.getStr("fcsl");
                    if(StringUtils.isNotEmpty(fcsl)) {
                        object.put("fcsl",String.format("%.3f",Double.valueOf(fcsl)/1000d));
                    }
                    object.put("sfyg", "1");
                    object.put("yglxmc", jsonObject.get("yglxmc"));
                    array.add(object);
                }
            }
        }
        return array;
    }

    @Override
    public List<WarehouseOilTankVO> getWarehouseOilTankList(JSONArray jsonArray) {
        List<WarehouseOilTankVO> warehouseOilTankVOList = jsonArray.toList(WarehouseOilTankVO.class);
        if(warehouseOilTankVOList != null && warehouseOilTankVOList.size() > 0){
            List<WarehouseOilTankVO> distinctList = warehouseOilTankVOList.stream()
                    .collect(Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new ArrayList<>()),
                            list -> list.stream()
                                    .distinct()
                                    .collect(Collectors.toList())
                    ));
            distinctList.forEach(d->{
                List<WarehouseOilTankVO> newList = warehouseOilTankVOList.stream().filter(w->w.getGfcfdm().equals(d.getGfcfdm())).collect(Collectors.toList());
                List<WarehouseVO> warehouseVOList = new ArrayList<>();
                LsBeanUtils.copyCollection(newList,warehouseVOList,WarehouseVO.class);
                d.setDwList(warehouseVOList);
            });
            return distinctList;
        }
        return null;
    }
}
