package com.unis.inspection.service.impl.backlog;

import java.util.Date;
import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.inspection.service.backlog.BacklogMQService;
import com.unis.inspectiontask.common.constant.BacklogConstant;
import com.unis.inspectiontask.common.vo.backlog.BacklogAddVO;
import com.unis.inspectiontask.common.vo.backlog.BacklogUpdateVO;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;

import lombok.extern.slf4j.Slf4j;

/**
 * 
 * @Description：待办服务实现
 * @author：王帅
 * @date: 2020年2月27日
 */
@Service
@Slf4j
public class BacklogMQServiceImpl implements BacklogMQService {

	@Autowired
	private RabbitTemplate amqpTemplate;

	@Override
	public void sendMsg(Object obj, String type) {
		try {
			this.amqpTemplate.convertAndSend(BacklogConstant.BACKLOG_EXCHANGE, "backlog." + type, obj);
		} catch (Exception e) {
			log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
		}
	}
	/*@Override
	public void sendMsg(Object obj, String type) {
		try {
			RabbitObjectTO rabbitObjectTO=new RabbitObjectTO();
			rabbitObjectTO.setObject(obj);
			rabbitObjectTO.setAction("backlog." + type);
			backlogProducer.send(rabbitObjectTO);
		} catch (Exception e) {
			log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
		}
	}*/

	@Override
	public void addNeedToDeals(String id, String title, String status, String statusName,String ispad,String tyname, String itemUrl,
			String itemQuery, String itemHavQuery, String itemHavUrl,String receiveCompanyName, List<ReceiverCollectionVO> userList) {
		if(CollectionUtils.isEmpty(userList)) {
			System.out.println("****************待办用户集合为空*****************");
			return;
		}
		System.out.println("*************进入创建待办************");
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		if(ispad!=null){
			record.setIspad(ispad);
		}
		if(tyname!=null){
			record.setTyname(tyname);
		}
		record.setItemId(id);
		record.setCompanyName(CurrentUtil.getOrgName());
		record.setItemName(title);
		record.setItemQueryHaveDone(itemHavQuery);
		record.setItemUrlHaveDone(itemHavUrl);
		if(!StringUtils.isEmpty(status)) {
			record.setItemStatus(Integer.valueOf(status));
		}
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		record.setReceiveCompanyName(receiveCompanyName);
		// 另起线程执行待办
		new Thread(new Runnable() {
			@Override
			public void run() {
				for (ReceiverCollectionVO userVO : userList) {
					record.setReceiver(userVO.getUserName());
					record.setReceiverId(userVO.getUserId());
					//0是待办
					record.setItemType("0");
					String data=JsonUtils.serialize(record);
					System.out.println("***待办*****************创建待办---接收人*******************");
					System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId()+"-----" + status +"-----"+data);
					System.out.println("***待办*****************************************");
					// 需要将对象序列化成JSONObject
					sendMsg(JSON.parseObject(data), "insert");
				}
			}
		}).start();
	}

	@Override
	public void addDealsYwjc(String id, String title, String status, String statusName, String isPad, String tyname,
							 String itemUrl, String itemQuery, String itemQueryHaveDone, String itemUrlHaveDone, List<ReceiverCollectionVO> userList, String userId, String userName,String receiveCompanyName) {
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setCompanyName(CurrentUtil.getOrgName());
		record.setItemQueryHaveDone(itemQueryHaveDone);
		record.setItemUrlHaveDone(itemUrlHaveDone);
		if(!org.apache.commons.lang3.StringUtils.isEmpty(status)) {
			record.setItemStatus(Integer.valueOf(status));
		}
		record.setHandlerId(userId);
		record.setHandler(userName);
		record.setHandlingTime(new Date());
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		if(isPad!=null){
			record.setIspad(isPad);
		}
		if(tyname!=null){
			record.setTyname(tyname);
		}
		record.setReceiveCompanyName(receiveCompanyName);
		System.out.println("*************进入保存已办业务检查---save,用户数:"+userList.size()+"************");
		// 另起线程执行待办
		new Thread(new Runnable() {
			@Override
			public void run() {
				for (ReceiverCollectionVO userVO : userList) {
					//类型1代表是加已办,默认是0
					record.setReceiver(userVO.getUserName());
					record.setReceiverId(userVO.getUserId());
					String data=JsonUtils.serialize(record);
					System.out.println("---保存已办业务检查---Receiver&ReceiverId---" + userVO.getUserName() + "-------" + userVO.getUserId()+"-------"+data);
					// 需要将对象序列化成JSONObject
					sendMsg(JSON.parseObject(data), "save");
				}
				System.out.println("*************结束保存已办业务检查---save************");
			}
		}).start();
	}
	
	
	@Override
	public void addDeals(String itemId, String itemName, String status, String statusName) {
		System.out.println("*************进入创建已办************");
		BacklogUpdateVO updateVO = new BacklogUpdateVO();
		updateVO.buildUpdateVO(updateVO);
		updateVO.setItemId(itemId);
		updateVO.setItemName(itemName);
		updateVO.setItemStatus(Integer.valueOf(status));
		updateVO.setItemStatusName(statusName);
		String data=JsonUtils.serialize(updateVO);
		System.out.println("---已办-------" + status +"------"+statusName+"-----"+data);
		System.out.println("***已办*****************************************");
		sendMsg(JSON.parseObject(data), "update");
	}
}
